@@ -12,7 +12,6 @@ create table t_bigint ( a bigint(10));
 create table t_float ( a float);
 create table t_double ( a double);
 create table t_decimal ( a decimal(2));
-create table t_fixed ( a fixed(2));
 create table t_smallint ( a smallint);
 create table t_tinyint ( a tinyint);
 create table t_null ( a int);
@@ -100,7 +99,7 @@ begin
 	var s string(30);
 
 	delete from t_datetime;
-	insert into t_datetime values ( date('%d.%m.%Y %H:%M:%S','01.01.2006 1:11:00'));
+	insert into t_datetime values ( scandate('%d.%m.%Y %H:%M:%S','01.01.2006 01:11:00'));
 
 	cursor dtCur as select date2str(a, '%d.%m.%Y') from t_datetime;
 	if fetch dtCur into ( :s  ) = true
@@ -210,36 +209,17 @@ begin
 	else
 		return 'ERROR';	
 	end;
-   elsif  :t = 'decimal'
+   elsif :t = 'decimal'
    then
-	var d decimal(2);
+	var f decimal(2);
 
 	delete from t_decimal;
 	insert into t_decimal values ( (decimal)12.34 );
 
-	cursor decimalCur as select a from t_decimal;
-	if fetch decimalCur into ( :d  ) = true
+	cursor decCur as select a from t_decimal;
+	if fetch decCur into ( :f  ) = true
    	then
-		if :d = (decimal)12.34
-		then  
-		      	return 'ok';
-		else
-			return 'ERROR';
-		end;	       
-	else
-		return 'ERROR';	
-	end;
-   elsif :t = 'fixed'
-   then
-	var f fixed(2);
-
-	delete from t_fixed;
-	insert into t_fixed values ( (fixed)12.34 );
-
-	cursor fixedCur as select a from t_fixed;
-	if fetch fixedCur into ( :f  ) = true
-   	then
-		if :f = (fixed)12.34
+		if :f = (decimal)12.34
 		then  
 		      	return 'ok';
 		else
@@ -451,7 +431,7 @@ begin
       end;
 
       cursor rbCur as select a from t_ta where b = 'beta';
-      if fetch taCur into ( :i  ) = true
+      if fetch rbCur into ( :i  ) = true
       then
 	return 'ERROR';
       end;
@@ -608,7 +588,7 @@ end;
 create procedure checkStringFunctions() return string(20)
 begin
 
-	insert into  t_strfunc values ( 1 , 'abXXXbb', date('%d.%m.%Y %H:%M:%S','01.01.2006 2:23:00'), 3.44, '42');
+	insert into  t_strfunc values ( 1 , 'abXXXbb', scandate('%d.%m.%Y %H:%M:%S','01.01.2006 02:23:00'), 3.44, '42');
 
 	var s string(10);
 	var i int;
@@ -1268,8 +1248,6 @@ insert into checklog values ('GATE-A', 'Float type check', :r);
 insert into checklog values ('GATE-A', 'Double type check', :r);
 :r = call checkType('decimal');
 insert into checklog values ('GATE-A', 'Decimal type check', :r);
-:r = call checkType('fixed');
-insert into checklog values ('GATE-A', 'Fixed type check', :r);
 :r = call checkType('smallint');
 insert into checklog values ('GATE-A', 'Small int type check', :r);
 :r = call checkType('tinyint');
@@ -1316,7 +1294,7 @@ insert into checklog values ('GATE-A', 'BTree check', :r);
 
 drop procedure checkType;
 drop procedure checkNull;
-drop procedure checkBtree;
+drop procedure checkBTree;
 drop procedure checkForeignKey;
 drop procedure checkTransaction;
 drop procedure checkSelectForUpdate;
@@ -1348,12 +1326,11 @@ drop table t_bigint;
 drop table t_float;
 drop table t_double;
 drop table t_decimal;
-drop table t_fixed;
 drop table t_smallint;
 drop table t_tinyint;
 drop table t_null;
-drop table t_fk1;
 drop table t_fk2;
+drop table t_fk1;
 drop table t_bt1;
 drop table t_ta;
 drop table t_sfu;
