@@ -8,7 +8,7 @@
 //     
 // Design and Implementation by Bjoern Lemke
 //
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2019 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -33,11 +33,11 @@ class CegoAVLIndexEntry {
     CegoAVLIndexEntry();
     ~CegoAVLIndexEntry();
     
-    void initEntry(const CegoDataPointer& dp, char* p = 0, int len = 0);
+    void initEntry(const CegoDataPointer& dp, char* p = 0, unsigned len = 0);
 
-    void setPtr(void* p, int len);
+    void setPtr(void* p, unsigned len);
     void* getPtr();
-    int getLen() const;
+    unsigned getLen() const;
     
     void setParent(const CegoDataPointer& dp);
     CegoDataPointer getParent() const;
@@ -54,16 +54,15 @@ class CegoAVLIndexEntry {
     void setData(const CegoDataPointer& dp);
     CegoDataPointer getData() const;
 
-        
     char* getIdxPtr();
-    int getIdxLen();
+    unsigned getIdxLen();
 
     CegoAVLIndexEntry& operator = (const CegoAVLIndexEntry& ie);
     
  private:
     
     void* _pI;
-    int _len;
+    unsigned _len;
     bool _isLocal;
     char* _idxDataPtr;
 };
