@@ -8,7 +8,7 @@
 //                                                         
 // Design and Implementation by Bjoern Lemke               
 //     
-// (C)opyright 2000-2016 Bjoern Lemke
+// (C)opyright 2000-2019 Bjoern Lemke
 //
 // INTERFACE MODULE
 //
@@ -46,7 +46,7 @@ public:
 				 const CegoDataPointer& sysEntry,
 				 const CegoDataPointer& dp, 
 				 char* idxPtr, 
-				 int idxLen, 
+				 unsigned idxLen, 
 				 unsigned long long tid, 		       
 				 bool insertAtLastPage,
 				 CegoDataPointer& ritp);
@@ -57,12 +57,12 @@ public:
 			  bool isUnique, 
 			  const CegoDataPointer& dp, 
 			  char* idxPtr,
-			  int idxLen, 
+			  unsigned idxLen, 
 			  unsigned long long tid, 
 			  bool insertAtLastPage, 
 			  bool allowWrite = false);
 
-    void deleteIndexTable(int tabSetId, 
+    void deleteIndexTable(unsigned tabSetId, 
 			  const Chain& tableName, 
 			  CegoObject::ObjectType tabType,
 			  const Chain& indexName,
@@ -70,10 +70,10 @@ public:
 			  const ListT<CegoField>& schema,
 			  const CegoDataPointer& ddp,
 			  char* idxPtr, 
-			  int idxLen,
+			  unsigned idxLen,
 			  bool allowWrite = false);
 
-    char checkIndex(int tabSetId, const Chain& indexName, CegoObject::ObjectType idxType);
+    char checkIndex(unsigned tabSetId, const Chain& indexName, CegoObject::ObjectType idxType);
 
 private:
 
@@ -84,17 +84,17 @@ private:
 
     TupleOrder compIndexValue(const ListT<CegoField>& schema, char* p1, char* p2);
     
-    void getSubTreeHeight(int tabSetId, CegoBufferPool::FixMode fixMode, const CegoAVLIndexEntry& pe, char& leftHeigtht, char& rightHeight);
-    void propagateDecrease(int tabSetId, CegoDataPointer itp, CegoBufferPool::FixMode fixMode);
-    CegoDataPointer rebalanceNode(int tabSetId, CegoDataPointer itp, CegoBufferPool::FixMode fixMode);
-    CegoDataPointer rotateRR(int tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode);        
-    CegoDataPointer rotateRL(int tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode);    
-    CegoDataPointer rotateLL(int tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode);
-    CegoDataPointer rotateLR(int tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode);    
+    void getSubTreeHeight(unsigned tabSetId, CegoBufferPool::FixMode fixMode, const CegoAVLIndexEntry& pe, char& leftHeigtht, char& rightHeight);
+    void propagateDecrease(unsigned tabSetId, CegoDataPointer itp, CegoBufferPool::FixMode fixMode);
+    CegoDataPointer rebalanceNode(unsigned tabSetId, CegoDataPointer itp, CegoBufferPool::FixMode fixMode);
+    CegoDataPointer rotateRR(unsigned tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode);        
+    CegoDataPointer rotateRL(unsigned tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode);    
+    CegoDataPointer rotateLL(unsigned tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode);
+    CegoDataPointer rotateLR(unsigned tabSetId, const CegoDataPointer& ptp, CegoBufferPool::FixMode fixMode);    
 
-    char recursiveIndexNodeCheck(int tabSetId, const CegoDataPointer& dp);
+    char recursiveIndexNodeCheck(unsigned tabSetId, const CegoDataPointer& dp);
 
-    CegoDataPointer searchDataPointer(int tabSetId, const CegoDataPointer& ddp, const CegoDataPointer& rdp, CegoBufferPool::FixMode fixMode);
+    CegoDataPointer searchDataPointer(unsigned tabSetId, const CegoDataPointer& ddp, const CegoDataPointer& rdp, CegoBufferPool::FixMode fixMode);
 
     unsigned int _lockId;
     
@@ -102,7 +102,3 @@ private:
 };
 
 #endif
-
-
-
-
