@@ -52,9 +52,7 @@ CegoAdmAction::CegoAdmAction(CegoAdminHandler *pAH, CegoModule *pModule, CegoAdm
     init();
     
     install(SIGINT);
-#ifndef HAVE_MINGW
     install(SIGPIPE);
-#endif
 
     _isAborted = false;
 	
@@ -174,7 +172,7 @@ void CegoAdmAction::readChain()
 {
     setReserved(STRINGVAL); 
     
-    int i=0;    
+    unsigned i=0;    
 
     if ( __quoteEscapeFlag )
     {
@@ -437,7 +435,7 @@ void CegoAdmAction::setQueryCacheMaxEntry()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_maxEntry = pS->asInteger();
+	_maxEntry = pS->asUnsigned();
     }
 }
 
@@ -446,7 +444,7 @@ void CegoAdmAction::setQueryCacheMaxSize()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_maxSize = pS->asInteger();
+	_maxSize = pS->asUnsigned();
     }
 }
 
@@ -455,7 +453,7 @@ void CegoAdmAction::setQueryCacheHashRange()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_hashRange = pS->asInteger();
+	_hashRange = pS->asUnsigned();
     }
 }
 
@@ -464,7 +462,7 @@ void CegoAdmAction::setQueryCacheThreshold()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_threshold = pS->asInteger();
+	_threshold = pS->asUnsigned();
     }
 }
 
@@ -577,7 +575,7 @@ void CegoAdmAction::setTableCacheMaxEntry()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_maxEntry = pS->asInteger();
+	_maxEntry = pS->asUnsigned();
     }
 }
 
@@ -586,7 +584,7 @@ void CegoAdmAction::setTableCacheMaxSize()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_maxSize = pS->asInteger();
+	_maxSize = pS->asUnsigned();
     }
 }
 
@@ -595,7 +593,7 @@ void CegoAdmAction::setTableCacheHashRange()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_hashRange = pS->asInteger();
+	_hashRange = pS->asUnsigned();
     }
 }
 
@@ -919,12 +917,12 @@ void CegoAdmAction::dbThreadInfoAction()
 
 void CegoAdmAction::dbThreadQueryHistAction() 
 {
-    int threadId = 0;
+    unsigned threadId = 0;
 
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	threadId = pS->asInteger();
+	threadId = pS->asUnsigned();
     }
         
     CegoAdminHandler::ResultType res;
@@ -950,12 +948,12 @@ void CegoAdmAction::dbThreadQueryHistAction()
 
 void CegoAdmAction::dbQueryHistLastAction()
 {
-    int numLast = 0;
+    unsigned numLast = 0;
 
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	numLast = pS->asInteger();
+	numLast = pS->asUnsigned();
     }
     
     CegoAdminHandler::ResultType res;
@@ -981,12 +979,12 @@ void CegoAdmAction::dbQueryHistLastAction()
 
 void CegoAdmAction::dbQueryHistCostAction()
 {
-    int numLast = 0;
+    unsigned numLast = 0;
 
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	numLast = pS->asInteger();
+	numLast = pS->asUnsigned();
     }
     
     CegoAdminHandler::ResultType res;
@@ -1167,11 +1165,11 @@ void CegoAdmAction::buStatResetAction()
 
 void CegoAdmAction::abortDbThreadAction() 
 {
-    int threadId = 0;
+    unsigned threadId = 0;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	threadId = pS->asInteger();
+	threadId = pS->asUnsigned();
     }
     CegoAdminHandler::ResultType res;
     res = _pAH->reqDbThreadAbort(threadId);
@@ -1496,7 +1494,7 @@ void CegoAdmAction::timeoutAction()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_timeout = pS->asInteger();
+	_timeout = pS->asUnsigned();
     }
 }
 
@@ -1721,7 +1719,7 @@ void CegoAdmAction::setTSRootPathAction()
 
 void CegoAdmAction::setTSLogNumAction()
 {
-    int logNum = 0;
+    unsigned logNum = 0;
     Chain tableSet;
     Chain* pS = getTokenList().First();
     if ( pS )
@@ -1733,7 +1731,7 @@ void CegoAdmAction::setTSLogNumAction()
     pS = getTokenList().Next();
     if ( pS )
     {
-	logNum = pS->asInteger();
+	logNum = pS->asUnsigned();
     }
 
     CegoAdminHandler::ResultType res;
@@ -1748,7 +1746,7 @@ void CegoAdmAction::setTSLogNumAction()
 
 void CegoAdmAction::setTSLogSizeAction()
 {
-    int logSize = 0;
+    unsigned logSize = 0;
     Chain tableSet;
     Chain* pS = getTokenList().First();
     if ( pS )
@@ -1759,7 +1757,7 @@ void CegoAdmAction::setTSLogSizeAction()
     pS = getTokenList().Next();
     if ( pS )
     {
-	logSize = pS->asInteger();
+	logSize = pS->asUnsigned();
     }
 
     CegoAdminHandler::ResultType res;
@@ -1827,7 +1825,7 @@ void CegoAdmAction::setTSLogUserAction()
 void CegoAdmAction::setTSSysSizeAction()
 {
     Chain tableSet;
-    int sysSize = 0;
+    unsigned sysSize = 0;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
@@ -1837,7 +1835,7 @@ void CegoAdmAction::setTSSysSizeAction()
     pS = getTokenList().Next();
     if ( pS )
     {
-	sysSize = pS->asInteger();
+	sysSize = pS->asUnsigned();
     }
 
     CegoAdminHandler::ResultType res;
@@ -1853,7 +1851,7 @@ void CegoAdmAction::setTSSysSizeAction()
 void CegoAdmAction::setTSTmpSizeAction()
 {
     Chain tableSet;
-    int tmpSize = 0;
+    unsigned tmpSize = 0;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
@@ -1863,7 +1861,7 @@ void CegoAdmAction::setTSTmpSizeAction()
     pS = getTokenList().Next();
     if ( pS )
     {
-	tmpSize = pS->asInteger();
+	tmpSize = pS->asUnsigned();
     }
 
     CegoAdminHandler::ResultType res;
@@ -1879,7 +1877,7 @@ void CegoAdmAction::setTSTmpSizeAction()
 void CegoAdmAction::setTSAppSizeAction()
 {
     Chain tableSet;
-    int appSize = 0;
+    unsigned appSize = 0;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
@@ -1889,7 +1887,7 @@ void CegoAdmAction::setTSAppSizeAction()
     pS = getTokenList().Next();
     if ( pS )
     {
-	appSize = pS->asInteger();
+	appSize = pS->asUnsigned();
     }
 
     CegoAdminHandler::ResultType res;
@@ -1905,7 +1903,7 @@ void CegoAdmAction::setTSAppSizeAction()
 void CegoAdmAction::setCheckpointAction()
 {
     Chain tableSet;
-    int interval = 0;
+    unsigned interval = 0;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
@@ -1915,7 +1913,7 @@ void CegoAdmAction::setCheckpointAction()
     pS = getTokenList().Next();
     if ( pS )
     {
-	interval = pS->asInteger();
+	interval = pS->asUnsigned();
     }
 
     CegoAdminHandler::ResultType res;
@@ -1930,11 +1928,11 @@ void CegoAdmAction::setCheckpointAction()
 
 void CegoAdmAction::setNumQueryLastAction()
 {    
-    int numLast = 0;
+    unsigned numLast = 0;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	numLast = pS->asInteger();
+	numLast = pS->asUnsigned();
     }
 
     CegoAdminHandler::ResultType res;
@@ -1949,11 +1947,11 @@ void CegoAdmAction::setNumQueryLastAction()
 
 void CegoAdmAction::setNumQueryCostAction()
 {   
-    int numCost = 0;
+    unsigned numCost = 0;
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	numCost = pS->asInteger();
+	numCost = pS->asUnsigned();
     }
 
     CegoAdminHandler::ResultType res;
@@ -2677,7 +2675,7 @@ void CegoAdmAction::importTableSetStructureAction()
 
 void CegoAdmAction::addDataFileAction()
 {
-    int numPages = 0;
+    unsigned numPages = 0;
     Chain tableSet;
     Chain dataFile(_stringBuf);
     Chain fileType;
@@ -2691,7 +2689,7 @@ void CegoAdmAction::addDataFileAction()
     pS = getTokenList().Next();
     if ( pS )
     {
-	numPages = pS->asInteger();
+	numPages = pS->asUnsigned();
     }
 
     pS = getTokenList().Next();
@@ -3355,7 +3353,7 @@ void CegoAdmAction::storeSysSizeAttr()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_sysSize = pS->asInteger();
+	_sysSize = pS->asUnsigned();
     }
 }
 
@@ -3364,7 +3362,7 @@ void CegoAdmAction::storeTmpSizeAttr()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_tmpSize = pS->asInteger();
+	_tmpSize = pS->asUnsigned();
     }
 }
 
@@ -3373,7 +3371,7 @@ void CegoAdmAction::storeAppSizeAttr()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_appSize = pS->asInteger();
+	_appSize = pS->asUnsigned();
     }
 }
 
@@ -3382,7 +3380,7 @@ void CegoAdmAction::storeLogSizeAttr()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_logSize = pS->asInteger();
+	_logSize = pS->asUnsigned();
     }
 }
 
@@ -3391,7 +3389,7 @@ void CegoAdmAction::storeLogNumAttr()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_logNum = pS->asInteger();
+	_logNum = pS->asUnsigned();
     }
 }
 
@@ -3424,7 +3422,7 @@ void CegoAdmAction::storeBranchAttr()
     Chain* pS = getTokenList().First();
     if ( pS )
     {
-	_branchId = pS->asInteger();
+	_branchId = pS->asUnsigned();
     }
 }
 
@@ -3578,9 +3576,7 @@ void CegoAdmAction::sigCatch(int sig)
     try
     {	
 	install(SIGINT);
-#ifndef HAVE_MINGW
 	install(SIGPIPE);
-#endif
 
 	if ( _abortEnabled )
 	{
