@@ -51,7 +51,7 @@ CegoAdmNet::~CegoAdmNet()
 	delete _pModule;
 }
 
-void CegoAdmNet::connect(const Chain& serverName, int port, const Chain& user, const Chain& pwd)
+void CegoAdmNet::connect(const Chain& serverName, unsigned port, const Chain& user, const Chain& pwd)
 {
     Net n (  NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN, NETMNG_MAXSENDLEN );
 
@@ -61,7 +61,7 @@ void CegoAdmNet::connect(const Chain& serverName, int port, const Chain& user, c
     {
 	_pModule = new CegoModule(_logFile, _progName);
 	
-	int modId = 100;
+	unsigned modId = 100;
 	
 	if ( _logLevel == Chain("notice"))
 	    _pModule->logModule(modId, "dbdimp", Logger::NOTICE);
@@ -390,7 +390,7 @@ void CegoAdmNet::exportTableSet(const Chain& tableSet, const Chain& expMode, con
     handleMedResult(res);        
 }
    
-void CegoAdmNet::addDataFile(const Chain& tableSet, const Chain& fileType, const Chain& dataFile, int numPages)
+void CegoAdmNet::addDataFile(const Chain& tableSet, const Chain& fileType, const Chain& dataFile, unsigned numPages)
 {
     CegoAdminHandler::ResultType res;    
     res = _pAH->medAddDataFile(tableSet, fileType, dataFile, numPages);
@@ -401,13 +401,13 @@ void CegoAdmNet::defineTableSet(const Chain& tableSet,
 				const Chain& tsRoot,
 				const Chain& primary,
 				const Chain& secondary,
-				int sysSize,
-				int tmpSize,
-				int appSize,
-				int logSize,
-				int logNum, 
+				unsigned sysSize,
+				unsigned tmpSize,
+				unsigned appSize,
+				unsigned logSize,
+				unsigned logNum, 
 				unsigned long long orderSize,
-				int branchId)
+				unsigned branchId)
 {
     CegoAdminHandler::ResultType res;
     res = _pAH->medDefineTableSet(tableSet,
