@@ -156,7 +156,7 @@ int main(int argc, char **argv)
     Chain logFile = longOpt.getOptValue("logfile");
     Chain serverName = longOpt.getOptValue("server");
     Chain prompt = longOpt.getOptValue("prompt");
-    int portNo = longOpt.getOptValue("port").asInteger();
+    unsigned portNo = longOpt.getOptValue("port").asUnsigned();
 
 
     CegoModule *pModule = 0;
@@ -262,7 +262,7 @@ int main(int argc, char **argv)
         }
 	case BATCH:
 	{	    
-	    int lineNo=0;
+	    unsigned lineNo=0;
 	    	    	    
 	    Chain cmd;
 	    Chain line;
