@@ -38,7 +38,7 @@ public:
     enum AggType { MIN, MAX, AVG, SUM, COUNT };
     
     CegoAggregation(bool isDistinct);
-    CegoAggregation(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId);
+    CegoAggregation(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     CegoAggregation(AggType type, CegoExpr* pExpr, bool isDistinct = false);
     ~CegoAggregation();
 
@@ -52,10 +52,10 @@ public:
 
     bool isDistinct() const;
 
-    void setTabSetId(int tabSetId);
+    void setTabSetId(unsigned tabSetId);
     
-    void setAggregationId(int aid);
-    const int getAggregationId() const;
+    void setAggregationId(unsigned aid);
+    const unsigned getAggregationId() const;
 
     void clearAttrCache();
     
@@ -66,8 +66,8 @@ public:
     ListT<CegoAttrDesc*> getAttrRefList() const;
 
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId);
-    int getEncodingLength(CegoProcBlock *pBlock) const;
+    void decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    unsigned getEncodingLength(CegoProcBlock *pBlock) const;
     
     Chain getId(CegoProcBlock *pBlock) const;
     Chain toChain(int defTabSetId) const;
@@ -79,7 +79,7 @@ private:
 
     CegoFieldValue _fv;
     
-    int _aid;
+    unsigned _aid;
     AggType _type;    
     CegoExpr* _pExpr;
     bool _isDistinct;
