@@ -164,12 +164,12 @@ CegoAttrComp::CompMode CegoAttrComp::getCompMode() const
     return _compMode;
 }
 
-int CegoAttrComp::getPos() const
+unsigned CegoAttrComp::getPos() const
 {
     return _pos;
 }
 
-void CegoAttrComp::setPos(int pos)
+void CegoAttrComp::setPos(unsigned pos)
 {
     _pos = pos;
 }
@@ -360,9 +360,9 @@ bool CegoAttrComp::setup(const ListT<CegoField>& fl)
     }
 }
 
-bool CegoAttrComp::setup(ListT<CegoField>** pJoinBuf, int offset)
+bool CegoAttrComp::setup(ListT<CegoField>** pJoinBuf, unsigned offset)
 {
-    int i = offset;
+    unsigned i = offset;
 
     if ( _compMode == ATTR )
     {
