@@ -200,9 +200,9 @@ void CegoAttrDesc::decode(char *buf)
     }
 }
 
-int CegoAttrDesc::getEncodingLength() const
+unsigned CegoAttrDesc::getEncodingLength() const
 {
-    int len = 0;
+    unsigned len = 0;
     
     len += sizeof(char);
     len += _tableName.length();
@@ -213,9 +213,9 @@ int CegoAttrDesc::getEncodingLength() const
     return len;
 }
 
-int CegoAttrDesc::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
+unsigned CegoAttrDesc::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
 {
-    int refCount = 0;
+    unsigned refCount = 0;
 
     if ( pCO->getType() == CegoObject::JOIN )
     {
@@ -234,20 +234,12 @@ int CegoAttrDesc::evalReferences(CegoContentObject *pCO, const ListT<CegoField>&
     return refCount;
 }
 
-int CegoAttrDesc::evalTableReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
+unsigned CegoAttrDesc::evalTableReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
 {    
-    int refCount = 0;
-    
-    if ( ( _tableName == (Chain)pCO->getTabName() && pCO->getType() != CegoObject::ALIAS )
-	|| ( _tableName == (Chain)pCO->getTabAlias() && _tableName != Chain()) )
-    {
-	if ( pCO->getType() == CegoObject::ALIAS )
-	    _tableName = pCO->getTabAlias();
-	else
-	    _tableName = pCO->getName();
-	refCount++;
-    }
-    else if ( _tableName == Chain() )
+    unsigned refCount = 0;
+ 
+    // if no table referance has been set up, we search for appropriate in field list
+    if ( _tableName == Chain() )
     {
 	CegoField* pF = fl.First();
 	while (pF)
@@ -260,6 +252,21 @@ int CegoAttrDesc::evalTableReferences(CegoContentObject *pCO, const ListT<CegoFi
 	    pF = fl.Next();	    
 	}
     }
+   else
+   {
+       // for alias objects, tablename is not visible for referencing attribute
+       // so just in case of non alias objects, we replace tablename with alias name
+      
+       if ( ( pCO->getType() != CegoObject::ALIAS && _tableName == (Chain)pCO->getTabName() )
+	    ||  _tableName == (Chain)pCO->getTabAlias() )
+       {
+	   // we set tableName in any case
+	   _tableName = pCO->getTabAlias();
+	   // needed to increase refcount
+	   refCount++;
+       }
+   }
+   
     return refCount;
 }
 
