@@ -52,7 +52,7 @@ CegoBufferPool::CegoBufferPool(const Chain& xmlDef, const Chain& logFile, const
     _avgWriteDelay=0;
     _cpCount = 0;
     
-    for (int i=0;i< TABMNG_MAXTABSET;i++)
+    for (unsigned i=0;i< TABMNG_MAXTABSET;i++)
     {
 	_lmLock[i].init(LCKMNG_LOCKWAITDELAY, __lockStatOn);
 	_lmLock[i].setId( Chain("LMLOCK") + Chain("-") + Chain(i));
@@ -75,7 +75,7 @@ void CegoBufferPool::initPool(unsigned long long numSegment, unsigned long long
 #endif
 
     Chain dbName = getDbName();
-    int pageSize = getPageSize();
+    unsigned pageSize = getPageSize();
     _maxFixTries = getMaxFixTries();
     _maxPageDelete = getMaxPageDelete();
     
@@ -160,7 +160,7 @@ Chain CegoBufferPool::getDBName()
     return _dbName;
 }
 
-void CegoBufferPool::bufferFix(CegoBufferPage &bp, int tabSetId, PageIdType pageId, FixMode m, CegoLockHandler *pLockHandle, int numTry)
+void CegoBufferPool::bufferFix(CegoBufferPage &bp, unsigned tabSetId, PageIdType pageId, FixMode m, CegoLockHandler *pLockHandle, unsigned numTry)
 {	    
     _fixCount++;
 
@@ -174,11 +174,11 @@ void CegoBufferPool::bufferFix(CegoBufferPage &bp, int tabSetId, PageIdType page
 	throw Exception(EXLOC, "No valid bufferpool" );
     }
     
-    int segid = calcSegment(pageId);
+    unsigned segid = calcSegment(pageId);
 
     void *base = (void*)_pBufPool[segid];
 
-    int hashId = calcHash(pageId);
+    unsigned hashId = calcHash(pageId);
     
     // cout << "PageId=" << pageId << ", Seg=" << segid << ", HashId=" << hashId << endl;
     
@@ -186,7 +186,7 @@ void CegoBufferPool::bufferFix(CegoBufferPage &bp, int tabSetId, PageIdType page
     
     bool isFixed = false;
     
-    int numTries = 0;
+    unsigned numTries = 0;
 
     // Step I : searching for possible slot
 	
@@ -400,8 +400,8 @@ void CegoBufferPool::bufferFix(CegoBufferPage &bp, int tabSetId, PageIdType page
 	    if ( numTry == 1 )
 	    {
 		// we force checkpoints for all active tableset, 
-		ListT<int> tsList = getOnlineTableSet();
-		int* pTS = tsList.First();
+		ListT<unsigned> tsList = getOnlineTableSet();
+		unsigned* pTS = tsList.First();
 		while ( pTS )
 		{
 		    if ( *pTS != tabSetId )
@@ -428,7 +428,7 @@ void CegoBufferPool::bufferFix(CegoBufferPage &bp, int tabSetId, PageIdType page
     bp.setFixed(true);
 }
 
-void CegoBufferPool::emptyFix(CegoBufferPage &bp, int tabSetId, FixMode m, CegoFileHandler::FileType ft, CegoLockHandler *pLockHandle, bool doAppend)
+void CegoBufferPool::emptyFix(CegoBufferPage &bp, unsigned tabSetId, FixMode m, CegoFileHandler::FileType ft, CegoLockHandler *pLockHandle, bool doAppend)
 {
     if (_pBufPool == 0)
     {
@@ -438,13 +438,13 @@ void CegoBufferPool::emptyFix(CegoBufferPage &bp, int tabSetId, FixMode m, CegoF
     PageIdType pageId;
     
     unsigned* fbm;
-    int fbmSize=0;
+    unsigned fbmSize=0;
 
     allocatePage(tabSetId, ft, pageId, pLockHandle, fbm, fbmSize, doAppend);
 
     if ( fbmSize > 0 )
     {
-	int fileId = getFileIdForPageId(pageId);
+	unsigned fileId = getFileIdForPageId(pageId);
 	logBM(tabSetId, fileId, fbm, fbmSize, pLockHandle);
 	delete[] fbm;
     }
@@ -461,11 +461,11 @@ void CegoBufferPool::bufferUnfix(CegoBufferPage &bp, bool isDirty, CegoLockHandl
 	throw Exception(EXLOC, "No valid bufferpool" );
     }
 
-    int segid = calcSegment(bp.getPageId());
+    unsigned segid = calcSegment(bp.getPageId());
     
     void *base = (void*)_pBufPool[segid];
     char* bufPtr = (char*)bp.getPagePtr();
-    int hashId = ( (long long)bufPtr - (long long)base - BUFFERPOOLHEAD_SIZE ) / (  BUFFERHEAD_SIZE + _pageSize );
+    unsigned hashId = ( (long long)bufPtr - (long long)base - BUFFERPOOLHEAD_SIZE ) / (  BUFFERHEAD_SIZE + _pageSize );
     
     bufPtr = bufPtr - BUFFERHEAD_SIZE;
     
@@ -504,11 +504,11 @@ void CegoBufferPool::bufferRelease(CegoBufferPage &bp, CegoLockHandler *pLockHan
     
     BufferHead bh;
     
-    int hashId = calcHash(bp.getPageId());
+    unsigned hashId = calcHash(bp.getPageId());
     
     pLockHandle->lockBufferPool(hashId, CegoLockHandler::WRITE);
 
-    int tabSetId = 0;
+    unsigned tabSetId = 0;
     
     try
     {
@@ -548,9 +548,9 @@ void CegoBufferPool::bufferRelease(CegoBufferPage &bp, CegoLockHandler *pLockHan
     }
 }
 
-unsigned long long CegoBufferPool::writeCheckPoint(const Chain& tableSet, bool switchLog, bool archComplete, CegoLockHandler *pLockHandle, const Chain& escCmd, int escTimeout, int archTimeout)
+unsigned long long CegoBufferPool::writeCheckPoint(const Chain& tableSet, bool switchLog, bool archComplete, CegoLockHandler *pLockHandle, const Chain& escCmd, unsigned escTimeout, unsigned archTimeout)
 {
-    int tabSetId = getTabSetId(tableSet);    
+    unsigned tabSetId = getTabSetId(tableSet);    
 
     log(_modId, Logger::NOTICE, Chain("Writing checkpoint for tableset ") + tableSet + Chain(" as lsn = ") 
 	+ Chain(getCurrentLSN(tabSetId)) + Chain(" ..."));    
@@ -578,7 +578,7 @@ unsigned long long CegoBufferPool::writeCheckPoint(const Chain& tableSet, bool s
     return lsn;
 }
 
-unsigned long long CegoBufferPool::writeCheckPoint(int tabSetId, bool switchLog, const Chain& escCmd, int timeout, CegoLockHandler *pLockHandle)
+unsigned long long CegoBufferPool::writeCheckPoint(unsigned tabSetId, bool switchLog, const Chain& escCmd, unsigned timeout, CegoLockHandler *pLockHandle)
 {
     if (_pBufPool == 0)
     {
@@ -626,7 +626,7 @@ unsigned long long CegoBufferPool::writeCheckPoint(int tabSetId, bool switchLog,
 	PageIdType *pDelPage = _deletedPageList.First();
 	while ( pDelPage )
 	{
-	    int fbmSize=0;
+	    unsigned fbmSize=0;
 	    unsigned* fbm;
 	    
 	    // cout << "Releasing page " << *pDelPage << endl;
@@ -635,7 +635,7 @@ unsigned long long CegoBufferPool::writeCheckPoint(int tabSetId, bool switchLog,
 	    
 	    if ( fbmSize > 0 )
 	    {
-		int fileId = getFileIdForPageId(*pDelPage);
+		unsigned fileId = getFileIdForPageId(*pDelPage);
 		logBM(tabSetId, fileId, fbm, fbmSize, pLockHandle);
 		delete[] fbm;
 	    }
@@ -737,7 +737,7 @@ unsigned long long CegoBufferPool::writeCheckPoint(int tabSetId, bool switchLog,
 #ifdef DEBUG
 				log(_modId, Logger::DEBUG, Chain("Reading page (") + Chain(bh.fileId) + Chain(",") + Chain(bh.pageId) + Chain(") to log ..."));
 #endif	
-				int ts;
+				unsigned ts;
 				unsigned fixStat;
 				char *pageData = new char[_pageSize];
 				readPage(bh.pageId, ts, fixStat, pageData, pLockHandle);
@@ -811,7 +811,7 @@ unsigned long long CegoBufferPool::getCPCount() const
     return _cpCount;
 }
 
-void CegoBufferPool::dumpCheckpoint(int tabSetId)
+void CegoBufferPool::dumpCheckpoint(unsigned tabSetId)
 {
     Chain tableSet = getTabSetName(tabSetId);
     Chain tsRoot = getTSRoot(tableSet);
@@ -844,7 +844,7 @@ void CegoBufferPool::dumpCheckpoint(int tabSetId)
     cpd.finish();
 }
 
-void CegoBufferPool::commitCheckpoint(int tabSetId, CegoLockHandler *pLockHandle)
+void CegoBufferPool::commitCheckpoint(unsigned tabSetId, CegoLockHandler *pLockHandle)
 {
     Chain currentState = getTableSetRunState(tabSetId);
     
@@ -878,7 +878,7 @@ void CegoBufferPool::commitCheckpoint(int tabSetId, CegoLockHandler *pLockHandle
 #ifdef DEBUG
 		log(_modId, Logger::DEBUG, Chain("Reading page (") + Chain(bh.fileId) + Chain(",") + Chain(bh.pageId) + Chain(") to log ..."));
 #endif	
-		int ts;
+		unsigned ts;
 		unsigned oldFixStat;
 		char *oldPageData = new char[_pageSize];
 		try
@@ -917,7 +917,7 @@ void CegoBufferPool::commitCheckpoint(int tabSetId, CegoLockHandler *pLockHandle
     cpd.remove();
 }
 
-void CegoBufferPool::restoreCheckpointDump(int tabSetId, CegoLockHandler *pLockHandle)
+void CegoBufferPool::restoreCheckpointDump(unsigned tabSetId, CegoLockHandler *pLockHandle)
 {
     Chain tableSet = getTabSetName(tabSetId);
     Chain tsRoot = getTSRoot(tableSet);
@@ -948,7 +948,7 @@ void CegoBufferPool::restoreCheckpointDump(int tabSetId, CegoLockHandler *pLockH
     cpd.cleanUp();
 }
     
-void CegoBufferPool::writeAndRemoveTabSet(int tabSetId, CegoLockHandler *pLockHandle)
+void CegoBufferPool::writeAndRemoveTabSet(unsigned tabSetId, CegoLockHandler *pLockHandle)
 {
     if (_pBufPool == 0)
     {
@@ -995,7 +995,7 @@ unsigned long long CegoBufferPool::uptime() const
     return ts.asLong() - _poolStart;
 }
 
-void CegoBufferPool::poolInfo(int& pageSize, 
+void CegoBufferPool::poolInfo(unsigned& pageSize, 
 			      unsigned long long& numTotal, 
 			      unsigned long long& numUsed, 
 			      unsigned long long& numFree, 
@@ -1185,7 +1185,7 @@ void CegoBufferPool::resetStats()
     _statStart = ts.asLong(); 
 }
 
-void CegoBufferPool::logIt(int tabSetId, CegoLogRecord& lr, CegoLockHandler* pLockHandle, bool flushLog)
+void CegoBufferPool::logIt(unsigned tabSetId, CegoLogRecord& lr, CegoLockHandler* pLockHandle, bool flushLog)
 {
     if ( isActive(tabSetId) )
     {
@@ -1271,7 +1271,7 @@ void CegoBufferPool::printPool()
     cout << "NumFree: " << numFree << endl;
 }
 
-void CegoBufferPool::getLMLockStat(int tabSetId, Chain& lockName, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+void CegoBufferPool::getLMLockStat(unsigned tabSetId, Chain& lockName, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     lockName = getTabSetName(tabSetId);
     lockCount = _lmLock[tabSetId].numLockTry();
@@ -1287,7 +1287,7 @@ void CegoBufferPool::getLMLockStat(int tabSetId, Chain& lockName, int& lockCount
 	sumWrDelay = _lmLock[tabSetId].sumWriteDelay() / LCKMNG_DELRES;
 }
 
-void CegoBufferPool::getAggLMLockStat(Chain& lockGroup, int& numLock, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+void CegoBufferPool::getAggLMLockStat(Chain& lockGroup, unsigned& numLock, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     lockGroup = Chain("LMLCK");
     
@@ -1316,7 +1316,7 @@ void CegoBufferPool::getAggLMLockStat(Chain& lockGroup, int& numLock, int& lockC
 // private methods //
 /////////////////////
 
-int CegoBufferPool::calcHash(PageIdType pageId)
+unsigned CegoBufferPool::calcHash(PageIdType pageId)
 {
     // we have to cast to long, since for large fileid values, we might exceed integer range
     // unsigned long long s = (unsigned long long)(fileId+1) * (unsigned long long)_hashkey + (unsigned long long)(pageId+1);    
@@ -1327,15 +1327,15 @@ int CegoBufferPool::calcHash(PageIdType pageId)
     if ( s > d )
 	s = s - d;
     
-    return (int)( s % (unsigned long long)_numPages);
+    return (unsigned)( s % (unsigned long long)_numPages);
 }
 
-int CegoBufferPool::calcSegment(PageIdType pageId)
+unsigned CegoBufferPool::calcSegment(PageIdType pageId)
 {
-    return (int)( ( pageId / (unsigned long long)_numPages ) % (unsigned long long)_numSegment);
+    return (unsigned)( ( pageId / (unsigned long long)_numPages ) % (unsigned long long)_numSegment);
 }
 
-void CegoBufferPool::logBM(int tabSetId, int fileId, unsigned* fbm, int fbmSize, CegoLockHandler* pLockHandle)
+void CegoBufferPool::logBM(unsigned tabSetId, unsigned fileId, unsigned* fbm, unsigned fbmSize, CegoLockHandler* pLockHandle)
 {    
     CegoLogRecord lr;
     
@@ -1350,7 +1350,7 @@ void CegoBufferPool::logBM(int tabSetId, int fileId, unsigned* fbm, int fbmSize,
 bool CegoBufferPool::archiveComplete(const Chain& tableSet)
 {
     ListT<Chain> lfList;
-    ListT<int> sizeList;
+    ListT<unsigned> sizeList;
     ListT<Chain> statusList;
 
     getLogFileInfo(tableSet, lfList, sizeList, statusList);
@@ -1371,7 +1371,7 @@ bool CegoBufferPool::archiveComplete(const Chain& tableSet)
     return true;
 }
 
-void CegoBufferPool::optimizePool(int tabSetId)
+void CegoBufferPool::optimizePool(unsigned tabSetId)
 {
     Chain tableSet = getTabSetName(tabSetId);
     log(_modId, Logger::NOTICE, Chain("Optimizing bufferpool for tableset ") + tableSet + Chain(" ..."));
@@ -1440,7 +1440,7 @@ void CegoBufferPool::optimizePool(int tabSetId)
     log(_modId, Logger::NOTICE, Chain(numRelocated) + Chain(" pages relocated "));
 }
 
-void CegoBufferPool::lockPool(int tabSetId, bool doWrite)
+void CegoBufferPool::lockPool(unsigned tabSetId, bool doWrite)
 {
     if ( doWrite )
     {
@@ -1452,7 +1452,7 @@ void CegoBufferPool::lockPool(int tabSetId, bool doWrite)
     }
 }
 
-void CegoBufferPool::unlockPool(int tabSetId)
+void CegoBufferPool::unlockPool(unsigned tabSetId)
 {
     _lmLock[tabSetId].unlock();   
 }
