@@ -91,7 +91,7 @@ enum RunMode { INTERACTIVE, PAGER, BATCH, DUMP };
 extern char __lfcVersionString[];
 extern char __lfcxmlVersionString[];
 extern Chain __dateTimeFormat;
-extern int __dateLength;
+extern unsigned __dateLength;
 extern char __currencySymbol;
 extern char __decimalPoint;
 
@@ -101,7 +101,7 @@ class AbortHandler : public SigHandler
 public:
 
     AbortHandler(const Chain& serverName, 
-		 int portNo,
+		 unsigned portNo,
 		 const Chain& tableSet,
 		 const Chain& user, 
 		 const Chain& password,		 
@@ -118,7 +118,7 @@ private:
     unsigned long long _tid;
     bool _doAbort;
     CegoModule *_pModule;
-    int _portNo;
+    unsigned _portNo;
     Chain _serverName;
     Chain _user;
     Chain _password;
@@ -135,7 +135,7 @@ public:
     ProfileEntry(const Chain& pid);
     ProfileEntry(const Chain& pid,
 		 const Chain& serverName,
-		 int portNo,
+		 unsigned portNo,
 		 const Chain& protocol,
 		 const Chain& tableSet,
 		 const Chain& auth, 
@@ -144,7 +144,7 @@ public:
 
     const Chain& getId() const;
     const Chain& getServerName() const;
-    int getPortNo() const;
+    unsigned getPortNo() const;
     const Chain& getProtocol() const;
     const Chain& getTableSet() const;
     const Chain& getAuth() const;
@@ -156,7 +156,7 @@ public:
 private:
 
     Chain _pid;
-    int _portNo;
+    unsigned _portNo;
     Chain _serverName;
     Chain _protocol;
     Chain _tableSet;
@@ -314,7 +314,7 @@ Chain user;
 Chain password;
 Chain serverName;
 Chain tableSet;
-int portNo;
+unsigned portNo;
 Chain authString;
 Chain promptString;
 Chain protocol;
@@ -505,7 +505,7 @@ int main(int argc, char **argv)
     {	
 	serverName = longOpt.getOptValue("server");
 	tableSet = longOpt.getOptValue("tableset");
-	portNo = longOpt.getOptValue("port").asInteger();    
+	portNo = longOpt.getOptValue("port").asUnsigned();    
 	authString = longOpt.getOptValue("user");
 	promptString = Chain(PROMPT);	
 	protocol = longOpt.getOptValue("protocol");
@@ -623,7 +623,7 @@ int execute()
     {	
     case BATCH:
     {
-	int lineNo=0;
+	unsigned lineNo=0;
 
 	CegoNet *pCegoNet = new CegoNet( protType, logFile, Chain(), logMode );	
 	
@@ -1864,14 +1864,14 @@ void loadProfile(const Chain& rcFileName, ListT<ProfileEntry>& pfeList)
 	    }
 
 	    Chain auth = user + Chain("/") + pwd;
-	    ProfileEntry pfe(pid, serverName, portNo.asInteger(), protocol, tableSet, auth, prompt);
+	    ProfileEntry pfe(pid, serverName, portNo.asUnsigned(), protocol, tableSet, auth, prompt);
 	    pfeList.Insert(pfe);	    
 	}		
     }
 }
 
 AbortHandler::AbortHandler(const Chain& serverName, 
-			   int portNo, 
+			   unsigned portNo, 
 			   const Chain& tableSet,
 			   const Chain& user, 
 			   const Chain& password,
@@ -1880,9 +1880,7 @@ AbortHandler::AbortHandler(const Chain& serverName,
 			   bool isQuiet) :  SigHandler() 
 {
     install(SIGINT);
-#ifndef HAVE_MINGW
     install(SIGPIPE);
-#endif
     _tid = tid;
     _pModule = pModule;
     _portNo = portNo;
@@ -1902,9 +1900,8 @@ void AbortHandler::sigCatch(int sig)
     try
     {	
 	install(SIGINT);
-#ifndef HAVE_MINGW
 	install(SIGPIPE);
-#endif
+	
 	if ( _doAbort )
 	{
 	    if ( _isQuiet == false )
@@ -1961,7 +1958,7 @@ ProfileEntry::ProfileEntry(const Chain& pid)
 
 ProfileEntry::ProfileEntry(const Chain& pid, 
 			   const Chain& serverName, 
-			   int portNo, 
+			   unsigned portNo, 
 			   const Chain& protocol, 
 			   const Chain& tableSet,
 			   const Chain& auth, 
@@ -1990,7 +1987,7 @@ const Chain& ProfileEntry::getServerName() const
     return _serverName;
 }
 
-int ProfileEntry::getPortNo() const
+unsigned ProfileEntry::getPortNo() const
 {
     return _portNo;
 }
