@@ -52,7 +52,7 @@ CegoDatabaseManager::ObjectRecord::ObjectRecord()
 {
 }
 
-CegoDatabaseManager::ObjectRecord::ObjectRecord(const int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+CegoDatabaseManager::ObjectRecord::ObjectRecord(const unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {
     _objName = objName;
     _type = type;
@@ -66,7 +66,7 @@ CegoDatabaseManager::ObjectRecord::~ObjectRecord()
 {
 }
 
-const int CegoDatabaseManager::ObjectRecord::getTabSetId() const
+const unsigned CegoDatabaseManager::ObjectRecord::getTabSetId() const
 {
     return _tabSetId;
 }
@@ -82,7 +82,7 @@ void CegoDatabaseManager::ObjectRecord::decUsed()
 	_numUsed--;
 }
 
-int CegoDatabaseManager::ObjectRecord::numUsed() const
+unsigned CegoDatabaseManager::ObjectRecord::numUsed() const
 {
     return _numUsed;
 }
@@ -209,12 +209,12 @@ const Chain& CegoDatabaseManager::CopyRecord::getMsg() const
     return _msg;
 }
 
-int CegoDatabaseManager::CopyRecord::getId() const
+unsigned CegoDatabaseManager::CopyRecord::getId() const
 {
     return _id;
 }
 
-void CegoDatabaseManager::CopyRecord::setId(int id)
+void CegoDatabaseManager::CopyRecord::setId(unsigned id)
 {
     _id = id;
 }
@@ -374,7 +374,7 @@ CegoDatabaseManager::CegoDatabaseManager(const Chain& xmlDef, const Chain& lckFi
     }
 
     dbmLock.init(LCKMNG_LOCKWAITDELAY, __lockStatOn);  
-    for ( int i=0; i<TABMNG_MAXTABSET; i++)
+    for ( unsigned i=0; i<TABMNG_MAXTABSET; i++)
     {
 	_recoveryMode[i] = OFF;
 	_pQueryCache[i] = 0;
@@ -392,7 +392,7 @@ CegoDatabaseManager::~CegoDatabaseManager()
     File lckFile(_lckFileName);
     lckFile.remove();
 
-    for ( int i=0; i<TABMNG_MAXTABSET; i++)
+    for ( unsigned i=0; i<TABMNG_MAXTABSET; i++)
     {
 	if ( _pQueryCache[i] )
 	    delete _pQueryCache[i];
@@ -405,14 +405,14 @@ void CegoDatabaseManager::allocateQueryCache(const Chain& tableSet)
 {
     if ( getQueryCacheMode(tableSet) )
     {	
-	int maxEntry = getMaxQueryCacheEntry(tableSet);
-	int maxSize = getMaxQueryCacheSize(tableSet);
-	int threshold = getQueryCacheThreshold(tableSet);
-	int hashRange = getQueryCacheHashRange(tableSet);
+	unsigned maxEntry = getMaxQueryCacheEntry(tableSet);
+	unsigned maxSize = getMaxQueryCacheSize(tableSet);
+	unsigned threshold = getQueryCacheThreshold(tableSet);
+	unsigned hashRange = getQueryCacheHashRange(tableSet);
 
 	if ( maxEntry > 0 && maxSize > 0 && hashRange > 0)
 	{
-	    int tabSetId = getTabSetId(tableSet);
+	    unsigned tabSetId = getTabSetId(tableSet);
 	    
 	    if ( _pQueryCache[tabSetId] )
 		delete _pQueryCache[tabSetId];
@@ -431,13 +431,13 @@ void CegoDatabaseManager::allocateTableCache(const Chain& tableSet)
     if ( getTableCacheMode(tableSet) )
     {
 	Chain cacheFilter = getTableCacheFilter(tableSet);
-	int maxSize = getTableCacheMaxSize(tableSet);
-	int maxEntry = getTableCacheMaxEntry(tableSet);
-	int hashRange = getTableCacheHashRange(tableSet);
+	unsigned maxSize = getTableCacheMaxSize(tableSet);
+	unsigned maxEntry = getTableCacheMaxEntry(tableSet);
+	unsigned hashRange = getTableCacheHashRange(tableSet);
 	
 	if (  maxSize > 0 && maxEntry > 0 && hashRange > 0 )
 	{
-	    int tabSetId = getTabSetId(tableSet);
+	    unsigned tabSetId = getTabSetId(tableSet);
 	    
 	    if ( _pTableCache[tabSetId] )
 		delete _pTableCache[tabSetId];
@@ -452,7 +452,7 @@ void CegoDatabaseManager::allocateTableCache(const Chain& tableSet)
 
 void CegoDatabaseManager::releaseQueryCache(const Chain& tableSet)
 {
-    int tabSetId = getTabSetId(tableSet);
+    unsigned tabSetId = getTabSetId(tableSet);
     
     if ( _pQueryCache[tabSetId] )
     {
@@ -463,7 +463,7 @@ void CegoDatabaseManager::releaseQueryCache(const Chain& tableSet)
 
 void CegoDatabaseManager::releaseTableCache(const Chain& tableSet)
 {
-    int tabSetId = getTabSetId(tableSet);
+    unsigned tabSetId = getTabSetId(tableSet);
     
     if ( _pTableCache[tabSetId] )
     {
@@ -472,7 +472,7 @@ void CegoDatabaseManager::releaseTableCache(const Chain& tableSet)
     }
 }
 
-void CegoDatabaseManager::cleanCache(int tabSetId, CegoObject::ObjectType objType, const Chain& objName)
+void CegoDatabaseManager::cleanCache(unsigned tabSetId, CegoObject::ObjectType objType, const Chain& objName)
 {
     if ( _pQueryCache[tabSetId] )
     {
@@ -487,22 +487,22 @@ void CegoDatabaseManager::cleanCache(int tabSetId, CegoObject::ObjectType objTyp
 
 CegoQueryCache* CegoDatabaseManager::getQueryCache(const Chain& tableSet) const
 {
-    int tabSetId = getTabSetId(tableSet);
+    unsigned tabSetId = getTabSetId(tableSet);
     return _pQueryCache[tabSetId];
 }
 
-CegoQueryCache* CegoDatabaseManager::getQueryCache(int tabSetId) const
+CegoQueryCache* CegoDatabaseManager::getQueryCache(unsigned tabSetId) const
 {
     return _pQueryCache[tabSetId];
 }
 
 CegoTableCache* CegoDatabaseManager::getTableCache(const Chain& tableSet) const
 {
-    int tabSetId = getTabSetId(tableSet);
+    unsigned tabSetId = getTabSetId(tableSet);
     return _pTableCache[tabSetId];
 }
 
-CegoTableCache* CegoDatabaseManager::getTableCache(int tabSetId) const
+CegoTableCache* CegoDatabaseManager::getTableCache(unsigned tabSetId) const
 {
     return _pTableCache[tabSetId];
 }
@@ -516,7 +516,7 @@ void CegoDatabaseManager::beat()
     lckFile.close();    
 }
 
-void CegoDatabaseManager::checkTableSetRunState(int tabSetId)
+void CegoDatabaseManager::checkTableSetRunState(unsigned tabSetId)
 {
     Chain runState = getTableSetRunState(tabSetId);
 
@@ -552,19 +552,19 @@ bool CegoDatabaseManager::isLoggerConfigured()
     return _logConfigured;
 }
 
-CegoDatabaseManager::RecoveryMode CegoDatabaseManager::getRecoveryMode(int tabSetId)
+CegoDatabaseManager::RecoveryMode CegoDatabaseManager::getRecoveryMode(unsigned tabSetId)
 {
     return _recoveryMode[tabSetId];
 }
 
-void CegoDatabaseManager::setRecoveryMode(int tabSetId, CegoDatabaseManager::RecoveryMode m)
+void CegoDatabaseManager::setRecoveryMode(unsigned tabSetId, CegoDatabaseManager::RecoveryMode m)
 {
     _recoveryMode[tabSetId] = m;
 }
 
 void CegoDatabaseManager::setAllRecoveryOff()
 {    
-    for ( int i=0; i<TABMNG_MAXTABSET; i++)
+    for ( unsigned i=0; i<TABMNG_MAXTABSET; i++)
     {
 	_recoveryMode[i] = OFF;
     }
@@ -599,7 +599,7 @@ bool CegoDatabaseManager::nextRecovery(Chain& tableSet)
     return false;
 }
 
-bool CegoDatabaseManager::nextCopy(int& id, Chain& tableSet, Chain& targetHost, Chain& mediatorHost, Chain& user, Chain& passwd)
+bool CegoDatabaseManager::nextCopy(unsigned& id, Chain& tableSet, Chain& targetHost, Chain& mediatorHost, Chain& user, Chain& passwd)
 {
     PW();
     CopyRecord *pCR = _copyList.First();
@@ -626,7 +626,7 @@ bool CegoDatabaseManager::nextCopy(int& id, Chain& tableSet, Chain& targetHost,
     return false;
 }
 
-void CegoDatabaseManager::setCopyStatus(int id, const Chain& msg)
+void CegoDatabaseManager::setCopyStatus(unsigned id, const Chain& msg)
 {
     PW();
     CopyRecord *pCR = _copyList.First();
@@ -670,7 +670,7 @@ Element* CegoDatabaseManager::getCopyInfo()
     return pCopyInfo;
 }
 
-void CegoDatabaseManager::useObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type, ObjectUseMode mode, CegoTableManager *pTabMng)
+void CegoDatabaseManager::useObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type, ObjectUseMode mode, CegoTableManager *pTabMng)
 {
     // In SHARED mode, an object can be use in parallel by several threads. Normally, this is done, if the object is accessed read only.
 
@@ -705,7 +705,7 @@ void CegoDatabaseManager::useObject(int tabSetId, const Chain& objName, CegoObje
 	}
 	else
 	{
-	    int numTries=0;
+	    unsigned numTries=0;
 
 	    while ( pOR && pOR->getMode() == EXCLUSIVE_WRITE && numTries < DBM_MAXLOCKTRIES )
 	    {
@@ -721,10 +721,10 @@ void CegoDatabaseManager::useObject(int tabSetId, const Chain& objName, CegoObje
 		    checkTableSetRunState(tabSetId);
 		    		    
 		    Sleeper ns;
-		    int sec = DBM_LOCKDELAY / 1000;
+		    unsigned sec = DBM_LOCKDELAY / 1000;
 		    if ( sec > 0 )
 			ns.secSleep(sec);
-		    int msec = DBM_LOCKDELAY % 1000;
+		    unsigned msec = DBM_LOCKDELAY % 1000;
 		    if ( msec > 0 )
 			ns.milliSleep(msec);
 		}
@@ -781,7 +781,7 @@ void CegoDatabaseManager::useObject(int tabSetId, const Chain& objName, CegoObje
 	    }
 	    else
 	    {	    
-		int numTries=0;
+		unsigned numTries=0;
 		while ( pOR && pOR->numUsed() != 0 && numTries < DBM_MAXLOCKTRIES )
 		{
 		    V();
@@ -796,10 +796,10 @@ void CegoDatabaseManager::useObject(int tabSetId, const Chain& objName, CegoObje
 			checkTableSetRunState(tabSetId);
 			
 			Sleeper ns;			
-			int sec = DBM_LOCKDELAY / 1000;
+			unsigned sec = DBM_LOCKDELAY / 1000;
 			if ( sec > 0 )
 			    ns.secSleep(sec);
-			int msec = DBM_LOCKDELAY % 1000;
+			unsigned msec = DBM_LOCKDELAY % 1000;
 			if ( msec > 0 )
 			    ns.milliSleep(msec);
 		    }
@@ -834,7 +834,7 @@ void CegoDatabaseManager::useObject(int tabSetId, const Chain& objName, CegoObje
     return;
 }
 
-void CegoDatabaseManager::unuseObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type, unsigned long long tid )
+void CegoDatabaseManager::unuseObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type, unsigned long long tid )
 {        
     // we fist check, if corresponding tableset is really not offline 
     checkTableSetRunState(tabSetId);
@@ -871,21 +871,21 @@ void CegoDatabaseManager::unuseObject(int tabSetId, const Chain& objName, CegoOb
     V();    
 }
 
-void CegoDatabaseManager::addObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+void CegoDatabaseManager::addObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {
     PW();
     _objList.Insert(ObjectRecord(tabSetId, objName, type));
     V();
 }
 
-void CegoDatabaseManager::removeObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+void CegoDatabaseManager::removeObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {
     PW();
     _objList.Remove(ObjectRecord(tabSetId, objName, type));
     V();
 }
 
-void CegoDatabaseManager::removeAllObjects(int tabSetId) 
+void CegoDatabaseManager::removeAllObjects(unsigned tabSetId) 
 { 
     PW(); 
     ObjectRecord *pOR = _objList.First(); 
@@ -904,7 +904,7 @@ void CegoDatabaseManager::removeAllObjects(int tabSetId)
     V(); 
 } 
 
-bool CegoDatabaseManager::objectExists(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+bool CegoDatabaseManager::objectExists(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {
     // we fist check, if corresponding tableset is really not offline
     checkTableSetRunState(tabSetId);
@@ -934,7 +934,7 @@ void CegoDatabaseManager::printObjectList()
     V();
 }
 
-void CegoDatabaseManager::setThreadInfo(int numDbThread, int numAdmThread, int numLogThread)
+void CegoDatabaseManager::setThreadInfo(unsigned numDbThread, unsigned numAdmThread, unsigned numLogThread)
 {
     _numDbThread = numDbThread;
     _numAdmThread = numAdmThread;
@@ -944,8 +944,8 @@ void CegoDatabaseManager::setThreadInfo(int numDbThread, int numAdmThread, int n
     _activeLogThread = 0;
 }
     
-void CegoDatabaseManager::getThreadInfo(int& numDbThread, int& numAdmThread, int& numLogThread,
-		   int& activeDbThread, int& activeAdmThread, int& activeLogThread)
+void CegoDatabaseManager::getThreadInfo(unsigned& numDbThread, unsigned& numAdmThread, unsigned& numLogThread,
+		   unsigned& activeDbThread, unsigned& activeAdmThread, unsigned& activeLogThread)
 {
     numDbThread = _numDbThread;
     numAdmThread = _numAdmThread;
@@ -985,7 +985,7 @@ void CegoDatabaseManager::decreaseActiveLogThread()
     _activeLogThread--;
 }
 
-void CegoDatabaseManager::getDBMLockStat(Chain& lockName, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+void CegoDatabaseManager::getDBMLockStat(Chain& lockName, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     lockName = dbmLock.getId();
     lockCount= dbmLock.numLockTry();
@@ -1066,7 +1066,7 @@ void CegoDatabaseManager::releaseSession(CegoDistDbHandler* pHandler)
     throw Exception(EXLOC, msg);
 }
 
-void CegoDatabaseManager::cleanSession(int lifetime)
+void CegoDatabaseManager::cleanSession(unsigned lifetime)
 {
     PW();
     
@@ -1090,7 +1090,7 @@ void CegoDatabaseManager::cleanSession(int lifetime)
     V();   
 }
 
-Element* CegoDatabaseManager::getSessionInfo(int lifetime)
+Element* CegoDatabaseManager::getSessionInfo(unsigned lifetime)
 {
     Element* pSessionInfo = new Element(XML_DBSESSIONINFO_ELEMENT);
     
@@ -1119,7 +1119,7 @@ Element* CegoDatabaseManager::getSessionInfo(int lifetime)
 CegoDistDbHandler* CegoDatabaseManager::createSession(const Chain& hostName, const Chain& tableSet,
 						  const Chain& userName, const Chain& password)
 {
-    int portNo;
+    unsigned portNo;
     getDataPort(portNo);
     
     Net n( NETMNG_MSG_BUFLEN, NETMNG_SIZEBUFLEN, getMaxSendLen() );
@@ -1176,7 +1176,7 @@ void CegoDatabaseManager::closeSession(CegoDistDbHandler* pSH)
 
 void CegoDatabaseManager::configureLogger(Logger::LogLevel level)
 {
-    for ( int i=1; i< getMapSize() ; i++)
+    for ( unsigned i=1; i< getMapSize() ; i++)
     {
 	logModule(i, getModName(i), level);
     }
@@ -1194,7 +1194,7 @@ void CegoDatabaseManager::configureLogger()
 	if ( (Chain)pMod->toUpper() == Chain("ALL"))
 	{
 	    Logger::LogLevel level = getLogLevel(*pMod);
-	    for ( int i=1; i< getMapSize() ; i++)
+	    for ( unsigned i=1; i< getMapSize() ; i++)
 	    {
 		logModule(i, getModName(i), level);
 	    }
@@ -1215,7 +1215,7 @@ bool CegoDatabaseManager::verifyJDBC(const Chain& user)
     return roleSet.Find(Chain(ROLE_JDBC));
 }
 
-bool CegoDatabaseManager::verifyAccess(const int tabSetId, const Chain& objName, CegoObject::ObjectType type, CegoXMLSpace::AccessMode mode, const Chain& user)
+bool CegoDatabaseManager::verifyAccess(const unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type, CegoXMLSpace::AccessMode mode, const Chain& user)
 {
     SetT<Chain> roleSet;
 
@@ -1237,14 +1237,14 @@ bool CegoDatabaseManager::verifyAccess(const int tabSetId, const Chain& objName,
 void CegoDatabaseManager::initLogFiles(const Chain& tableSet, bool overwrite)
 {
     ListT<Chain> lfList;
-    ListT<int> sizeList;
+    ListT<unsigned> sizeList;
     ListT<Chain> statusList;
     
-    int tabSetId = getTabSetId(tableSet);
+    unsigned tabSetId = getTabSetId(tableSet);
     getLogFileInfo(tableSet, lfList, sizeList, statusList);
 
     Chain *pLog = lfList.First();
-    int *pSize = sizeList.First();
+    unsigned *pSize = sizeList.First();
 
     bool isFirst = true;
     while ( pLog ) 
@@ -1279,10 +1279,10 @@ void CegoDatabaseManager::initLogFiles(const Chain& tableSet, bool overwrite)
 void CegoDatabaseManager::releaseLogFiles(const Chain& tableSet, bool waitForArch)
 {
     ListT<Chain> lfList;
-    ListT<int> sizeList;
+    ListT<unsigned> sizeList;
     ListT<Chain> statusList;
     
-    int tabSetId = getTabSetId(tableSet);
+    unsigned tabSetId = getTabSetId(tableSet);
     getLogFileInfo(tableSet, lfList, sizeList, statusList);
 
     Chain *pLog = lfList.First(); 
@@ -1313,7 +1313,7 @@ void CegoDatabaseManager::releaseLogFiles(const Chain& tableSet, bool waitForArc
 	    log(_modId, Logger::NOTICE, Chain("Waiting for archive ... "));	    
 
 	    ListT<Chain> lfList;
-	    ListT<int> sizeList;
+	    ListT<unsigned> sizeList;
 	    ListT<Chain> statusList;
 	
 	    getLogFileInfo(tableSet, lfList, sizeList, statusList);
@@ -1345,7 +1345,7 @@ CegoDbHandler::ProtocolType CegoDatabaseManager::getProtType() const
     return _protType;
 }
 
-bool CegoDatabaseManager::getQCLockStat(int tabSetId, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+bool CegoDatabaseManager::getQCLockStat(unsigned tabSetId, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     if ( _pQueryCache[tabSetId] )
     {
@@ -1355,7 +1355,7 @@ bool CegoDatabaseManager::getQCLockStat(int tabSetId, int& lockCount, unsigned l
     return false;
 }
 
-void CegoDatabaseManager::getAggQCLockStat(Chain& lockGroup, int& numLock, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+void CegoDatabaseManager::getAggQCLockStat(Chain& lockGroup, unsigned& numLock, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     lockGroup = Chain("QCLCK");
     
@@ -1366,11 +1366,11 @@ void CegoDatabaseManager::getAggQCLockStat(Chain& lockGroup, int& numLock, int&
     sumWrDelay = 0;
     numLock = 0;
    
-    for ( int i=0; i<TABMNG_MAXTABSET; i++)
+    for ( unsigned i=0; i<TABMNG_MAXTABSET; i++)
     {
 	if ( _pQueryCache[i] )
 	{
-	    int qcLockCount;
+	    unsigned qcLockCount;
 	    unsigned long long qcNumRdLock;
 	    unsigned long long qcNumWrLock;
 	    unsigned long long qcSumRdDelay;
@@ -1390,7 +1390,7 @@ void CegoDatabaseManager::getAggQCLockStat(Chain& lockGroup, int& numLock, int&
     }
 }
 
-bool CegoDatabaseManager::getTCLockStat(int tabSetId, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+bool CegoDatabaseManager::getTCLockStat(unsigned tabSetId, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     if ( _pTableCache[tabSetId] )
     {
@@ -1400,7 +1400,7 @@ bool CegoDatabaseManager::getTCLockStat(int tabSetId, int& lockCount, unsigned l
     return false;
 }
 
-void CegoDatabaseManager::getAggTCLockStat(Chain& lockGroup, int& numLock, int& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
+void CegoDatabaseManager::getAggTCLockStat(Chain& lockGroup, unsigned& numLock, unsigned& lockCount, unsigned long long &numRdLock, unsigned long long &numWrLock, unsigned long long &sumRdDelay, unsigned long long &sumWrDelay)
 {
     lockGroup = Chain("TCLCK");
     
@@ -1411,11 +1411,11 @@ void CegoDatabaseManager::getAggTCLockStat(Chain& lockGroup, int& numLock, int&
     sumWrDelay = 0;
     numLock = 0;
 
-    for ( int i=0; i<TABMNG_MAXTABSET; i++)
+    for ( unsigned i=0; i<TABMNG_MAXTABSET; i++)
     {
 	if ( _pTableCache[i] )
 	{
-	    int qcLockCount;
+	    unsigned qcLockCount;
 	    unsigned long long qcNumRdLock;
 	    unsigned long long qcNumWrLock;
 	    unsigned long long qcSumRdDelay;
