@@ -379,6 +379,10 @@ void CegoDbThread::invalidateObject(unsigned tabSetId, const Chain& objName, Ceg
     {
 	_pTabMng->removeCompProcedure(tabSetId, objName);
     }
+    else if ( type == CegoObject::TRIGGER )
+    {
+	_pTabMng->removeCompTrigger(tabSetId, objName);
+    }    
     else
     {
 	throw Exception(EXLOC, "Unknown object type for invalidation");	    
