@@ -47,7 +47,7 @@ public:
     public:
        
 	QueryEntry() {}
-	QueryEntry(int idx, unsigned long qid, unsigned long long ts, const Chain& query, unsigned long long cost)
+	QueryEntry(unsigned idx, unsigned long qid, unsigned long long ts, const Chain& query, unsigned long long cost)
 	{
 	    _idx = idx;
 	    _qid = qid;
@@ -211,7 +211,7 @@ public:
 
 	enum QueryOrder { LAST, REVLAST, COST, REVCOST };
 	
-	int _idx;
+	unsigned _idx;
 	unsigned long long _qid;
 	unsigned long long _ts;
 	Chain _query;
@@ -235,13 +235,13 @@ public:
 
     void abortSession();
 
-    void loadObjects(int tabSetId);
-    void unloadObjects(int tabSetId);
-    void invalidateObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type);
-    void addReloadRequest(int tabSetId);
+    void loadObjects(unsigned tabSetId);
+    void unloadObjects(unsigned tabSetId);
+    void invalidateObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type);
+    void addReloadRequest(unsigned tabSetId);
     void checkReloadRequest();
 
-    int getErrorCode() const;
+    unsigned getErrorCode() const;
     
 private:
 
@@ -269,15 +269,15 @@ private:
     
     unsigned long long _qid;
     
-    ListT<int> _loadList;
+    ListT<unsigned> _loadList;
 
-    int _errorCode;
+    unsigned _errorCode;
 
     NanoTimer* _pTim;
     NanoTimer* _pCost;
 
-    int _numLast;
-    int _numCost;
+    unsigned _numLast;
+    unsigned _numCost;
 
     Chain _lastAction;
     unsigned long _modId;
