@@ -22,10 +22,6 @@
 
 #include <config.h>
 
-#ifdef HAVE_MINGW32
-#include <windows.h>
-#endif
-
 #define CEGO_PRODUCT PACKAGE_NAME
 #define CEGO_VERSION PACKAGE_VERSION
 #define CEGO_COPYRIGHT "Copyright (C) 2000-2025 by Bjoern Lemke. All rights reserved"
