@@ -118,7 +118,7 @@ void CegoDistManager::createTableSet(const Chain& tableSet)
     startTableSet(tableSet, dbHost, false, false, false, false);
     
     _pDBMng->log(_modId, Logger::NOTICE, Chain("Creating system space ..."));
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
     createSystemSpace(tabSetId);
 
     stopTableSet(tableSet, false);    
@@ -131,7 +131,7 @@ void CegoDistManager::startDistTableSet(const Chain& tableSet, const Chain& seco
 
 void CegoDistManager::registerObjects(const Chain& tableSet)
 {
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
     
     ListT<Chain> tabList;
     getObjectList(tabSetId, CegoObject::TABLE, tabList);
@@ -245,7 +245,7 @@ void CegoDistManager::registerObjects(const Chain& tableSet)
 
 void CegoDistManager::stopDistTableSet(const Chain& tableSet, bool archComplete)
 {    
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
     
     _pDBMng->removeAllObjects(tabSetId);
     _pDBMng->releaseTableCache(tableSet);
@@ -273,7 +273,7 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
     if ( tsTicket.exists()) 
 	throw Exception(EXLOC, Chain("Backup tableset ticket exists"));
     
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
     regDataFiles(tableSet);
     
     Chain dbHost;
@@ -281,7 +281,7 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
     
     if ( secondary != dbHost )
     {
-	int logPort;
+	unsigned logPort;
 	_pDBMng->getLogPort(logPort);
 
 	Chain logUser = _pDBMng->getTSLogUser(tableSet);
@@ -380,7 +380,7 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
 		if ( isAutoCorrect )
 		{
 		    _pDBMng->log(_modId, Logger::NOTICE, Chain("Perform autocorrect for tableset ") + tableSet + Chain(" ..."));		    
-		    int tabSetId = _pDBMng->getTabSetId(tableSet);
+		    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 		    correctTableSet(tabSetId, false);
 		}
 	    }
@@ -412,7 +412,7 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
 	if ( cleanIt )
 	{
 	    _pDBMng->log(_modId, Logger::NOTICE, Chain("Cleaning tableset ") + tableSet + Chain(" ..."));
-	    int cleanCount = cleanTableSet(tabSetId);
+	    unsigned cleanCount = cleanTableSet(tabSetId);
 	    _pDBMng->log(_modId, Logger::NOTICE, Chain(cleanCount) + Chain(" pages cleaned"));
 	}
 	
@@ -430,7 +430,7 @@ void CegoDistManager::startTableSet(const Chain& tableSet, const Chain& secondar
 
 bool CegoDistManager::distObjectExists(const Chain& tableSet, const Chain& objName, CegoObject::ObjectType objType)
 {
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     Chain hostName = _pDBMng->getPrimary(tabSetId);
     
@@ -466,7 +466,7 @@ bool CegoDistManager::distObjectExists(const Chain& tableSet, const Chain& objNa
 
 void CegoDistManager::getDistObject(const Chain& tableSet, const Chain& objName, CegoObject::ObjectType type, CegoDecodableObject& oe)
 {
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, objName, type, CegoXMLSpace::READ, _authUser) == false )
     {
@@ -518,7 +518,7 @@ void CegoDistManager::getDistObject(const Chain& tableSet, const Chain& objName,
     }
 }
 
-void CegoDistManager::getLocalObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type, CegoDecodableObject& oe)
+void CegoDistManager::getLocalObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type, CegoDecodableObject& oe)
 {
     getObject(tabSetId, objName, type, oe);
 }
@@ -529,7 +529,7 @@ void CegoDistManager::truncateDistTable(const Chain& tableName, const Chain& tab
     _pDBMng->log(_modId, Logger::DEBUG, Chain("Truncating table ") + tableName);
 #endif
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
     
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, tableName, CegoObject::TABLE, CegoXMLSpace::MODIFY, _authUser) == false )
     {
@@ -581,7 +581,7 @@ void CegoDistManager::dropDistObject(const Chain& objName, const Chain& tableSet
     _pDBMng->log(_modId, Logger::DEBUG, Chain("Dropping object ") + objName);
 #endif
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, objName, type, CegoXMLSpace::MODIFY, _authUser) == false )
     {
@@ -637,7 +637,7 @@ void CegoDistManager::createDistDataTable(const Chain& tableSet, const Chain& ta
 #endif
 
     Chain hostName = _pDBMng->getPrimary(tableSet);
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, tableName, type, CegoXMLSpace::MODIFY, _authUser) == false )
     {
@@ -677,7 +677,7 @@ void CegoDistManager::createDistDataTable(const Chain& tableSet, const Chain& ta
     }
 }
 
-void CegoDistManager::createLocalDataTable(int tabSetId, const Chain& tableName, CegoObject::ObjectType type, ListT<CegoField>& fldList, ListT<CegoField>& idxList, bool useColumnId)
+void CegoDistManager::createLocalDataTable(unsigned tabSetId, const Chain& tableName, CegoObject::ObjectType type, ListT<CegoField>& fldList, ListT<CegoField>& idxList, bool useColumnId)
 {    
     createDataTable(tabSetId, tableName, type, fldList, useColumnId);
     _pDBMng->addObject(tabSetId, tableName, CegoObject::TABLE);
@@ -706,7 +706,7 @@ void CegoDistManager::createDistIndexTable( const Chain& tableSet, const Chain&
     _pDBMng->log(_modId, Logger::DEBUG, Chain("Creating global index ") + indexName + Chain(" in tableset ") + tableSet);
 #endif
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, indexName, CegoObject::AVLTREE, CegoXMLSpace::MODIFY, _authUser) == false )
     {
@@ -744,7 +744,7 @@ void CegoDistManager::createDistForeignKey( const Chain& tableSet, const Chain&
 #endif
 
     Chain hostName = _pDBMng->getPrimary(tableSet);
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, tableName, CegoObject::TABLE, CegoXMLSpace::MODIFY, _authUser) == false )
     {
@@ -773,7 +773,7 @@ void CegoDistManager::createDistForeignKey( const Chain& tableSet, const Chain&
     }
 }
 
-void CegoDistManager::createLocalForeignKey(int tabSetId, const Chain& fkey, const Chain& tableName, const ListT<CegoField>& keyList, const Chain& refTable, const ListT<CegoField>& refList)
+void CegoDistManager::createLocalForeignKey(unsigned tabSetId, const Chain& fkey, const Chain& tableName, const ListT<CegoField>& keyList, const Chain& refTable, const ListT<CegoField>& refList)
 {
     createForeignKey(tabSetId, fkey, tableName, keyList, refTable, refList);
 
@@ -787,7 +787,7 @@ void CegoDistManager::createDistCheck( const Chain& tableSet, const Chain& check
 #endif
     
     Chain hostName = _pDBMng->getPrimary(tableSet);
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, tableName, CegoObject::TABLE, CegoXMLSpace::MODIFY, _authUser) == false )
     {
@@ -817,7 +817,7 @@ void CegoDistManager::createDistCheck( const Chain& tableSet, const Chain& check
     }    
 }
 
-void CegoDistManager::createLocalCheck(int tabSetId, const Chain& checkName, const Chain& tableName, CegoPredicate *pPredDesc)
+void CegoDistManager::createLocalCheck(unsigned tabSetId, const Chain& checkName, const Chain& tableName, CegoPredicate *pPredDesc)
 {
     createCheck(tabSetId, checkName, tableName, pPredDesc);    
     _pDBMng->addObject(tabSetId, checkName, CegoObject::CHECK);
@@ -830,7 +830,7 @@ void CegoDistManager::reorgDistObject(const Chain& tableSet, const Chain& objNam
 #endif
 
     Chain hostName = _pDBMng->getPrimary(tableSet);
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, objName, type, CegoXMLSpace::MODIFY, _authUser) == false )
     {
@@ -877,7 +877,7 @@ void CegoDistManager::startDistTransaction( const Chain& tableSet)
 #endif
 
     Chain hostName = _pDBMng->getPrimary(tableSet);
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     Chain dbHost;
     _pDBMng->getDBHost(dbHost);
@@ -918,7 +918,7 @@ long CegoDistManager::endDistTransaction( const Chain& tableSet)
 #endif
 
     Chain hostName = _pDBMng->getPrimary(tableSet);
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     Chain dbHost;
     _pDBMng->getDBHost(dbHost);
@@ -964,7 +964,7 @@ long CegoDistManager::rollbackDistTransaction(const Chain& tableSet)
 #endif
 
     Chain hostName = _pDBMng->getPrimary(tableSet);
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     Chain dbHost;
     _pDBMng->getDBHost(dbHost);
@@ -1003,10 +1003,10 @@ long CegoDistManager::rollbackDistTransaction(const Chain& tableSet)
     }
 }
 
-int CegoDistManager::getDistTid( const Chain& tableSet)
+unsigned long long CegoDistManager::getDistTid( const Chain& tableSet)
 {
     Chain hostName = _pDBMng->getPrimary(tableSet);
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     Chain dbHost;
     _pDBMng->getDBHost(dbHost);
@@ -1027,7 +1027,8 @@ int CegoDistManager::getDistTid( const Chain& tableSet)
 	Chain msg;
 	CegoDbHandler::ResultType res;
     
-	int tid = 0;
+	unsigned long long tid = 0;
+	
 	res = pSH->reqGetTidOp(tableSet);
 	
 	if ( res == CegoDbHandler::DB_INFO )
@@ -1035,7 +1036,7 @@ int CegoDistManager::getDistTid( const Chain& tableSet)
 	    Chain tidString;
 	    pSH->getArgValue(XML_TID_ATTR, tidString);
 	    
-	    tid = tidString.asInteger();
+	    tid = tidString.asUnsignedLongLong();
 
 	    _pDBMng->releaseSession(pSH);	    
 	    
@@ -1050,7 +1051,7 @@ int CegoDistManager::getDistTid( const Chain& tableSet)
     }
 }
 
-int CegoDistManager::getLocalTid(int tabSetId)
+unsigned long long CegoDistManager::getLocalTid(unsigned tabSetId)
 {
     return getTID(tabSetId);
 }
@@ -1126,7 +1127,7 @@ void CegoDistManager::insertLocalDataTable(CegoTableObject& oe, ListT<CegoField>
 	ListT<CegoCheckObject> checkList;
 	ListT<CegoTriggerObject> triggerList;
 	ListT<CegoAliasObject> aliasList;
-	int numInvalid;
+	unsigned numInvalid;
 	
 	bool doAppend;
 	bool doLogging = true;
@@ -1243,7 +1244,7 @@ void CegoDistManager::insertLocalDataTable(CegoTableObject& oe, ListT< ListT<Ceg
 	ListT<CegoCheckObject> checkList;
 	ListT<CegoTriggerObject> triggerList;
 	ListT<CegoAliasObject> aliasList;
-	int numInvalid;
+	unsigned numInvalid;
 	
 	bool doAppend;
 	bool doLogging = true;
@@ -1264,8 +1265,8 @@ void CegoDistManager::insertLocalDataTable(CegoTableObject& oe, ListT< ListT<Ceg
 	}
 
 	ListT<CegoField> *pFVL = fva.First();
-	int numEntry = fva.Size();
-	int entryCount=0;
+	unsigned numEntry = fva.Size();
+	unsigned entryCount=0;
 	
 	while ( pFVL )
 	{
@@ -1373,7 +1374,7 @@ unsigned long long CegoDistManager::deleteLocalDataTable(CegoTableObject& oe, Ce
 	ListT<CegoCheckObject> checkList;
 	ListT<CegoTriggerObject> triggerList;
 	ListT<CegoAliasObject> aliasList;
-	int numInvalid;
+        unsigned numInvalid;
 	
 	getObjectListByTable(oe.getTabSetId(), oe.getTabName(), idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
 	
@@ -1525,7 +1526,7 @@ unsigned long long CegoDistManager::updateLocalDataTable(CegoTableObject& oe,
 	ListT<CegoCheckObject> checkList;
 	ListT<CegoTriggerObject> triggerList;
 	ListT<CegoAliasObject> aliasList;
-	int numInvalid;
+	unsigned numInvalid;
 	
 	getObjectListByTable(oe.getTabSetId(), oe.getTabName(), idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
 	if ( numInvalid > 0 )
@@ -1672,7 +1673,7 @@ void CegoDistManager::renameDistObject(const Chain& tableSet, const Chain& objNa
     _pDBMng->log(_modId, Logger::DEBUG, Chain("Renaming global table ") + objName);
 #endif
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, objName, type, CegoXMLSpace::MODIFY, _authUser) == false )
     {
@@ -1703,7 +1704,7 @@ void CegoDistManager::renameDistObject(const Chain& tableSet, const Chain& objNa
     }
 }
 
-void CegoDistManager::renameLocalObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type,  const Chain& newObjName)
+void CegoDistManager::renameLocalObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type,  const Chain& newObjName)
 {
     if ( objectExists(tabSetId, newObjName, type) )
     {
@@ -1722,7 +1723,7 @@ void CegoDistManager::createDistView(const Chain& tableSet, const Chain& viewNam
     _pDBMng->log(_modId, Logger::DEBUG, Chain("Creating global view ") + viewName + Chain(" in tableset ") + tableSet);
 #endif
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, viewName, CegoObject::VIEW, CegoXMLSpace::MODIFY, _authUser) == false )
     {
@@ -1753,7 +1754,7 @@ void CegoDistManager::createDistView(const Chain& tableSet, const Chain& viewNam
     }
 }
 
-void CegoDistManager::createLocalView( int tabSetId, const Chain& viewName, const ListT<CegoField>& schema, const Chain& viewText)
+void CegoDistManager::createLocalView(unsigned tabSetId, const Chain& viewName, const ListT<CegoField>& schema, const Chain& viewText)
 {
     CegoViewObject vo( tabSetId, viewName, schema, viewText);
 
@@ -1786,7 +1787,7 @@ void CegoDistManager::createDistTrigger(const Chain& tableSet, const Chain& trig
     _pDBMng->log(_modId, Logger::DEBUG, Chain("Creating global trigger ") + triggerName + Chain(" in tableset ") + tableSet);
 #endif
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, triggerName, CegoObject::TRIGGER, CegoXMLSpace::MODIFY, _authUser) == false )
     {
@@ -1818,7 +1819,7 @@ void CegoDistManager::createDistTrigger(const Chain& tableSet, const Chain& trig
     }
 }
 
-void CegoDistManager::createLocalTrigger(int tabSetId, const Chain& triggerName,
+void CegoDistManager::createLocalTrigger(unsigned tabSetId, const Chain& triggerName,
 					 bool isBefore, bool isOnInsert, bool isOnUpdate, bool isOnDelete,
 					 const Chain& tableName, const Chain& triggerText)
 {
@@ -1835,7 +1836,7 @@ void CegoDistManager::createDistAlias(const Chain& tableSet, const Chain& aliasN
     _pDBMng->log(_modId, Logger::DEBUG, Chain("Creating global alias ") + aliasName + Chain(" in tableset ") + tableSet);
 #endif
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, aliasName, CegoObject::ALIAS, CegoXMLSpace::MODIFY, _authUser) == false )
     {
@@ -1867,7 +1868,7 @@ void CegoDistManager::createDistAlias(const Chain& tableSet, const Chain& aliasN
     }
 }
 
-void CegoDistManager::createLocalAlias(int tabSetId, const Chain& aliasName,
+void CegoDistManager::createLocalAlias(unsigned tabSetId, const Chain& aliasName,
 					 const Chain& tableName, const ListT<CegoAttrAlias>& aliasList)
 {
     createAlias(tabSetId, aliasName, tableName, aliasList);    
@@ -1880,7 +1881,7 @@ void CegoDistManager::createDistProc(const Chain& tableSet, const Chain& procNam
     _pDBMng->log(_modId, Logger::DEBUG, Chain("Creating global procedure ") + procName + Chain(" in tableset ") + tableSet);
 #endif
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     if ( _authEnabled == true && _pDBMng->verifyAccess(tabSetId, procName, CegoObject::PROCEDURE, CegoXMLSpace::MODIFY, _authUser) == false )
     {
@@ -1911,7 +1912,7 @@ void CegoDistManager::createDistProc(const Chain& tableSet, const Chain& procNam
     }
 }
 
-void CegoDistManager::createLocalProc(int tabSetId, const Chain& procName, const Chain& procText)
+void CegoDistManager::createLocalProc(unsigned tabSetId, const Chain& procName, const Chain& procText)
 {
     CegoProcObject po(tabSetId, procName, procText);
 
@@ -1943,7 +1944,7 @@ void CegoDistManager::getDistObjectList(const Chain& tableSet, CegoObject::Objec
     _pDBMng->log(_modId, Logger::DEBUG, Chain("Getting global object list in tableset ") + tableSet);
 #endif
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);    
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);    
     Chain hostName = _pDBMng->getPrimary(tabSetId);
 
     Chain dbHost;
@@ -1980,7 +1981,7 @@ void CegoDistManager::getDistObjectList(const Chain& tableSet, CegoObject::Objec
     }
 }
 
-void CegoDistManager::getLocalObjectList(int tabSetId, CegoObject::ObjectType type, ListT<Chain> &objList)
+void CegoDistManager::getLocalObjectList(unsigned tabSetId, CegoObject::ObjectType type, ListT<Chain> &objList)
 {
     getObjectList(tabSetId, type, objList);
 }
@@ -1993,13 +1994,13 @@ void CegoDistManager::getDistObjectByTableList(const Chain& tableSet,
 					       ListT<CegoCheckObject>& checkList,
 					       ListT<CegoTriggerObject>& triggerList,
 					       ListT<CegoAliasObject>& aliasList,
-					       int& numInvalid)
+					       unsigned& numInvalid)
 {
 #ifdef CGDEBUG
     _pDBMng->log(_modId, Logger::DEBUG, Chain("Getting global object list by table ") + tabName + Chain(" in tableset ") + tableSet);
 #endif
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);    
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
     Chain hostName = _pDBMng->getPrimary(tabSetId);
 
     Chain dbHost;
@@ -2037,9 +2038,9 @@ void CegoDistManager::getDistObjectByTableList(const Chain& tableSet,
     }
 }
 
-int CegoDistManager::getDistPageCount(const Chain& tableSet, const Chain& tabName, CegoObject::ObjectType type)
+unsigned CegoDistManager::getDistPageCount(const Chain& tableSet, const Chain& tabName, CegoObject::ObjectType type)
 {
-    int tabSetId = _pDBMng->getTabSetId(tableSet);    
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);    
     Chain hostName = _pDBMng->getPrimary(tabSetId);
 
     Chain dbHost;
@@ -2062,7 +2063,7 @@ int CegoDistManager::getDistPageCount(const Chain& tableSet, const Chain& tabNam
 
 	res = pSH->reqGetPageCount(tableSet, tabName, type);
 
-	int pageCount = 0;
+	unsigned pageCount = 0;
 
 	if ( res == CegoDbHandler::DB_INFO )
 	{
@@ -2085,9 +2086,9 @@ CegoLockHandler* CegoDistManager::getLockHandle()
     return _pLockHandle;
 }
 
-void CegoDistManager::syncDistTableSet(const Chain& tableSet, const Chain& msg, const Chain& escCmd, int timeout)
+void CegoDistManager::syncDistTableSet(const Chain& tableSet, const Chain& msg, const Chain& escCmd, unsigned timeout)
 {
-    int tabSetId = _pDBMng->getTabSetId(tableSet);    
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);    
     Chain hostName =_pDBMng->getPrimary(tabSetId);
 
     Chain dbHost;
@@ -2152,11 +2153,11 @@ Element* CegoDistManager::verifyTable(const Chain& tableSet, const Chain& tableN
 {   
     _pDBMng->log(_modId, Logger::NOTICE, Chain("Verifying table ") + tableName + Chain(" ..."));
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     Element *pVerification = new Element(XML_VERIFICATION_ELEMENT);
     
-    int errorCount = 0;
+    unsigned errorCount = 0;
     
     ListT<CegoTableObject> idxList;
     ListT<CegoBTreeObject> btreeList;
@@ -2164,7 +2165,7 @@ Element* CegoDistManager::verifyTable(const Chain& tableSet, const Chain& tableN
     ListT<CegoCheckObject> checkList;
     ListT<CegoTriggerObject> triggerList;
     ListT<CegoAliasObject> aliasList;
-    int numInvalid;
+    unsigned numInvalid;
 
     getObjectListByTable(tabSetId, tableName, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
 	
@@ -2323,7 +2324,7 @@ Element* CegoDistManager::verifyTable(const Chain& tableSet, const Chain& tableN
 
 Element* CegoDistManager::verifyView(const Chain& tableSet, const Chain& viewName)
 {
-    int tabSetId = _pDBMng->getTabSetId(tableSet);    
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);    
     Element *pVerification = new Element(XML_VERIFICATION_ELEMENT);
     
     CegoViewObject vo;
@@ -2349,7 +2350,7 @@ Element* CegoDistManager::verifyView(const Chain& tableSet, const Chain& viewNam
 
 Element* CegoDistManager::verifyProcedure(const Chain& tableSet, const Chain& procName)
 {
-    int tabSetId = _pDBMng->getTabSetId(tableSet);    
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);    
     Element *pVerification = new Element(XML_VERIFICATION_ELEMENT);
     
     CegoProcObject po;
@@ -2377,11 +2378,11 @@ Element* CegoDistManager::correctTable(const Chain& tableSet, const Chain& table
 {   
     _pDBMng->log(_modId, Logger::NOTICE, Chain("Correcting table ") + tableName + Chain(" ..."));
 
-    int tabSetId = _pDBMng->getTabSetId(tableSet);
+    unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 
     Element *pCorrection = new Element(XML_CORRECTION_ELEMENT);
     
-    int errorCount = 0;
+    unsigned errorCount = 0;
     
     ListT<CegoTableObject> idxList;
     ListT<CegoBTreeObject> btreeList;
@@ -2389,7 +2390,7 @@ Element* CegoDistManager::correctTable(const Chain& tableSet, const Chain& table
     ListT<CegoCheckObject> checkList;
     ListT<CegoTriggerObject> triggerList;
     ListT<CegoAliasObject> aliasList;
-    int numInvalid;
+    unsigned numInvalid;
 
     getObjectListByTable(tabSetId, tableName, idxList, btreeList, keyList, checkList, triggerList, aliasList, numInvalid);
     
@@ -2452,7 +2453,7 @@ Element* CegoDistManager::correctTable(const Chain& tableSet, const Chain& table
     return pCorrection;
 }
 
-bool CegoDistManager::checkKey(int tabSetId, const Chain& tableName, const ListT<CegoField>& schema, const ListT<CegoKeyObject>& keyList)
+bool CegoDistManager::checkKey(unsigned tabSetId, const Chain& tableName, const ListT<CegoField>& schema, const ListT<CegoKeyObject>& keyList)
 {    
     CegoKeyObject* pKey = keyList.First();
     while ( pKey )
@@ -2517,11 +2518,11 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 
 	getDistObject(tableSet, objName, type, to);
 	
-	int maxAttrLen=10;
+	unsigned maxAttrLen=10;
 	CegoField *pF = to.getSchema().First();
 	while ( pF )
 	{
-	    if ( (int)pF->getAttrName().length() > maxAttrLen )
+	    if ( (unsigned)pF->getAttrName().length() > maxAttrLen )
 		maxAttrLen = pF->getAttrName().length();
 	    pF = to.getSchema().Next();
 	}
@@ -2563,17 +2564,17 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoTableObject io;
 	getDistObject(tableSet, objName, type, io);
 	
-	int maxAttrLen=10;
+	unsigned maxAttrLen=10;
 	CegoField *pF = io.getSchema().First();
 	while ( pF )
 	{
-	    if ( (int)pF->getAttrName().length() > maxAttrLen )
+	    if ( (unsigned)pF->getAttrName().length() > maxAttrLen )
 		maxAttrLen = pF->getAttrName().length();
 	    pF = io.getSchema().Next();
 	}
 
-	int maxTabLen=10;	
-	if ( (int)io.getTabName().length() > maxTabLen )
+	unsigned maxTabLen=10;	
+	if ( (unsigned)io.getTabName().length() > maxTabLen )
 	    maxTabLen = io.getTabName().length();
 	    
 	schema.Insert(CegoField(Chain("INDEXDESC"), Chain("TABLEDESC"), Chain("ATTR"), VARCHAR_TYPE, maxAttrLen));
@@ -2608,17 +2609,17 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoBTreeObject bto;
 	getDistObject(tableSet, objName, type, bto);
 	
-	int maxAttrLen=10;
+	unsigned maxAttrLen=10;
 	CegoField *pF = bto.getSchema().First();
 	while ( pF )
 	{
-	    if ( (int)pF->getAttrName().length() > maxAttrLen )
+	    if ( (unsigned)pF->getAttrName().length() > maxAttrLen )
 		maxAttrLen = pF->getAttrName().length();
 	    pF = bto.getSchema().Next();
 	}
 
-	int maxTabLen=10;	
-	if ( (int)bto.getTabName().length() > maxTabLen )
+	unsigned maxTabLen=10;	
+	if ( (unsigned)bto.getTabName().length() > maxTabLen )
 	    maxTabLen = bto.getTabName().length();
 	    
 	schema.Insert(CegoField(Chain("BTREEDESC"), Chain("TABLEDESC"), Chain("ATTR"), VARCHAR_TYPE, maxAttrLen));
@@ -2651,11 +2652,11 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoViewObject vo;
 	getDistObject(tableSet, objName, type, vo);
 
-	int maxAttrLen=10;
+	unsigned maxAttrLen=10;
 	CegoField *pF = vo.getSchema().First();
 	while ( pF )
 	{
-	    if ( (int)pF->getAttrName().length() > maxAttrLen )
+	    if ( (unsigned)pF->getAttrName().length() > maxAttrLen )
 		maxAttrLen = pF->getAttrName().length();
 	    pF = vo.getSchema().Next();
 	}
@@ -2683,7 +2684,7 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
     }
     case CegoObject::PROCEDURE:
     {
-	int tabSetId = getDBMng()->getTabSetId(tableSet);
+	unsigned tabSetId = getDBMng()->getTabSetId(tableSet);
 
 	if ( checkCompProcedure(tabSetId, objName) == false )
 	    reloadProcedure( tabSetId, objName );
@@ -2693,11 +2694,11 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	ListT<CegoProcVar> argList;
 	pProc->getArgList(argList);
 
-	int maxAttrLen=10;
+	unsigned maxAttrLen=10;
 	CegoProcVar *pArg = argList.First();
 	while ( pArg )
 	{
-	    if ( (int)pArg->getName().length() > maxAttrLen )
+	    if ( (unsigned)pArg->getName().length() > maxAttrLen )
 		maxAttrLen = pArg->getName().length();
 	    pArg = argList.Next();
 	}
@@ -2736,15 +2737,15 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoKeyObject ko;
 	getDistObject(tableSet, objName, type, ko);
 	
-	int maxTabLen=10;
-	if ( (int)objName.length() > maxTabLen )
+	unsigned maxTabLen=10;
+	if ( (unsigned)objName.length() > maxTabLen )
 	    maxTabLen = objName.length();
 	
-	int maxAttrLen=10;
+	unsigned maxAttrLen=10;
 	CegoField *pK = ko.getKeySchema().First();
 	while ( pK )
 	{
-	    if ( (int)pK->getAttrName().length() > maxAttrLen )
+	    if ( (unsigned)pK->getAttrName().length() > maxAttrLen )
 		maxAttrLen = pK->getAttrName().length();
 	    
 	    pK = ko.getKeySchema().Next();
@@ -2752,7 +2753,7 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoField *pR = ko.getRefSchema().First();
 	while ( pR )
 	{
-	    if ( (int)pR->getAttrName().length() > maxAttrLen )
+	    if ( (unsigned)pR->getAttrName().length() > maxAttrLen )
 		maxAttrLen = pR->getAttrName().length();
 	    pR = ko.getRefSchema().Next();
 	}	
@@ -2794,13 +2795,13 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoCheckObject co;
 	getDistObject(tableSet, objName, type, co);
 
-	int tabSetId = _pDBMng->getTabSetId(tableSet);
+	unsigned tabSetId = _pDBMng->getTabSetId(tableSet);
 	    
-	int maxTabLen=10;
-	if ( (int)objName.length() > maxTabLen )
+	unsigned maxTabLen=10;
+	if ( (unsigned)objName.length() > maxTabLen )
 	    maxTabLen = objName.length();
 	
-	int maxCheckLen=30;
+	unsigned maxCheckLen=30;
 	schema.Insert(CegoField(Chain("CHECKDESC"), Chain("CHECKDESC"), Chain("TABLE"), VARCHAR_TYPE, maxTabLen));
 	schema.Insert(CegoField(Chain("CHECKDESC"), Chain("CHECKDESC"), Chain("CONDITION"), VARCHAR_TYPE, maxCheckLen));
 
@@ -2818,11 +2819,11 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoTriggerObject to;
 	getDistObject(tableSet, objName, type, to);
 	
-	int maxTabLen=10;
-	if ( (int)objName.length() > maxTabLen )
+	unsigned maxTabLen=10;
+	if ( (unsigned)objName.length() > maxTabLen )
 	    maxTabLen = objName.length();
 	
-	int maxCheckLen=30;
+	unsigned maxCheckLen=30;
 	schema.Insert(CegoField(Chain("TRIGGERDESC"), Chain("TRIGGERDESC"), Chain("TABLE"), VARCHAR_TYPE, maxTabLen));
 	schema.Insert(CegoField(Chain("TRIGGERDESC"), Chain("TRIGGERDESC"), Chain("TRIGGERTEXT"), VARCHAR_TYPE, maxCheckLen));
 
@@ -2840,11 +2841,11 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
 	CegoAliasObject ao;
 	getDistObject(tableSet, objName, type, ao);
 	
-	int maxTabLen=10;
-	if ( (int)objName.length() > maxTabLen )
+	unsigned maxTabLen=10;
+	if ( (unsigned)objName.length() > maxTabLen )
 	    maxTabLen = objName.length();
 	
-	int maxAliasLen=30;
+	unsigned maxAliasLen=30;
 	schema.Insert(CegoField(Chain("ALIASDESC"), Chain("ALIASDESC"), Chain("TABLE"), VARCHAR_TYPE, maxTabLen));
 	schema.Insert(CegoField(Chain("ALIASDESC"), Chain("ALIASDESC"), Chain("ATTRIBUTE"), VARCHAR_TYPE, maxAliasLen));
 	schema.Insert(CegoField(Chain("ALIASDESC"), Chain("ALIASDESC"), Chain("ALIAS"), VARCHAR_TYPE, maxAliasLen));
@@ -2871,7 +2872,7 @@ void CegoDistManager::getObjectDesc(const Chain& tableSet, const Chain& objName,
     }
 }
 
-CegoView* CegoDistManager::getView(int tabSetId, const Chain& viewName)
+CegoView* CegoDistManager::getView(unsigned tabSetId, const Chain& viewName)
 {
     if ( checkCompView(tabSetId, viewName) == false )
 	reloadView( tabSetId, viewName );
@@ -2879,7 +2880,7 @@ CegoView* CegoDistManager::getView(int tabSetId, const Chain& viewName)
 }
 
 
-CegoProcedure* CegoDistManager::getProcedure(int tabSetId, const Chain& procName)
+CegoProcedure* CegoDistManager::getProcedure(unsigned tabSetId, const Chain& procName)
 {
     if ( checkCompProcedure(tabSetId, procName) == false )
 	reloadProcedure( tabSetId, procName );
@@ -2897,7 +2898,7 @@ CegoAction* CegoDistManager::getParser()
     return _pPA;
 }
 
-void CegoDistManager::reloadView(int tabSetId, const Chain& viewName)
+void CegoDistManager::reloadView(unsigned tabSetId, const Chain& viewName)
 {
     CegoViewObject vo;
     getObject(tabSetId, viewName, CegoObject::VIEW, vo);
@@ -2956,7 +2957,7 @@ void CegoDistManager::reloadView(int tabSetId, const Chain& viewName)
     delete pPA;
 }
 
-void CegoDistManager::reloadProcedure(int tabSetId, const Chain& procName)
+void CegoDistManager::reloadProcedure(unsigned tabSetId, const Chain& procName)
 {    
     CegoProcObject po;
     getObject(tabSetId, procName, CegoObject::PROCEDURE, po);
@@ -2996,7 +2997,7 @@ void CegoDistManager::reloadProcedure(int tabSetId, const Chain& procName)
 }
 
 
-CegoTrigger* CegoDistManager::getTrigger(int tabSetId, const Chain& triggerName)
+CegoTrigger* CegoDistManager::getTrigger(unsigned tabSetId, const Chain& triggerName)
 {
     if ( checkCompTrigger(tabSetId, triggerName) == false )
 	reloadTrigger( tabSetId, triggerName );
@@ -3004,7 +3005,7 @@ CegoTrigger* CegoDistManager::getTrigger(int tabSetId, const Chain& triggerName)
     return getCompTrigger(tabSetId, triggerName );
 }
 
-void CegoDistManager::reloadTrigger(int tabSetId, const Chain& triggerName)
+void CegoDistManager::reloadTrigger(unsigned tabSetId, const Chain& triggerName)
 {    
     CegoTriggerObject to;
     getObject(tabSetId, triggerName, CegoObject::TRIGGER, to);
