@@ -47,13 +47,13 @@ public:
     void stopDistTableSet(const Chain& tableSet, bool archComplete);
     bool distObjectExists( const Chain& tableSet, const Chain& objName, CegoObject::ObjectType objType);
     void getDistObject(const Chain& tableSet, const Chain& objName, CegoObject::ObjectType type, CegoDecodableObject& oe);
-    void getLocalObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type, CegoDecodableObject& oe);
+    void getLocalObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type, CegoDecodableObject& oe);
     void createDistDataTable(const Chain& tableSet, const Chain& tableName, CegoObject::ObjectType type, ListT<CegoField>& fldList, ListT<CegoField>& idxList, bool useColumnId = false);
-    void createLocalDataTable(int tabSetId, const Chain& tableName, CegoObject::ObjectType type, ListT<CegoField>& fldList, ListT<CegoField>& idxList, bool useColumnId = false);
+    void createLocalDataTable(unsigned tabSetId, const Chain& tableName, CegoObject::ObjectType type, ListT<CegoField>& fldList, ListT<CegoField>& idxList, bool useColumnId = false);
     void createDistForeignKey( const Chain& tableSet, const Chain& fkey, const Chain& tableName, const ListT<CegoField>& keyList, const Chain& refTable, const ListT<CegoField>& refList);
-    void createLocalForeignKey(int tabSetId, const Chain& fkey, const Chain& tableName, const ListT<CegoField>& keyList, const Chain& refTable, const ListT<CegoField>& refList);    
+    void createLocalForeignKey(unsigned tabSetId, const Chain& fkey, const Chain& tableName, const ListT<CegoField>& keyList, const Chain& refTable, const ListT<CegoField>& refList);    
     void createDistCheck( const Chain& tableSet, const Chain& checkName, const Chain& tableName, CegoPredicate *pPredDesc);
-    void createLocalCheck(int tabSetId, const Chain& checkName, const Chain& tableName, CegoPredicate *pPredDesc);
+    void createLocalCheck(unsigned tabSetId, const Chain& checkName, const Chain& tableName, CegoPredicate *pPredDesc);
     void reorgDistObject(const Chain& tableSet, const Chain& tableName, CegoObject::ObjectType type);
     void createDistIndexTable( const Chain& tableSet, const Chain& indexName, const Chain& tableName, ListT<CegoField>& schema, CegoObject::ObjectType type, bool isCached = false);
     void insertDistDataTable(CegoTableObject& oe, ListT<CegoField>& fvl);
@@ -78,25 +78,25 @@ public:
 					    CegoProcBlock* pBlock = 0);
     void alterDistDataTable(CegoTableObject& oe, const ListT<CegoAlterDesc>& alterList);
     void renameDistObject(const Chain& tableSet, const Chain& objName, CegoObject::ObjectType type,  const Chain& newObjName);
-    void renameLocalObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type,  const Chain& newObjName);
+    void renameLocalObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type,  const Chain& newObjName);
     void createDistView(const Chain& tableSet, const Chain& viewName, const ListT<CegoField>& schema, const Chain& viewText);
-    void createLocalView(int tabSetId, const Chain& viewName, const ListT<CegoField>& schema, const Chain& viewText);
+    void createLocalView(unsigned tabSetId, const Chain& viewName, const ListT<CegoField>& schema, const Chain& viewText);
     void createDistTrigger(const Chain& tableSet, const Chain& triggerName,
 			   bool isBefore, bool isOnInsert, bool isOnUpdate, bool isOnDelete,
 			   const Chain& tableName, const Chain& triggerText);
-    void createLocalTrigger(int tabSetId, const Chain& triggerName,
+    void createLocalTrigger(unsigned tabSetId, const Chain& triggerName,
 			    bool isBefore, bool isOnInsert, bool isOnUpdate, bool isOnDelete,
 			    const Chain& tableName , const Chain& triggerText);
     void createDistAlias(const Chain& tableSet, const Chain& aliasName,
 			   const Chain& tableName, const ListT<CegoAttrAlias>& aliasList);
-    void createLocalAlias(int tabSetId, const Chain& aliasName,
+    void createLocalAlias(unsigned tabSetId, const Chain& aliasName,
 			    const Chain& tableName, const ListT<CegoAttrAlias>& aliasList);
     void createDistProc(const Chain& tableSet, const Chain& procName, const Chain& procText);
-    void createLocalProc(int tabSetId, const Chain& procName, const Chain& procText);
+    void createLocalProc(unsigned tabSetId, const Chain& procName, const Chain& procText);
     void truncateDistTable(const Chain& tableName, const Chain& tableSet);
     void dropDistObject(const Chain& tableName, const Chain& tableSet, CegoObject::ObjectType type);
     void getDistObjectList(const Chain& tableSet, CegoObject::ObjectType type, ListT<Chain> &objList);
-    void getLocalObjectList(int tabSetId, CegoObject::ObjectType type, ListT<Chain> &objList);
+    void getLocalObjectList(unsigned tabSetId, CegoObject::ObjectType type, ListT<Chain> &objList);
     void getDistObjectByTableList(const Chain& tableSet,
 				  const Chain& tabName,
 				  ListT<CegoTableObject> &idxList,
@@ -105,16 +105,16 @@ public:
 				  ListT<CegoCheckObject>& checkList,
 				  ListT<CegoTriggerObject>& triggerList,
 				  ListT<CegoAliasObject>& aliasList,
-				  int &numInvalid);
-    int getDistPageCount(const Chain& tableSet, const Chain& tabName, CegoObject::ObjectType type);
+				  unsigned &numInvalid);
+    unsigned getDistPageCount(const Chain& tableSet, const Chain& tabName, CegoObject::ObjectType type);
     void startDistTransaction( const Chain& tableSet);
     long endDistTransaction( const Chain& tableSet);
     long rollbackDistTransaction( const Chain& tableSet);
-    int getDistTid( const Chain& tableSet);
-    int getLocalTid(int tabSetId);
+    unsigned long long getDistTid( const Chain& tableSet);
+    unsigned long long getLocalTid(unsigned tabSetId);
     void setAllocatedSortArea(unsigned long long n);
     unsigned long long getAllocatedSortArea() const;
-    void syncDistTableSet(const Chain& tableSet, const Chain& msg, const Chain& escCmd, int timeout);
+    void syncDistTableSet(const Chain& tableSet, const Chain& msg, const Chain& escCmd, unsigned timeout);
     void enableAuth();
     void disableAuth();
     void setActiveUser(const Chain& tableSet, const Chain& user, const Chain& passwd);
@@ -127,16 +127,16 @@ public:
     Element* correctTable(const Chain& tableSet, const Chain& tableName);
     void getObjectDesc(const Chain& tableSet, const Chain& objName, CegoObject::ObjectType type, 
 		       ListT<CegoField>& schema, ListT< ListT<CegoFieldValue> > &fa);
-    CegoView* getView(int tabSetId, const Chain& viewName);
+    CegoView* getView(unsigned tabSetId, const Chain& viewName);
 
     
-    CegoProcedure* getProcedure(int tabSetId, const Chain& procName);
-    CegoTrigger* getTrigger(int tabSetId, const Chain& triggerName);
+    CegoProcedure* getProcedure(unsigned tabSetId, const Chain& procName);
+    CegoTrigger* getTrigger(unsigned tabSetId, const Chain& triggerName);
     CegoAction* getParser();
 
-    void reloadView(int tabSetId, const Chain& viewName);   
-    void reloadProcedure(int tabSetId, const Chain& procName);
-    void reloadTrigger(int tabSetId, const Chain& triggerName);
+    void reloadView(unsigned tabSetId, const Chain& viewName);   
+    void reloadProcedure(unsigned tabSetId, const Chain& procName);
+    void reloadTrigger(unsigned tabSetId, const Chain& triggerName);
     void setGraceMode(bool isGrace);
     bool isGraceMode() const;
 
@@ -146,7 +146,7 @@ public:
 private:
 
     void startTableSet(const Chain& tableSet, const Chain& secondary, bool cleanIt, bool cpDump, bool doAutoCorrect, bool doTempReset);
-    bool checkKey(int tabSetId, const Chain& tableName, const ListT<CegoField>& schema, const ListT<CegoKeyObject>& keyList);
+    bool checkKey(unsigned tabSetId, const Chain& tableName, const ListT<CegoField>& schema, const ListT<CegoKeyObject>& keyList);
     
     class ActiveTSUser {
 	
