@@ -33,7 +33,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-CegoFactor::CegoFactor(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId)
+CegoFactor::CegoFactor(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _pAttrDesc = 0;
     _pExpr = 0;
@@ -263,7 +263,7 @@ void CegoFactor::cleanUp()
     }
 }
 
-void CegoFactor::setTabSetId(int tabSetId)
+void CegoFactor::setTabSetId(unsigned tabSetId)
 {
     switch ( _type ) 
     {
@@ -481,7 +481,7 @@ void CegoFactor::getFieldList(ListT<CegoField>& fl, ListT<CegoField>** pFLA) con
 	    throw Exception(EXLOC, msg);
 	}
 	
-	int i=0;
+	unsigned i=0;
 	CegoField* pF = 0;
 	while ( pFLA[i] && pF == 0 )
 	{		    
@@ -581,9 +581,9 @@ ListT<CegoAttrDesc*> CegoFactor::getAttrRefList() const
     return attrList;
 }
 
-int CegoFactor::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
+unsigned CegoFactor::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
 {
-    int refCount = 0;
+    unsigned refCount = 0;
 
     switch ( _type )
     {
@@ -1073,7 +1073,7 @@ Chain CegoFactor::getId(CegoProcBlock *pBlock) const
     return s;
 }
 
-Chain CegoFactor::toChain(int defTabSetId, const Chain& indent) const
+Chain CegoFactor::toChain(unsigned defTabSetId, const Chain& indent) const
 {
     Chain s;
     
@@ -1213,7 +1213,7 @@ void CegoFactor::encode(char *buf, CegoProcBlock *pBlock)
     }
 }
 
-void CegoFactor::decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, int tabSetId)
+void CegoFactor::decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     char* pE = (char*)buf;
 
@@ -1284,9 +1284,9 @@ void CegoFactor::decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock,
     }
 }
 
-int CegoFactor::getEncodingLength(CegoProcBlock *pBlock) const
+unsigned CegoFactor::getEncodingLength(CegoProcBlock *pBlock) const
 {   
-    int len = 0;
+    unsigned len = 0;
 
     len += sizeof(CegoFactor::FacType);
 
