@@ -45,7 +45,7 @@ class CegoFactor {
     
     enum FacType { CONSTVAL, VAR, EXPR, FETCH, ATTR, FUNCTION, QUERY, AGGREGATION, CASECOND, CONDITION };
 
-    CegoFactor(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId);
+    CegoFactor(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
     CegoFactor(const CegoFactor& pf);
     CegoFactor(const Chain& varName);
     CegoFactor(const CegoFieldValue& fv);
@@ -62,7 +62,7 @@ class CegoFactor {
 
     void cleanUp();
 
-    void setTabSetId(int tabSetId);
+    void setTabSetId(unsigned tabSetId);
     
     void clearAttrCache();
 
@@ -89,7 +89,7 @@ class CegoFactor {
     void getFieldList(ListT<CegoField>& fl, ListT<CegoField>** pFLA) const;
 
     ListT<CegoAttrDesc*> getAttrRefList() const;
-    int evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl);
+    unsigned evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl);
     
     CegoField evalField(const ListT<CegoField>& fl, bool graceful = false) const;
 
@@ -106,12 +106,12 @@ class CegoFactor {
     CegoFactor& operator = ( const CegoFactor& pf);
 
     Chain getId(CegoProcBlock *pBlock) const;
-    Chain toChain(int defTabSetId, const Chain& indent) const;
+    Chain toChain(unsigned defTabSetId, const Chain& indent) const;
     Chain dbFormat(CegoDatabaseFormater *pForm) const;
     
     void encode(char *buf, CegoProcBlock *pBlock);
-    void decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, int tabSetId);
-    int getEncodingLength(CegoProcBlock *pBlock) const;
+    void decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId);
+    unsigned getEncodingLength(CegoProcBlock *pBlock) const;
 
     ListT<CegoAggregation*> getAggregationList();
 
@@ -135,8 +135,8 @@ class CegoFactor {
     CegoSelect* _pSelect;
     CegoCaseCond* _pCaseCond;
     CegoCondition* _pCond;    
-    int _flaCacheArrayPos;
-    int _flaCacheFieldPos;
+    unsigned _flaCacheArrayPos;
+    unsigned _flaCacheFieldPos;
     bool _flaCached;
 };
 #endif
