@@ -55,7 +55,7 @@ CegoFunction::CegoFunction(CegoFunction::FunctionType type, ListT<CegoExpr*>& ex
     _type = type;
 }
 
-CegoFunction::CegoFunction(char* buf, CegoDistManager *pTabMng, CegoProcBlock *pBlock, int tabSetId)
+CegoFunction::CegoFunction(char* buf, CegoDistManager *pTabMng, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _pTabMng = pTabMng;
     _tabSetId = tabSetId;
@@ -63,14 +63,14 @@ CegoFunction::CegoFunction(char* buf, CegoDistManager *pTabMng, CegoProcBlock *p
     _pProc = 0;
 }
 
-CegoFunction::CegoFunction(CegoDistManager* pTabMng, int tabSetId, CegoFunction::FunctionType type)
+CegoFunction::CegoFunction(CegoDistManager* pTabMng, unsigned tabSetId, CegoFunction::FunctionType type)
 {
     _pTabMng = pTabMng;
     _tabSetId = tabSetId;
     _type = type;
 }
 
-CegoFunction::CegoFunction(CegoDistManager* pTabMng, int tabSetId, const Chain& funcName, ListT<CegoExpr*>& exprList)
+CegoFunction::CegoFunction(CegoDistManager* pTabMng, unsigned tabSetId, const Chain& funcName, ListT<CegoExpr*>& exprList)
 {
     _pTabMng = pTabMng;
     _exprList = exprList;
@@ -117,7 +117,7 @@ void CegoFunction::cleanUp()
     }
 }
 
-void CegoFunction::setTabSetId(int tabSetId)
+void CegoFunction::setTabSetId(unsigned tabSetId)
 {
     _tabSetId = tabSetId;
     
@@ -129,7 +129,7 @@ void CegoFunction::setTabSetId(int tabSetId)
     }
 }
 
-int CegoFunction::getTabSetId() const
+unsigned CegoFunction::getTabSetId() const
 {
     return _tabSetId;
 }
@@ -439,7 +439,7 @@ CegoDataType CegoFunction::getReturnType()
     }
 }
 
-int CegoFunction::getReturnTypeLen(const ListT<CegoField>& fl)
+unsigned CegoFunction::getReturnTypeLen(const ListT<CegoField>& fl)
 {
     switch ( _type )
     {
@@ -557,7 +557,7 @@ int CegoFunction::getReturnTypeLen(const ListT<CegoField>& fl)
 	if ( _pTabMng == 0 )
 	    throw Exception(EXLOC, "No valid table manager set up");
 
-	int returnTypeLen;
+	unsigned returnTypeLen;
 
 	if ( _pProc )
 	{
@@ -587,14 +587,14 @@ int CegoFunction::getReturnTypeLen(const ListT<CegoField>& fl)
     }
 }
 
-int CegoFunction::getReturnTypeDim()
+unsigned CegoFunction::getReturnTypeDim()
 {
     if ( _type == USERDEFINED )
     {
 	if ( _pTabMng == 0 )
 	    throw Exception(EXLOC, "No valid table manager set up");
 	
-	int returnTypeDim;
+	unsigned returnTypeDim;
 
 	if ( _pProc )
 	{
@@ -759,9 +759,9 @@ ListT<CegoAttrDesc*> CegoFunction::getAttrRefList() const
     return attrList;
 }
 
-int CegoFunction::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
+unsigned CegoFunction::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
 {
-    int refCount = 0;
+    unsigned refCount = 0;
 
     CegoExpr** pExpr = _exprList.First();
     while ( pExpr )
@@ -1003,7 +1003,8 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
     }
     case CegoFunction::NEWDATE:
     {
-	int year = 0;
+	// we stay on signed variables, since these values are internally handeled as int
+        int year = 0;
 	int month = 1;
 	int day = 1;
 	int hour = 0;
@@ -1225,9 +1226,10 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
 	CegoExpr** pExpr4 = _exprList.Next();
 	
 	CegoFieldValue fv1, fv2;
-	
+
+	// start may be -1 to indicate search from end
 	int start = 0;
-	int occ = 1;
+	unsigned occ = 1;
 	
 	fv1 = (*pExpr1)->evalFieldValue(pFLA, pBlock);
 	fv2 = (*pExpr2)->evalFieldValue(pFLA, pBlock);
@@ -1240,12 +1242,12 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
 	if ( pExpr4 )
 	{
 	    CegoFieldValue fv = (*pExpr4)->evalFieldValue(pFLA, pBlock);
-	    occ = fv.valAsChain().asInteger();    
+	    occ = fv.valAsChain().asUnsigned();    
 	}
 
 	Chain s = fv1.valAsChain();
 			
-	int pos;
+	unsigned long pos;
 	if ( s.posStr(fv2.valAsChain(), pos, start, occ) )
 	{		
 	    CegoFieldValue fv(INT_TYPE, pos);
@@ -1267,14 +1269,14 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
 	fv2 = (*pExpr2)->evalFieldValue(pFLA, pBlock);
 	
 	Chain s = fv1.valAsChain();
-	int start = fv2.valAsChain().asInteger();
+	unsigned start = fv2.valAsChain().asUnsigned();
 		
-	int len=0;
+	unsigned len=0;
 	
 	if ( pExpr3 )
 	{
 	    fv3 = (*pExpr3)->evalFieldValue(pFLA, pBlock);
-	    len=fv3.valAsChain().asInteger();
+	    len=fv3.valAsChain().asUnsigned();
 	}
 
 	// we start at min at position 1
@@ -1282,13 +1284,13 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
 	    start = 1;
 
 	// we start at max s.length()
-	if ( start > (int)s.length() )
+	if ( start > (unsigned)s.length() )
 	{
-	    start = s.length();
+	    start = (unsigned)s.length();
 	    // throw Exception(EXLOC, "Start postion after end");
 	}
 		
-	if ( start+len-1 > (int)s.length())
+	if ( start+len-1 > (unsigned)s.length())
 	{
 	    len = s.length() - start;
 	    // throw Exception(EXLOC, "End postion after end");
@@ -1390,7 +1392,7 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
 	CegoReplacer *pRep = _pTabMng->getReplacer(pattern, replace);
 	   
 	Chain target;
-	int nmatch = pRep->replace(src, target);
+	unsigned nmatch = pRep->replace(src, target);
 
 	if ( pExpr4 )
 	{
@@ -1508,12 +1510,12 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
 
 	fv = (*pExpr)->evalFieldValue(pFLA, pBlock);
 
-	int l = (int)random() % fv.valAsChain().asInteger();
+	unsigned l = (unsigned)random() % fv.valAsChain().asUnsigned();
 	if ( l == 0 )
-	    l = fv.valAsChain().asInteger();
+	    l = fv.valAsChain().asUnsigned();
 	
 	Chain rs;
-	for ( int j=0; j<l; j++ ) 
+	for ( unsigned j=0; j<l; j++ ) 
 	{ 
 	    rs += Chain((char)(65 + (random() % 26))); 
 	}
@@ -1529,7 +1531,7 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
 
 	fv = (*pExpr)->evalFieldValue(pFLA, pBlock);
 	
-	int l = fv.valAsChain().asInteger();
+	unsigned l = fv.valAsChain().asUnsigned();
 
 	CegoFieldValue retVal(INT_TYPE, random() % l);  
 	return retVal;
@@ -2134,7 +2136,7 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
 	    
 	    CegoProcVar *pVar = argList.First();
 	    CegoExpr **pExpr = _exprList.First();
-	    int pos=1;
+	    unsigned pos=1;
 	    while ( pVar && pExpr ) 
 	    {		    		
 		if ( pVar->getVarType() == CegoProcVar::OUTVAR )
@@ -2175,10 +2177,10 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
 			    if ( fv.castTo(pVar->getType(), pVar->getDim()) == false )
 			    {
 				throw Exception(EXLOC, Chain("Mismatched datatype <") 
-						+ CEGO_TYPE_MAP[(int)fv.getType()] 
+						+ CEGO_TYPE_MAP[(unsigned)fv.getType()] 
 						+ Chain("> in value list for argument ") + Chain(pos) 
 						+ " ( expected " 
-						+ CEGO_TYPE_MAP[(int)pVar->getType()] + " )");
+						+ CEGO_TYPE_MAP[(unsigned)pVar->getType()] + " )");
 			    }
 			}
 		    }
@@ -2234,7 +2236,7 @@ CegoFieldValue CegoFunction::evalFieldValue(ListT<CegoField>** pFLA, CegoProcBlo
     }
 }
 
-CegoProcedure* CegoFunction::loadProcedure(int tabSetId, const Chain& procName) const
+CegoProcedure* CegoFunction::loadProcedure(unsigned tabSetId, const Chain& procName) const
 {
     CegoProcObject po;
     _pTabMng->getObject(tabSetId, procName, CegoObject::PROCEDURE, po);
@@ -2331,7 +2333,7 @@ Chain CegoFunction::getId(CegoProcBlock *pBlock) const
     return s;   
 }
 
-Chain CegoFunction::toChain(int defTabSetId, const Chain& indent) const
+Chain CegoFunction::toChain(unsigned defTabSetId, const Chain& indent) const
 {
     Chain argString;
 
@@ -2377,17 +2379,17 @@ void CegoFunction::encode(char *buf, CegoProcBlock *pBlock)
 
     if ( _type == CegoFunction::USERDEFINED )
     {
-	int len = _funcName.length() - 1;
-	memcpy(pE, &len, sizeof(int));
-	pE = pE + sizeof(int);
+	unsigned len = _funcName.length() - 1;
+	memcpy(pE, &len, sizeof(unsigned));
+	pE = pE + sizeof(unsigned);
 	memcpy(pE, (char*)_funcName, len);
 	pE = pE + len; 
     }
 
-    int numExpr = _exprList.Size();
+    unsigned numExpr = _exprList.Size();
 
-    memcpy( pE, &numExpr, sizeof(int));
-    pE = pE + sizeof(int);
+    memcpy( pE, &numExpr, sizeof(unsigned));
+    pE = pE + sizeof(unsigned);
         
     CegoExpr** pExpr = _exprList.First();
     while ( pExpr )
@@ -2398,7 +2400,7 @@ void CegoFunction::encode(char *buf, CegoProcBlock *pBlock)
     }
 }
 
-void CegoFunction::decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, int tabSetId)
+void CegoFunction::decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     char* pE = (char*)buf;
 
@@ -2407,18 +2409,18 @@ void CegoFunction::decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBloc
 
     if ( _type == CegoFunction::USERDEFINED )
     {
-	int len;
-	memcpy( &len, pE, sizeof(int));
-	pE = pE + sizeof(int);
+	unsigned len;
+	memcpy( &len, pE, sizeof(unsigned));
+	pE = pE + sizeof(unsigned);
 	_funcName = Chain((char*)pE, len);
 	pE = pE + len;
     }
 
-    int numExpr;
-    memcpy( &numExpr, pE, sizeof(int));
-    pE = pE + sizeof(int);
+    unsigned numExpr;
+    memcpy( &numExpr, pE, sizeof(unsigned));
+    pE = pE + sizeof(unsigned);
 
-    int i=0;
+    unsigned i=0;
     while ( i < numExpr )
     {
 	CegoExpr *pExpr = new CegoExpr(pE, pGTM, pBlock, tabSetId);
@@ -2428,17 +2430,17 @@ void CegoFunction::decode(char *buf, CegoDistManager* pGTM, CegoProcBlock *pBloc
     }    
 }
 
-int CegoFunction::getEncodingLength(CegoProcBlock *pBlock) const
+unsigned CegoFunction::getEncodingLength(CegoProcBlock *pBlock) const
 {
-    int len = 0;
+    unsigned len = 0;
     
     len += sizeof(CegoFunction::FunctionType);
     if ( _type == CegoFunction::USERDEFINED )
     {
-	len += sizeof(int); // size of user funcname
+	len += sizeof(unsigned); // size of user funcname
 	len += _funcName.length() - 1;
     }
-    len += sizeof(int); // numExpr
+    len += sizeof(unsigned); // numExpr
     
     CegoExpr** pExpr = _exprList.First();
     while ( pExpr )
