@@ -37,8 +37,8 @@ public:
     CegoKeyObject(const CegoKeyObject& ko);    
     CegoKeyObject(ObjectType type,
 		  const Chain& objName,
-		  int tabSetId = 0);
-    CegoKeyObject(int tabSetId,
+		  unsigned tabSetId = 0);
+    CegoKeyObject(unsigned tabSetId,
 		  const Chain& fkey, 
 		  const Chain& tabName, 
 		  const ListT<CegoField>& schemaList,
@@ -54,7 +54,7 @@ public:
     const Chain& getRefTable() const;
     void setRefSchema(const ListT<CegoField>& refSchema);   
     const ListT<CegoField>& getRefSchema() const;
-    int getEntrySize() const;
+    unsigned getEntrySize() const;
     void encode(char *buf) const;
     void decode(char *buf);
     void setEmpty();
