@@ -35,7 +35,7 @@ class CegoMediatorThread : public Thread {
     CegoMediatorThread(CegoDatabaseManager *pDBMng);
     ~CegoMediatorThread();
 
-    void getDbSpec(const Chain& dbSpecFileName, const Chain& medHost, int medPort, const Chain& user, const Chain& passwd);
+    void getDbSpec(const Chain& dbSpecFileName, const Chain& medHost, unsigned medPort, const Chain& user, const Chain& passwd);
     void* job(void* arg);
 
  private:
