@@ -83,10 +83,10 @@ CegoModule::~CegoModule()
 {
 }
 
-int CegoModule::getModId(const Chain& module)
+unsigned CegoModule::getModId(const Chain& module)
 {
-    int i=0;
-    while ( i < (int)(sizeof (  CEGO_MODULE_MAP ) / sizeof( char*)) )
+    unsigned i=0;
+    while ( i < (unsigned)(sizeof (  CEGO_MODULE_MAP ) / sizeof( char*)) )
     {
 	if ( Chain( CEGO_MODULE_MAP[i] ) == module )
 	    return i;
@@ -95,12 +95,12 @@ int CegoModule::getModId(const Chain& module)
     throw Exception(EXLOC, Chain("Module ") + module + Chain(" not registered"));
 }
 
-Chain CegoModule::getModName(int id)
+Chain CegoModule::getModName(unsigned id)
 {
     return Chain( CEGO_MODULE_MAP[id] );
 }
 
-int CegoModule::getMapSize()
+unsigned CegoModule::getMapSize()
 {
     return sizeof(CEGO_MODULE_MAP) / sizeof(char*);
 }
