@@ -285,7 +285,7 @@ void CegoObjectManager::createAliasObject(CegoAliasObject& aliasObject)
     }
 }
 
-void CegoObjectManager::truncateObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+void CegoObjectManager::truncateObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {
     unsigned long long lockId = 0;
     CegoBufferPage bp;
@@ -327,7 +327,7 @@ void CegoObjectManager::truncateObject(int tabSetId, const Chain& objName, CegoO
 		{	    
 		    CegoObject obj;
 		    
-		    int size;
+		    unsigned size;
 		    obj.decodeBase(pE, size);   
 		    
 		    bool typeMatch =  ( type == CegoObject::AVLTREE
@@ -369,7 +369,7 @@ void CegoObjectManager::truncateObject(int tabSetId, const Chain& objName, CegoO
 			    
 			    tupPage.setType(CegoBufferPage::TUPLE);
 			    
-			    int dataPageId = tupPage.getPageId();
+			    PageIdType dataPageId = tupPage.getPageId();
 			    
 			    _pDBMng->bufferUnfix(tupPage, true, _pLockHandle);
 
@@ -404,7 +404,7 @@ void CegoObjectManager::truncateObject(int tabSetId, const Chain& objName, CegoO
 			    rootNode.setPtr(rootPage.getChunkEntry(), rootPage.getChunkLen());
 			    rootNode.initNode();
 	
-			    int dataPageId = rootPage.getPageId();
+			    PageIdType dataPageId = rootPage.getPageId();
 
 			    btoe.setDataPageId(dataPageId);
 
@@ -456,7 +456,7 @@ void CegoObjectManager::truncateObject(int tabSetId, const Chain& objName, CegoO
     }
 }
 
-void CegoObjectManager::removeObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+void CegoObjectManager::removeObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {    
     unsigned long long lockId = 0;
     CegoBufferPage bp;
@@ -498,7 +498,7 @@ void CegoObjectManager::removeObject(int tabSetId, const Chain& objName, CegoObj
 		{	    
 		    CegoObject obj;
 		    
-		    int size;
+		    unsigned size;
 		    obj.decodeBase(pE, size);   
 
 		    bool typeMatch =  
@@ -607,7 +607,7 @@ void CegoObjectManager::removeObject(int tabSetId, const Chain& objName, CegoObj
     }
 }
 
-int CegoObjectManager::traceObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+unsigned CegoObjectManager::traceObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {    
     unsigned long long lockId = 0;
     CegoBufferPage bp;
@@ -649,7 +649,7 @@ int CegoObjectManager::traceObject(int tabSetId, const Chain& objName, CegoObjec
 		{	    
 		    CegoObject obj;
 		    
-		    int size;
+		    unsigned size;
 		    obj.decodeBase(pE, size);   
 
 		    bool typeMatch =  
@@ -688,7 +688,7 @@ int CegoObjectManager::traceObject(int tabSetId, const Chain& objName, CegoObjec
 
 			    CegoBTreeManager btreeMng(this, &btoe);
 			    
-			    int traceCount = btreeMng.traceBTree();
+			    unsigned traceCount = btreeMng.traceBTree();
 			    
 			    _pLockHandle->unlockSysPage(lockId);
 			    lockId = 0;
@@ -712,7 +712,7 @@ int CegoObjectManager::traceObject(int tabSetId, const Chain& objName, CegoObjec
 			    _pLockHandle->unlockSysPage(lockId);
 			    lockId = 0;
 
-			    int traceCount = traceObjectPages(tabSetId, pageId);
+			    unsigned traceCount = traceObjectPages(tabSetId, pageId);
 			    _pDBMng->bufferUnfix(bp, true, _pLockHandle);
 			    
 			    return traceCount;       
@@ -754,7 +754,7 @@ int CegoObjectManager::traceObject(int tabSetId, const Chain& objName, CegoObjec
     }
 }
 
-void CegoObjectManager::reorgObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+void CegoObjectManager::reorgObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {
     unsigned long long lockId = 0;
     CegoBufferPage bp;
@@ -797,7 +797,7 @@ void CegoObjectManager::reorgObject(int tabSetId, const Chain& objName, CegoObje
 		{	    
 		    CegoObject obj;
 		    
-		    int size;
+		    unsigned size;
 		    obj.decodeBase(pE, size);   
 		    
 		    bool typeMatch = ( type == CegoObject::AVLTREE
@@ -887,7 +887,7 @@ void CegoObjectManager::reorgObject(int tabSetId, const Chain& objName, CegoObje
     }
 }
 
-void CegoObjectManager::invalidateObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+void CegoObjectManager::invalidateObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {
     unsigned long long lockId = 0;
     CegoBufferPage bp;
@@ -930,7 +930,7 @@ void CegoObjectManager::invalidateObject(int tabSetId, const Chain& objName, Ceg
 		{	    
 		    CegoObject obj;
 		    
-		    int size;
+		    unsigned size;
 		    obj.decodeBase(pE, size);   
 		    
 		    bool typeMatch =  
@@ -1042,32 +1042,32 @@ void CegoObjectManager::invalidateObject(int tabSetId, const Chain& objName, Ceg
     }
 }
 
-void CegoObjectManager::alterTableObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type, CegoTableObject& objEntry)
+void CegoObjectManager::alterTableObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type, CegoTableObject& objEntry)
 {
     alterObject(tabSetId, objName, type, objEntry);
 }
 
-void CegoObjectManager::alterBTreeObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type, CegoBTreeObject& objEntry)
+void CegoObjectManager::alterBTreeObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type, CegoBTreeObject& objEntry)
 {
     alterObject(tabSetId, objName, type, objEntry);
 }
 
-void CegoObjectManager::alterKeyObject(int tabSetId, const Chain& keyName, CegoKeyObject& objEntry)
+void CegoObjectManager::alterKeyObject(unsigned tabSetId, const Chain& keyName, CegoKeyObject& objEntry)
 {
     alterObject(tabSetId, keyName, objEntry.getType(), objEntry);
 }
 
-void CegoObjectManager::alterTriggerObject(int tabSetId, const Chain& triggerName, CegoTriggerObject& objEntry)
+void CegoObjectManager::alterTriggerObject(unsigned tabSetId, const Chain& triggerName, CegoTriggerObject& objEntry)
 {
     alterObject(tabSetId, triggerName, objEntry.getType(), objEntry);
 }
 
-void CegoObjectManager::alterCheckObject(int tabSetId, const Chain& checkName, CegoCheckObject& checkEntry)
+void CegoObjectManager::alterCheckObject(unsigned tabSetId, const Chain& checkName, CegoCheckObject& checkEntry)
 {
     alterObject(tabSetId, checkName, checkEntry.getType(), checkEntry);
 }
 
-void CegoObjectManager::getObjectList(int tabSetId, CegoObject::ObjectType type, ListT<Chain>& objList)
+void CegoObjectManager::getObjectList(unsigned tabSetId, CegoObject::ObjectType type, ListT<Chain>& objList)
 {        
     unsigned long long lockId = 0;
     CegoBufferPage bp;
@@ -1087,7 +1087,7 @@ void CegoObjectManager::getObjectList(int tabSetId, CegoObject::ObjectType type,
 	    pageOffset = _pDBMng->getSysPageOffset(tabSetId);
 	}
 
-	int maxPos = TABMNG_HASHSIZE;
+	unsigned maxPos = TABMNG_HASHSIZE;
 	
 	for ( PageIdType hashPos = 0 ; hashPos < (PageIdType)maxPos; hashPos++ )
 	{	    
@@ -1106,7 +1106,7 @@ void CegoObjectManager::getObjectList(int tabSetId, CegoObject::ObjectType type,
 		while (pE)
 		{		    
 		    CegoObject obj;
-		    int entrySize;
+		    unsigned entrySize;
 		    
 		    obj.decodeBase(pE, entrySize);   
 		    
@@ -1161,14 +1161,14 @@ void CegoObjectManager::setIgnoreInvalid(bool ignoreInvalid)
     _ignoreInvalid = ignoreInvalid;
 } 
 
-void CegoObjectManager::getObjectListByTable(int tabSetId, const Chain& tabName, 
+void CegoObjectManager::getObjectListByTable(unsigned tabSetId, const Chain& tabName, 
 					     ListT<CegoTableObject>& idxList, 
 					     ListT<CegoBTreeObject>& btreeList, 
 					     ListT<CegoKeyObject>& keyList,
 					     ListT<CegoCheckObject>& checkList,
 					     ListT<CegoTriggerObject>& triggerList,
 					     ListT<CegoAliasObject>& aliasList,
-					     int& numInvalid)
+					     unsigned& numInvalid)
 {    
     unsigned long long lockId = 0;
     CegoBufferPage bp;
@@ -1191,7 +1191,7 @@ void CegoObjectManager::getObjectListByTable(int tabSetId, const Chain& tabName,
 
 	pageOffset = _pDBMng->getSysPageOffset(tabSetId);
 
-	int maxPos = TABMNG_HASHSIZE;
+	unsigned maxPos = TABMNG_HASHSIZE;
 	
 	for ( PageIdType hashPos = 0; hashPos < (PageIdType)maxPos; hashPos++ )
 	{	    
@@ -1209,7 +1209,7 @@ void CegoObjectManager::getObjectListByTable(int tabSetId, const Chain& tabName,
 		while (pE)
 		{	    
 		    CegoObject obj;
-		    int entrySize;
+		    unsigned entrySize;
 		    obj.decodeBase(pE, entrySize);   
 		    
 		    if ( tabSetId == obj.getTabSetId() )
@@ -1342,14 +1342,14 @@ void CegoObjectManager::getObjectListByTable(int tabSetId, const Chain& tabName,
     }	
 }
 
-void CegoObjectManager::getObject(int tabSetId, const Chain& objectName, CegoObject::ObjectType type, CegoDecodableObject& oe)
+void CegoObjectManager::getObject(unsigned tabSetId, const Chain& objectName, CegoObject::ObjectType type, CegoDecodableObject& oe)
 {    
     CegoBufferPage bp;
     getObjectWithFix(tabSetId, objectName, type, oe, bp);
     _pDBMng->bufferUnfix(bp, false, _pLockHandle);    
 }
 
-void CegoObjectManager::getObjectWithFix(int tabSetId, const Chain& objectName, CegoObject::ObjectType type, CegoDecodableObject& oe, CegoBufferPage &bp)
+void CegoObjectManager::getObjectWithFix(unsigned tabSetId, const Chain& objectName, CegoObject::ObjectType type, CegoDecodableObject& oe, CegoBufferPage &bp)
 {
     unsigned long long lockId = 0;
 
@@ -1391,7 +1391,7 @@ void CegoObjectManager::getObjectWithFix(int tabSetId, const Chain& objectName,
 		while (pE && notFound )
 		{		    
 		    CegoObject obj;
-		    int entrySize;
+		    unsigned entrySize;
 		    obj.decodeBase(pE, entrySize);
 		    
 		    if ( tabSetId == obj.getTabSetId() )
@@ -1460,14 +1460,14 @@ void CegoObjectManager::getObjectWithFix(int tabSetId, const Chain& objectName,
     }
 }
 
-bool CegoObjectManager::tableObjectExists(int tabSetId, const Chain& objectName)
+bool CegoObjectManager::tableObjectExists(unsigned tabSetId, const Chain& objectName)
 {
     return objectExists(tabSetId, objectName, CegoObject::TABLE)
 	|| objectExists(tabSetId, objectName, CegoObject::VIEW)
 	|| objectExists(tabSetId, objectName, CegoObject::ALIAS);	
 }
 
-bool CegoObjectManager::objectExists(int tabSetId, const Chain& objectName, CegoObject::ObjectType type)
+bool CegoObjectManager::objectExists(unsigned tabSetId, const Chain& objectName, CegoObject::ObjectType type)
 {
     CegoBufferPage bp;
     unsigned long long lockId = 0;	    
@@ -1510,7 +1510,7 @@ bool CegoObjectManager::objectExists(int tabSetId, const Chain& objectName, Cego
 		while (pE && ! found )
 		{	    
 		    CegoObject oe;
-		    int entrySize;
+		    unsigned entrySize;
 		    oe.decodeBase(pE, entrySize);
 		    
 		    if ( tabSetId == oe.getTabSetId() )
@@ -1569,7 +1569,7 @@ bool CegoObjectManager::objectExists(int tabSetId, const Chain& objectName, Cego
     }
 }
 
-CegoDataPointer CegoObjectManager::insertData(CegoTableObject& oe, char* data, int dataSize, bool doAppend, bool allowWrite)
+CegoDataPointer CegoObjectManager::insertData(CegoTableObject& oe, char* data, unsigned dataSize, bool doAppend, bool allowWrite)
 {
     unsigned long long recLock = 0;
     unsigned long long lockId = 0;
@@ -1610,7 +1610,7 @@ CegoDataPointer CegoObjectManager::insertData(CegoTableObject& oe, char* data, i
 		while ( pE )
 		{
 		    CegoObject obj;
-		    int entrySize;
+		    unsigned entrySize;
 		    obj.decodeBase(pE, entrySize);
 		    		    
 		    if ( oe.getTabSetId() == obj.getTabSetId() 
@@ -1633,7 +1633,7 @@ CegoDataPointer CegoObjectManager::insertData(CegoTableObject& oe, char* data, i
 			
 			CegoDataPointer dp;
 			
-			int startPageId;
+			PageIdType startPageId;
 			
 			if ( doAppend )			    
 			{			
@@ -1725,7 +1725,7 @@ CegoDataPointer CegoObjectManager::insertData(CegoTableObject& oe, char* data, i
    Normally, this is used for index and temp objects.
  */
 
-CegoDataPointer CegoObjectManager::insertData( const CegoDataPointer& sysEntry, CegoTableObject& oe, char* data, int dataSize, bool doAppend, bool allowWrite)
+CegoDataPointer CegoObjectManager::insertData( const CegoDataPointer& sysEntry, CegoTableObject& oe, char* data, unsigned dataSize, bool doAppend, bool allowWrite)
 {		
     unsigned long long recLock = 0;
 
@@ -1742,7 +1742,7 @@ CegoDataPointer CegoObjectManager::insertData( const CegoDataPointer& sysEntry,
 
 	CegoDataPointer dp;
 	
-	int pageId;
+	PageIdType pageId;
 	
 	// int lockPageId = oe.getDataPageId();	       	    
 	
@@ -1794,7 +1794,7 @@ CegoDataPointer CegoObjectManager::insertData( const CegoDataPointer& sysEntry,
     }
 }
 
-void CegoObjectManager::deleteData(CegoObject::ObjectType type, int tabSetId, const CegoDataPointer& dp)
+void CegoObjectManager::deleteData(CegoObject::ObjectType type, unsigned tabSetId, const CegoDataPointer& dp)
 {
     CegoBufferPage bp;
     unsigned long long lockId = 0;
@@ -1825,7 +1825,7 @@ void CegoObjectManager::deleteData(CegoObject::ObjectType type, int tabSetId, co
     }
 }
 
-CegoObjectCursor* CegoObjectManager::getObjectCursor(int tabSetId, const Chain& hashName, const Chain& objName, CegoObject::ObjectType type)
+CegoObjectCursor* CegoObjectManager::getObjectCursor(unsigned tabSetId, const Chain& hashName, const Chain& objName, CegoObject::ObjectType type)
 {
     CegoBufferPage bp;
     unsigned long long lockId = 0;
@@ -1865,7 +1865,7 @@ CegoObjectCursor* CegoObjectManager::getObjectCursor(int tabSetId, const Chain&
 		while (pE && ! inserted )
 		{
 		    CegoObject obj;
-		    int entrySize;
+		    unsigned entrySize;
 		    
 		    obj.decodeBase(pE, entrySize);
 		    
@@ -1931,11 +1931,11 @@ CegoObjectCursor* CegoObjectManager::getObjectCursor(int tabSetId, const Chain&
     }
 }
 
-void CegoObjectManager::claimDataPtrUnlocked(int tabSetId, CegoBufferPool::FixMode fixMode, const CegoDataPointer& dp, char*& ptr, int& len, CegoBufferPage& bp)
+void CegoObjectManager::claimDataPtrUnlocked(unsigned tabSetId, CegoBufferPool::FixMode fixMode, const CegoDataPointer& dp, char*& ptr, unsigned& len, CegoBufferPage& bp)
 {     
     _pDBMng->bufferFix(bp, tabSetId, dp.getPageId(), fixMode, _pLockHandle);    
     ptr = (char*)bp.getPagePtr() + dp.getOffset();
-    len = *(int*)((long long)bp.getPagePtr() + (long)dp.getOffset() - sizeof(int));
+    len = *(unsigned*)((long long)bp.getPagePtr() + (long)dp.getOffset() - sizeof(unsigned));
 }
 
 void CegoObjectManager::releaseDataPtrUnlocked(CegoBufferPage& bp, bool isDirty)
@@ -1944,7 +1944,7 @@ void CegoObjectManager::releaseDataPtrUnlocked(CegoBufferPage& bp, bool isDirty)
 	_pDBMng->bufferUnfix(bp, isDirty, _pLockHandle);
 }
 
-void CegoObjectManager::releaseAndClaimDataPtrUnlocked(CegoBufferPage& bp, bool isDirty, int tabSetId, CegoBufferPool::FixMode fixMode, const CegoDataPointer& dp, char*& ptr, int& len, CegoBufferPage& nbp)
+void CegoObjectManager::releaseAndClaimDataPtrUnlocked(CegoBufferPage& bp, bool isDirty, unsigned tabSetId, CegoBufferPool::FixMode fixMode, const CegoDataPointer& dp, char*& ptr, unsigned& len, CegoBufferPage& nbp)
 {
     // do we have to unfix and fix ?
     if ( bp.getPageId() == dp.getPageId() )
@@ -1952,7 +1952,7 @@ void CegoObjectManager::releaseAndClaimDataPtrUnlocked(CegoBufferPage& bp, bool
 	// same page id, so we just setup
 	nbp = bp;
 	ptr = (char*)nbp.getPagePtr() + dp.getOffset();
-	len = *(int*)((long long)nbp.getPagePtr() + (long)dp.getOffset() - sizeof(int));
+	len = *(unsigned*)((long long)nbp.getPagePtr() + (long)dp.getOffset() - sizeof(unsigned));
     }
     else
     {
@@ -1961,7 +1961,7 @@ void CegoObjectManager::releaseAndClaimDataPtrUnlocked(CegoBufferPage& bp, bool
     }
 }
 
-void CegoObjectManager::freeObjectPages(int tabSetId, PageIdType pageId)
+void CegoObjectManager::freeObjectPages(unsigned tabSetId, PageIdType pageId)
 {
     bool lastPage = false;
 
@@ -1986,11 +1986,11 @@ void CegoObjectManager::freeObjectPages(int tabSetId, PageIdType pageId)
     }
 }
 
-int CegoObjectManager::traceObjectPages(int tabSetId, PageIdType pageId)
+unsigned CegoObjectManager::traceObjectPages(unsigned tabSetId, PageIdType pageId)
 {
     bool lastPage = false;
 
-    int pageCount = 0;
+    unsigned pageCount = 0;
     
     while ( ! lastPage )
     {	
@@ -2019,10 +2019,10 @@ int CegoObjectManager::traceObjectPages(int tabSetId, PageIdType pageId)
     return pageCount;
 }
 
-int CegoObjectManager::countObjectPages(int tabSetId, PageIdType pageId)
+unsigned CegoObjectManager::countObjectPages(unsigned tabSetId, PageIdType pageId)
 {
     bool lastPage = false;
-    int pageCount=0;
+    unsigned pageCount=0;
 
     while ( ! lastPage )
     {	
@@ -2041,7 +2041,7 @@ int CegoObjectManager::countObjectPages(int tabSetId, PageIdType pageId)
 
 	    pageCount++;
 
-	    int nextPageId = countPage.getNextPageId();
+	    PageIdType nextPageId = countPage.getNextPageId();
 
 	    _pDBMng->bufferUnfix(countPage, false, _pLockHandle);
 	    
@@ -2051,7 +2051,7 @@ int CegoObjectManager::countObjectPages(int tabSetId, PageIdType pageId)
     return pageCount;
 }
 
-void CegoObjectManager::removeEmptyPages(int tabSetId, PageIdType pageId, PageIdType& newPageId, PageIdType& newLastPageId)
+void CegoObjectManager::removeEmptyPages(unsigned tabSetId, PageIdType pageId, PageIdType& newPageId, PageIdType& newLastPageId)
 {
     bool lastPage = false;
     
@@ -2142,7 +2142,7 @@ void CegoObjectManager::removeEmptyPages(int tabSetId, PageIdType pageId, PageId
     }
 }
 
-CegoDataPointer CegoObjectManager::insertPageData(int tabSetId, CegoObject::ObjectType type, PageIdType pageId, char* data, int dataSize, bool& isNewPage, bool allowWrite, bool doAppend)
+CegoDataPointer CegoObjectManager::insertPageData(unsigned tabSetId, CegoObject::ObjectType type, PageIdType pageId, char* data, unsigned dataSize, bool& isNewPage, bool allowWrite, bool doAppend)
 {
     unsigned long long lockId = 0;
     CegoBufferPage bp;
@@ -2257,7 +2257,7 @@ CegoDataPointer CegoObjectManager::insertPageData(int tabSetId, CegoObject::Obje
     }
 }
 
-void CegoObjectManager::getNewFilePage(CegoBufferPage& bp, int tabSetId, CegoObject::ObjectType type, bool allowWrite, bool doAppend)
+void CegoObjectManager::getNewFilePage(CegoBufferPage& bp, unsigned tabSetId, CegoObject::ObjectType type, bool allowWrite, bool doAppend)
 {
     CegoBufferPool::FixMode fixMode;
     CegoFileHandler::FileType fileType;
@@ -2296,14 +2296,14 @@ void CegoObjectManager::getNewFilePage(CegoBufferPage& bp, int tabSetId, CegoObj
     _pDBMng->emptyFix(bp, tabSetId, fixMode, fileType, _pLockHandle, doAppend);
 }
 
-int CegoObjectManager::getPageCount(int tabSetId, const Chain& objName, CegoObject::ObjectType type)
+unsigned CegoObjectManager::getPageCount(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type)
 {
     CegoBufferPage bp;
     unsigned long long lockId = 0;
 	    
     try
     {
-	int pageCount=0;
+	unsigned pageCount=0;
 	bool notFound = true;
 
 	CegoBufferPool::FixMode lockMode;
@@ -2350,7 +2350,7 @@ int CegoObjectManager::getPageCount(int tabSetId, const Chain& objName, CegoObje
 		{		    
 		    CegoObject obj;
 		    
-		    int size;
+		    unsigned size;
 		    obj.decodeBase(pE, size);   
 
 		    bool typeMatch =  
@@ -2544,7 +2544,7 @@ void CegoObjectManager::createObject(const CegoDecodableObject& obj, PageIdType&
     }
 }
 
-void CegoObjectManager::alterObject(int tabSetId, const Chain& objName, CegoObject::ObjectType type, CegoDecodableObject& obj)
+void CegoObjectManager::alterObject(unsigned tabSetId, const Chain& objName, CegoObject::ObjectType type, CegoDecodableObject& obj)
 {
     unsigned long long lockId = 0;
     unsigned long long altLockId = 0;
@@ -2595,7 +2595,7 @@ void CegoObjectManager::alterObject(int tabSetId, const Chain& objName, CegoObje
 		while ( pE )
 		{	    
 		    CegoObject compObj;
-		    int entrySize;
+		    unsigned entrySize;
 		    
 		    compObj.decodeBase(pE, entrySize);   
 		    
