@@ -44,7 +44,7 @@ void CegoProcNoopStmt::cleanUp()
 {
 }
 
-Chain CegoProcNoopStmt::toChain(int defTabSetId, const Chain& indent) const
+Chain CegoProcNoopStmt::toChain(unsigned defTabSetId, const Chain& indent) const
 {
     Chain s;
     s = indent + Chain("noop");
