@@ -261,7 +261,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
     {
 	try
 	{
-	    int tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);    
+	    unsigned tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);    
 	    _pGTM->lockTable(tabSetId, _tableName);
 	}
 	catch ( Exception e )
@@ -275,7 +275,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
     {
 	try
 	{
-	    int tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
+	    unsigned tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
 	    _pGTM->unlockTable(tabSetId, _tableName);
 	}
 	catch ( Exception e )
@@ -301,7 +301,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	
 	try
 	{
-	    int tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
+	    unsigned tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
 	    if ( _pGTM->objectExists(tabSetId, _tableName, CegoObject::ALIAS ))
 	    {
 		CegoAliasObject ao;
@@ -499,7 +499,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	{
 	    // clean clobs and blobs
 	    
-	    int tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
+	    unsigned tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
 	    
 	    CegoField *pF = execSchema.First();
 	
@@ -543,7 +543,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 		}
 	    }
 	    
-	    int tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
+	    unsigned tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
 	    if ( _pGTM->objectExists(tabSetId, _tableName, CegoObject::ALIAS ))
 	    {
 		CegoAliasObject ae;
@@ -619,7 +619,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	    }
 	}
 	
-	int tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);    
+	unsigned tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);    
 	ListT<CegoField> fl;
 	bool moreTuple = false;
 	
@@ -689,7 +689,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	    {		    
 		// clean clobs and blobs
 		
-		int tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
+		unsigned tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
 		
 		ListT<CegoField> *pFLA = fva.First();
 		while ( pFLA )
@@ -753,7 +753,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 	    }
 
 	    CegoTableObject oe;
-	    int tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
+	    unsigned tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
 	    
 	    if ( _pGTM->objectExists(tabSetId, _tableName, CegoObject::ALIAS ))
 	    {
@@ -797,7 +797,7 @@ Chain CegoQuery::execute(CegoProcBlock *pBlock)
 		}
 	    }
 	    
-	    int tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
+	    unsigned tabSetId = _pGTM->getDBMng()->getTabSetId(_tableSet);
 	    if ( _pGTM->objectExists(tabSetId, _tableName, CegoObject::ALIAS ))
 	    {
 		CegoAliasObject ae;
@@ -970,7 +970,7 @@ long CegoQuery::getAffectedCount() const
     return _affCount;
 }
 
-Chain CegoQuery::toChain(int defTabSetId, const Chain& indent) const
+Chain CegoQuery::toChain(unsigned defTabSetId, const Chain& indent) const
 {
     Chain s;
     switch ( _mode )
