@@ -32,7 +32,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-int __dateLength;
+unsigned __dateLength;
 
 CegoQueryHelper::CegoQueryHelper()
 {
@@ -46,7 +46,7 @@ CegoQueryHelper::AttrCondMatch CegoQueryHelper::checkAttrCond(CegoAttrCond& ac,
 							    CegoPredicate* pP, 
 							    const ListT<CegoField>& schema,
 							    ListT<CegoField>* flArray, 
-							    int flSize, 
+							    unsigned flSize, 
 							    CegoProcBlock *pBlock)
 {
     AttrCondMatch m = evalAttrCond(ac, pP, schema, flArray, flSize, pBlock);
@@ -60,7 +60,7 @@ CegoQueryHelper::AttrCondMatch CegoQueryHelper::evalAttrCond(CegoAttrCond& ac,
 							     CegoPredicate* pP, 
 							     const ListT<CegoField>& schema,
 							     ListT<CegoField>* flArray, 
-							     int flSize, 
+							     unsigned flSize, 
 							     CegoProcBlock *pBlock)
 {
     if (pP->getCondition())
@@ -95,7 +95,7 @@ CegoQueryHelper::AttrCondMatch CegoQueryHelper::evalAttrCond(CegoAttrCond& ac,
 		      pAttrDesc1->getTableName() == Chain())
 		     && (Chain)pAttrDesc1->getAttrName() == (Chain)pF->getAttrName() )
 		{
-		    for ( int i=0; i<flSize; i++)
+		    for ( unsigned i=0; i<flSize; i++)
 		    {
 			CegoField* pFB = flArray[i].First();
 			while (pFB)
@@ -121,7 +121,7 @@ CegoQueryHelper::AttrCondMatch CegoQueryHelper::evalAttrCond(CegoAttrCond& ac,
 		      pAttrDesc2->getTableName() == Chain())
 		     && (Chain)pAttrDesc2->getAttrName() == (Chain)pF->getAttrName() )
 		{			
-		    for ( int i=0; i<flSize; i++)
+		    for ( unsigned i=0; i<flSize; i++)
 		    {
 			CegoField* pFB = flArray[i].First();
 			while (pFB)			   			    
@@ -520,7 +520,7 @@ CegoQueryHelper::AttrCondMatch CegoQueryHelper::evalAttrCond(CegoAttrCond& ac,
 
 		    if ( attrFound == false )
 		    {
-			for ( int i=0; i<flSize; i++)
+			for ( unsigned i=0; i<flSize; i++)
 			{
 			    CegoField* pFB = flArray[i].First();
 			    while (pFB)
@@ -592,7 +592,7 @@ CegoQueryHelper::AttrCondMatch CegoQueryHelper::evalAttrCondbyCondition(CegoAttr
 									CegoCondition* pC,
 									const ListT<CegoField>& schema,
 									ListT<CegoField>* flArray, 
-									int flSize, 
+									unsigned flSize, 
 									CegoProcBlock* pBlock)
 {
     
@@ -716,13 +716,13 @@ void CegoQueryHelper::createConjunctionList(CegoPredicate* pPred, ListT<CegoPred
     }
 }
 
-Chain CegoQueryHelper::condToChain(CegoCondition* pC, int depth)
+Chain CegoQueryHelper::condToChain(CegoCondition* pC, unsigned depth)
 {
     Chain s;
     if (pC->Left())
     {
 	s = predToChain(pC->Left(), depth+1);
-	for (int i=0;i<depth;i++)
+	for (unsigned i=0;i<depth;i++)
 	    s += Chain(" ");
 	switch(pC->getCondType())
 	{
@@ -740,7 +740,7 @@ Chain CegoQueryHelper::condToChain(CegoCondition* pC, int depth)
     return s;
 }
 
-Chain CegoQueryHelper::predToChain(CegoPredicate* pP, int depth)
+Chain CegoQueryHelper::predToChain(CegoPredicate* pP, unsigned depth)
 {
     Chain s;
 
@@ -752,7 +752,7 @@ Chain CegoQueryHelper::predToChain(CegoPredicate* pP, int depth)
     }
     else
     {
-	for (int i=0;i<depth;i++)
+	for (unsigned i=0;i<depth;i++)
 	    s+= Chain(" ");	
     }
     return s;    
@@ -803,7 +803,7 @@ void CegoQueryHelper::aggregateTuple(ListT<CegoField>& aggTuple, CegoAggregation
 
 	if ( fv.getType() == VARCHAR_TYPE )
 	{
-	    Chain msg = Chain("sum/avg not supported on datatype <") + CEGO_TYPE_MAP[ (int) fv.getType()] + Chain(">");
+	    Chain msg = Chain("sum/avg not supported on datatype <") + CEGO_TYPE_MAP[ (unsigned) fv.getType()] + Chain(">");
 	    throw Exception(EXLOC, msg);
 	}
 	
@@ -876,7 +876,7 @@ void CegoQueryHelper::aggregateTuple(ListT<CegoField>& aggTuple, CegoAggregation
     }
 }
 
-void CegoQueryHelper::prepareFieldValue(CegoField* pFV, CegoFieldValue& fv, CegoTableManager* pTM, int tabSetId)
+void CegoQueryHelper::prepareFieldValue(CegoField* pFV, CegoFieldValue& fv, CegoTableManager* pTM, unsigned tabSetId)
 {
     // first we check if the field is nullable and a value is given
     if ( pFV->isNullable() == false && fv.isNull() )
@@ -895,10 +895,10 @@ void CegoQueryHelper::prepareFieldValue(CegoField* pFV, CegoFieldValue& fv, Cego
 	if ( fv.castTo(pFV->getType(), pFV->getDim()) == false )
 	{
 	    throw Exception(EXLOC, Chain("Mismatched datatype <") 
-			    + CEGO_TYPE_MAP[(int)fv.getType()] 
+			    + CEGO_TYPE_MAP[(unsigned)fv.getType()] 
 			    + Chain("> for attribute ") + pFV->getAttrName() 
 			    + ", expected <" 
-			    + CEGO_TYPE_MAP[(int)pFV->getType()] + ">");
+			    + CEGO_TYPE_MAP[(unsigned)pFV->getType()] + ">");
 	}
     }    
     
@@ -957,15 +957,15 @@ void CegoQueryHelper::prepareFieldValue(CegoField* pFV, CegoFieldValue& fv, Cego
 	    
 	    Chain fixedVal = fv.valAsChain();
 	    
-	    int pos;
+	    unsigned long pos;
 	    if ( fixedVal.posStr(Chain("."), pos) == false )
 		throw Exception(EXLOC, Chain("Invalid decimal value <") + fixedVal + Chain(">"));
 	    
-	    int dim = fixedVal.length() - pos - 1;
+	    unsigned dim = fixedVal.length() - pos - 1;
 	    
 	    if ( dim < pFV->getDim() )
 	    {
-		int diff = pFV->getDim() - dim;
+		unsigned diff = pFV->getDim() - dim;
 		while ( diff > 0 )
 		{
 		    fixedVal = fixedVal + Chain("0");
@@ -974,7 +974,7 @@ void CegoQueryHelper::prepareFieldValue(CegoField* pFV, CegoFieldValue& fv, Cego
 	    }
 	    else if ( dim > pFV->getDim() )
 	    {
-		int diff = dim - pFV->getDim();
+		unsigned diff = dim - pFV->getDim();
 		fixedVal = fixedVal.subChain(1, fixedVal.length() - ( diff + 1) );
 	    }
 
@@ -983,7 +983,7 @@ void CegoQueryHelper::prepareFieldValue(CegoField* pFV, CegoFieldValue& fv, Cego
     }
 }
 
-bool CegoQueryHelper::checkIndexForPredicate(int tabSetId, CegoDistManager* pGTM, CegoPredicate *pPred, ListT<CegoContentObject*>& coList)
+bool CegoQueryHelper::checkIndexForPredicate(unsigned tabSetId, CegoDistManager* pGTM, CegoPredicate *pPred, ListT<CegoContentObject*>& coList)
 {  
     CegoCondition* pC = pPred->getCondition();	
     if (pC)
@@ -1013,9 +1013,9 @@ bool CegoQueryHelper::checkIndexForPredicate(int tabSetId, CegoDistManager* pGTM
 	    ListT<CegoCheckObject> checkList;
 	    ListT<CegoTriggerObject> triggerList;
 	    ListT<CegoAliasObject> aliasList;
-	    int numInvalid;
+	    unsigned numInvalid;
 
-	    int tsId;
+	    unsigned tsId;
 	    Chain tabName;
 	    CegoContentObject **pCO = coList.First();
 	    bool found=false;
@@ -1093,21 +1093,21 @@ bool CegoQueryHelper::checkIndexForPredicate(int tabSetId, CegoDistManager* pGTM
     return false;
 }
 
-void CegoQueryHelper::encodeFL(const ListT<CegoField>& fvl, char* &pBufBase, int &buflen)
+void CegoQueryHelper::encodeFL(const ListT<CegoField>& fvl, char* &pBufBase, unsigned &buflen)
 {
     CegoField* pF = fvl.First();
     while (pF)
     {
 	buflen += sizeof(CegoDataType); // datatype
-	buflen += sizeof(int); // datatype len
-	buflen += sizeof(int); // datatype dim
-	buflen += sizeof(int); // defaultvalue len
+	buflen += sizeof(unsigned); // datatype len
+	buflen += sizeof(unsigned); // datatype dim
+	buflen += sizeof(unsigned); // defaultvalue len
 
 	if ( pF->getValue().getLength() > 0 )
 	    buflen += pF->getValue().getLength();
 
 	buflen += sizeof(char); // isNullable
-	buflen += sizeof(int); // attr length
+	buflen += sizeof(unsigned); // attr length
 	buflen += pF->getAttrName().length(); // attr
 
 	pF = fvl.Next();
@@ -1125,26 +1125,26 @@ void CegoQueryHelper::encodeFL(const ListT<CegoField>& fvl, char* &pBufBase, int
     pF = fvl.First();
     while (pF)
     {
-	int attrLength =  pF->getAttrName().length();
+	unsigned attrLength =  (unsigned)pF->getAttrName().length();
 	CegoDataType dt = pF->getType();
 		
 	memcpy( pBuf, &dt, sizeof(CegoDataType));
 	pBuf += sizeof(CegoDataType);
 
-        int dtlen = pF->getLength();
+        unsigned dtlen = (unsigned)pF->getLength();
 	
-	memcpy( pBuf, &dtlen, sizeof(int));
-	pBuf += sizeof(int);
+	memcpy( pBuf, &dtlen, sizeof(unsigned));
+	pBuf += sizeof(unsigned);
 
-	int dim = pF->getDim();
+	unsigned dim = pF->getDim();
 	
-	memcpy( pBuf, &dim, sizeof(int));
-	pBuf += sizeof(int);
+	memcpy( pBuf, &dim, sizeof(unsigned));
+	pBuf += sizeof(unsigned);
 
-	int deflen = pF->getValue().getLength();
+	unsigned deflen = pF->getValue().getLength();
 
-	memcpy( pBuf, &deflen, sizeof(int));
-	pBuf += sizeof(int);
+	memcpy( pBuf, &deflen, sizeof(unsigned));
+	pBuf += sizeof(unsigned);
 
 	if ( deflen > 0 )
 	{
@@ -1159,8 +1159,8 @@ void CegoQueryHelper::encodeFL(const ListT<CegoField>& fvl, char* &pBufBase, int
 	memcpy( pBuf, &isNullable, sizeof(char));
 	pBuf += sizeof(char);
 	
-	memcpy( pBuf, &attrLength, sizeof(int));
-	pBuf += sizeof(int);
+	memcpy( pBuf, &attrLength, sizeof(unsigned));
+	pBuf += sizeof(unsigned);
 
 	memcpy( pBuf, (char*)pF->getAttrName(), attrLength);
 	pBuf += attrLength;
@@ -1169,7 +1169,7 @@ void CegoQueryHelper::encodeFL(const ListT<CegoField>& fvl, char* &pBufBase, int
     }
 }
 
-void CegoQueryHelper::decodeFL(ListT<CegoField>& fvl, char* pc, int len)
+void CegoQueryHelper::decodeFL(ListT<CegoField>& fvl, char* pc, unsigned len)
 {
     char *pBase = pc;
 
@@ -1179,19 +1179,19 @@ void CegoQueryHelper::decodeFL(ListT<CegoField>& fvl, char* pc, int len)
 	memcpy(&dt, pc, sizeof(CegoDataType));
 	pc += sizeof(CegoDataType);
 
-	int dtlen;
-	memcpy( &dtlen, pc, sizeof(int));
-	pc += sizeof(int);
+	unsigned dtlen;
+	memcpy( &dtlen, pc, sizeof(unsigned));
+	pc += sizeof(unsigned);
 
-	int dim;
-	memcpy( &dim, pc, sizeof(int));
-	pc += sizeof(int);
+	unsigned dim;
+	memcpy( &dim, pc, sizeof(unsigned));
+	pc += sizeof(unsigned);
 
 	CegoFieldValue defVal;
 
-	int deflen;
-	memcpy( &deflen, pc, sizeof(int));
-	pc += sizeof(int);
+	unsigned deflen;
+	memcpy( &deflen, pc, sizeof(unsigned));
+	pc += sizeof(unsigned);
 	if ( deflen > 0 )
 	{
 	    defVal = CegoFieldValue(dt, pc, deflen, false);
@@ -1202,9 +1202,9 @@ void CegoQueryHelper::decodeFL(ListT<CegoField>& fvl, char* pc, int len)
 	memcpy(&isNullable, pc, sizeof(char));
 	pc += sizeof(char);
 
-	int attrLength;
-	memcpy( &attrLength, pc, sizeof(int));
-	pc += sizeof(int);
+	unsigned attrLength;
+	memcpy( &attrLength, pc, sizeof(unsigned));
+	pc += sizeof(unsigned);
 	
 	Chain attrName(pc, attrLength-1);
 	pc += attrLength;
@@ -1215,24 +1215,24 @@ void CegoQueryHelper::decodeFL(ListT<CegoField>& fvl, char* pc, int len)
     }
 }
 
-int CegoQueryHelper::encodeFVL(unsigned long long tid, unsigned long long tastep, CegoTupleState ts, const ListT<CegoField>& fvl, char* &pBufBase, int& buflen)
+unsigned CegoQueryHelper::encodeFVL(unsigned long long tid, unsigned long long tastep, CegoTupleState ts, const ListT<CegoField>& fvl, char* &pBufBase, unsigned& buflen)
 {
     ListT<CegoBlob> blobList;
     ListT<CegoClob> clobList;    
     return encodeFVL(tid, tastep, ts, fvl, blobList, clobList, pBufBase, buflen);
 }
 
-int CegoQueryHelper::encodeFVL(unsigned long long tid, unsigned long long tastep, CegoTupleState ts, const ListT<CegoField>& fvl, const ListT<CegoBlob>& blobList, const ListT<CegoClob>& clobList, char* &pBufBase, int& buflen)
+unsigned CegoQueryHelper::encodeFVL(unsigned long long tid, unsigned long long tastep, CegoTupleState ts, const ListT<CegoField>& fvl, const ListT<CegoBlob>& blobList, const ListT<CegoClob>& clobList, char* &pBufBase, unsigned& buflen)
 {
-    int enclen = skipTupleHeader();
+    unsigned enclen = skipTupleHeader();
 
-    int blobIdx = 0;
-    int clobIdx = 0;
+    unsigned blobIdx = 0;
+    unsigned clobIdx = 0;
     
     CegoField* pF = fvl.First();
     while (pF)
     {
-	int l =  pF->getValue().getLength();
+	unsigned l =  (unsigned)pF->getValue().getLength();
 	CegoDataType dt = pF->getValue().getType();
 	
 	// force null type in case of fv length and value constraints 
@@ -1241,7 +1241,7 @@ int CegoQueryHelper::encodeFVL(unsigned long long tid, unsigned long long tastep
 		
 	if ( dt != NULL_TYPE )
 	{
-	    enclen += sizeof(int); // id
+	    enclen += sizeof(unsigned); // id
 	    enclen += sizeof(CegoDataType);
 
 	    if ( dt == BLOB_TYPE && blobList.Size() > 0)
@@ -1271,7 +1271,7 @@ int CegoQueryHelper::encodeFVL(unsigned long long tid, unsigned long long tastep
 	pF = fvl.Next();
     }
 
-    enclen += sizeof(int); // terminating id
+    enclen += sizeof(unsigned); // terminating id
 
     if ( enclen > buflen )
     {
@@ -1288,7 +1288,7 @@ int CegoQueryHelper::encodeFVL(unsigned long long tid, unsigned long long tastep
 
     char *pBuf = pBufBase;
 
-    int toff = encodeTupleHeader(tid, tastep, ts, pBuf);
+    unsigned toff = encodeTupleHeader(tid, tastep, ts, pBuf);
     pBuf += toff;
 
     blobIdx = 0;
@@ -1297,8 +1297,8 @@ int CegoQueryHelper::encodeFVL(unsigned long long tid, unsigned long long tastep
     pF = fvl.First();
     while (pF)
     {
-	int id =  pF->getId();
-	int l =  pF->getValue().getLength();
+	unsigned id =  pF->getId();
+	unsigned l =  (unsigned)pF->getValue().getLength();
 	CegoDataType dt = pF->getValue().getType();
 
 	// force null type in case of fv length and value constraints 
@@ -1307,8 +1307,8 @@ int CegoQueryHelper::encodeFVL(unsigned long long tid, unsigned long long tastep
 	
 	if ( dt != NULL_TYPE )
 	{
-	    memcpy( pBuf, &id, sizeof(int));
-	    pBuf += sizeof(int);
+	    memcpy( pBuf, &id, sizeof(unsigned));
+	    pBuf += sizeof(unsigned);
 	    
 	    memcpy( pBuf, &dt, sizeof(CegoDataType));
 	    pBuf += sizeof(CegoDataType);
@@ -1337,8 +1337,8 @@ int CegoQueryHelper::encodeFVL(unsigned long long tid, unsigned long long tastep
 		     || dt == BIGINT_TYPE 
 		     || dt == DECIMAL_TYPE )
 		{
-		    memcpy( pBuf, &l, sizeof(int));
-		    pBuf += sizeof(int);
+		    memcpy( pBuf, &l, sizeof(unsigned));
+		    pBuf += sizeof(unsigned);
 		}
 
 		memcpy( pBuf, pF->getValue().getValue(), l);	
@@ -1350,20 +1350,20 @@ int CegoQueryHelper::encodeFVL(unsigned long long tid, unsigned long long tastep
 	pF = fvl.Next();
     }
 
-    int termId=0;
-    memcpy( pBuf, &termId, sizeof(int));
+    unsigned termId=0;
+    memcpy( pBuf, &termId, sizeof(unsigned));
 
     return enclen;
 }
 
 // for performance reasons, we also provide a method to just return the 
 // tuple header len
-int CegoQueryHelper::skipTupleHeader()
+unsigned CegoQueryHelper::skipTupleHeader()
 {
     return sizeof(unsigned long long) + sizeof(unsigned long long) + sizeof(CegoTupleState);
 }
 
-int CegoQueryHelper::encodeTupleHeader(unsigned long long tid, unsigned long long tastep, CegoTupleState ts, char* p)
+unsigned CegoQueryHelper::encodeTupleHeader(unsigned long long tid, unsigned long long tastep, CegoTupleState ts, char* p)
 {
     memcpy(p, &tid, sizeof(unsigned long long));
     p += sizeof(unsigned long long);
@@ -1374,7 +1374,7 @@ int CegoQueryHelper::encodeTupleHeader(unsigned long long tid, unsigned long lon
     return sizeof(unsigned long long) + sizeof(unsigned long long) + sizeof(CegoTupleState);
 }
 
-int CegoQueryHelper::decodeTupleHeader(unsigned long long& tid, unsigned long long& tastep, CegoTupleState& ts, char* p)
+unsigned CegoQueryHelper::decodeTupleHeader(unsigned long long& tid, unsigned long long& tastep, CegoTupleState& ts, char* p)
 {
     memcpy(&tid, p, sizeof(unsigned long long));
 
@@ -1387,7 +1387,7 @@ int CegoQueryHelper::decodeTupleHeader(unsigned long long& tid, unsigned long lo
     return sizeof(unsigned long long) + sizeof(unsigned long long) + sizeof(CegoTupleState);
 }
 
-void CegoQueryHelper::decodeFVL(ListT<CegoField>& fvl, char* pc, int len)
+void CegoQueryHelper::decodeFVL(ListT<CegoField>& fvl, char* pc, unsigned len)
 {        
     char* pBase = pc;
     bool eot = false;
@@ -1396,26 +1396,26 @@ void CegoQueryHelper::decodeFVL(ListT<CegoField>& fvl, char* pc, int len)
     
     while (pF && pc - pBase < len && eot == false)
     {
-	int id;     
-	memcpy(&id, pc, sizeof(int));
+	unsigned id;     
+	memcpy(&id, pc, sizeof(unsigned));
 	
 	if ( id > 0 )
 	{	    
-	    pc += sizeof(int);
+	    pc += sizeof(unsigned);
 	    
 	    CegoDataType dt;
 	    memcpy(&dt, pc, sizeof(CegoDataType));
 	    
 	    pc += sizeof(CegoDataType);
 	    
-	    int flen;
+	    unsigned flen;
 	    
 	    if (dt == VARCHAR_TYPE
 		|| dt == BIGINT_TYPE
 		|| dt == DECIMAL_TYPE )
 	    {
-		memcpy(&flen, pc, sizeof(int));
-		pc += sizeof(int);
+		memcpy(&flen, pc, sizeof(unsigned));
+		pc += sizeof(unsigned);
 	    }
 	    else
 	    {
@@ -1455,7 +1455,7 @@ void CegoQueryHelper::decodeFVL(ListT<CegoField>& fvl, char* pc, int len)
 }
 
 /* field list decoding with included blob decoding. This is used by the recovery manager for redo log recovery  */
-void CegoQueryHelper::decodeFVL(ListT<CegoField>& fvl, ListT<CegoBlob>& blobList, ListT<CegoClob>& clobList, char* pc, int len)
+void CegoQueryHelper::decodeFVL(ListT<CegoField>& fvl, ListT<CegoBlob>& blobList, ListT<CegoClob>& clobList, char* pc, unsigned len)
 {    
     // make sure no field values are set
     CegoField* pF = fvl.First(); 
@@ -1471,18 +1471,18 @@ void CegoQueryHelper::decodeFVL(ListT<CegoField>& fvl, ListT<CegoBlob>& blobList
     bool eot = false;
     while (pc - pBase < len && eot == false )
     {
-	int id;
-	memcpy(&id, pc, sizeof(int));
+	unsigned id;
+	memcpy(&id, pc, sizeof(unsigned));
 
 	if ( id > 0 )
 	{
-	    pc += sizeof(int);
+	    pc += sizeof(unsigned);
 	    
 	    CegoDataType dt;
 	    memcpy(&dt, pc, sizeof(CegoDataType));
 	    pc += sizeof(CegoDataType);
 	    
-	    int flen=0;
+	    unsigned flen=0;
 	    unsigned long long blobSize=0;
 	    unsigned long long clobSize=0;
 	    
@@ -1490,8 +1490,8 @@ void CegoQueryHelper::decodeFVL(ListT<CegoField>& fvl, ListT<CegoBlob>& blobList
 		|| dt == BIGINT_TYPE
 		|| dt == DECIMAL_TYPE )	    
 	    {
-		memcpy(&flen, pc, sizeof(int));
-		pc += sizeof(int);
+		memcpy(&flen, pc, sizeof(unsigned));
+		pc += sizeof(unsigned);
 	    }
 	    else if (dt == BLOB_TYPE )
 	    {
@@ -1575,26 +1575,26 @@ void CegoQueryHelper::decodeFVL(ListT<CegoField>& fvl, ListT<CegoBlob>& blobList
     }
 }
 
-void CegoQueryHelper::decodeNativeFVL(ListT<CegoFieldValue>& fvl, ListT<CegoBlob>& blobList, ListT<CegoClob>& clobList, char* pc, int len)
+void CegoQueryHelper::decodeNativeFVL(ListT<CegoFieldValue>& fvl, ListT<CegoBlob>& blobList, ListT<CegoClob>& clobList, char* pc, unsigned len)
 {
     char* pBase = pc;
 
     bool eot = false;    
     while (pc - pBase < len && eot == false)
     {		    
-	int id;
-	memcpy(&id, pc, sizeof(int));
+	unsigned id;
+	memcpy(&id, pc, sizeof(unsigned));
 
 	if ( id > 0 )
 	{       
-	    pc += sizeof(int);
+	    pc += sizeof(unsigned);
 	    
 	    CegoDataType dt;
 	    memcpy(&dt, pc, sizeof(CegoDataType));
 	    
 	    pc += sizeof(CegoDataType);
 	    
-	    int flen=0;
+	    unsigned flen=0;
 	    unsigned long long blobSize=0;
 	    unsigned long long clobSize=0;
 	    
@@ -1602,8 +1602,8 @@ void CegoQueryHelper::decodeNativeFVL(ListT<CegoFieldValue>& fvl, ListT<CegoBlob
 		|| dt == BIGINT_TYPE
 		|| dt == DECIMAL_TYPE )	    
 	    {
-		memcpy(&flen, pc, sizeof(int));
-		pc += sizeof(int);
+		memcpy(&flen, pc, sizeof(unsigned));
+		pc += sizeof(unsigned);
 	    }
 	    else if (dt == BLOB_TYPE )
 	    {
@@ -1672,14 +1672,14 @@ void CegoQueryHelper::encodeUpdRec(const Chain& tableAlias,
 				   const ListT<CegoClob>& clobList,
 				   bool returnOnFirst,
 				   CegoProcBlock* pBlock,
-				   char* &pBuf, int &buflen)
+				   char* &pBuf, unsigned &buflen)
 {
     char* updBuf;
-    int updBufLen = 0;
+    unsigned updBufLen = 0;
     char* predBuf;
-    int predBufLen = 0;
+    unsigned predBufLen = 0;
     char* expBuf;
-    int expBufLen = 0;
+    unsigned expBufLen = 0;
 
     if ( pPred )
     {
@@ -1702,8 +1702,8 @@ void CegoQueryHelper::encodeUpdRec(const Chain& tableAlias,
     encodeFL(updList, updBuf, updBufLen);
 
     expBufLen = 0;
-    int blobIdx=0;
-    int clobIdx=0;
+    unsigned blobIdx=0;
+    unsigned clobIdx=0;
     
     CegoExpr **pExpr = exprList.First();
     while ( pExpr )
@@ -1788,20 +1788,20 @@ void CegoQueryHelper::encodeUpdRec(const Chain& tableAlias,
 	pExpr = exprList.Next();
     }
 
-    int aliasLen = tableAlias.length();
+    unsigned aliasLen = tableAlias.length();
 
     buflen = predBufLen
-	+ sizeof(int) + aliasLen
-	+ sizeof(int) + updBufLen
-	+ sizeof(int) + expBufLen
+	+ sizeof(unsigned) + aliasLen
+	+ sizeof(unsigned) + updBufLen
+	+ sizeof(unsigned) + expBufLen
 	+ sizeof(bool); // returnOnFirst
 
     pBuf = (char*)malloc(buflen);
 
     char* pBP = pBuf;
 
-    memcpy(pBP, &aliasLen, sizeof(int));
-    pBP = pBP + sizeof(int);
+    memcpy(pBP, &aliasLen, sizeof(unsigned));
+    pBP = pBP + sizeof(unsigned);
 
     memcpy( pBP, (char*)tableAlias, aliasLen);
     pBP = pBP + aliasLen;
@@ -1809,14 +1809,14 @@ void CegoQueryHelper::encodeUpdRec(const Chain& tableAlias,
     memcpy(pBP, predBuf, predBufLen);
     pBP = pBP + predBufLen;
     
-    memcpy(pBP, &updBufLen, sizeof(int));
-    pBP = pBP + sizeof(int);
+    memcpy(pBP, &updBufLen, sizeof(unsigned));
+    pBP = pBP + sizeof(unsigned);
 
     memcpy(pBP, updBuf, updBufLen);
     pBP = pBP + updBufLen;
 
-    memcpy(pBP, &expBufLen, sizeof(int));
-    pBP = pBP + sizeof(int);
+    memcpy(pBP, &expBufLen, sizeof(unsigned));
+    pBP = pBP + sizeof(unsigned);
     
     memcpy(pBP, expBuf, expBufLen);
     pBP = pBP + expBufLen;
@@ -1834,12 +1834,12 @@ void CegoQueryHelper::decodeUpdRec(Chain& tableAlias,
 				   ListT<CegoField>& updList, 
 				   ListT<CegoExpr*>& exprList,
 				   bool& returnOnFirst,
-				   char* pBuf, int buflen,
-				   CegoDistManager *pGTM, int tabSetId)
+				   char* pBuf, unsigned buflen,
+				   CegoDistManager *pGTM, unsigned tabSetId)
 {
-    int aliasLen;
-    memcpy(&aliasLen, pBuf, sizeof(int));
-    pBuf += sizeof(int);
+    unsigned aliasLen;
+    memcpy(&aliasLen, pBuf, sizeof(unsigned));
+    pBuf += sizeof(unsigned);
 
     tableAlias = Chain(pBuf, aliasLen-1);
     pBuf += aliasLen;
@@ -1858,17 +1858,17 @@ void CegoQueryHelper::decodeUpdRec(Chain& tableAlias,
 	pPred = 0;
     }
 
-    int updBufLen;
-    memcpy(&updBufLen, pBuf, sizeof(int));
-    pBuf += sizeof(int);
+    unsigned updBufLen;
+    memcpy(&updBufLen, pBuf, sizeof(unsigned));
+    pBuf += sizeof(unsigned);
 
     decodeFL(updList, pBuf, updBufLen);
 
     pBuf += updBufLen;
 
-    int expBufLen;
-    memcpy(&expBufLen, pBuf, sizeof(int));
-    pBuf += sizeof(int);
+    unsigned expBufLen;
+    memcpy(&expBufLen, pBuf, sizeof(unsigned));
+    pBuf += sizeof(unsigned);
 
     int pos = 0;
     while ( pos < expBufLen  )
@@ -1898,7 +1898,7 @@ void CegoQueryHelper::decodeUpdRec(Chain& tableAlias,
 	    
 	    exprList.Insert(pExpr);
 	    
-	    int len = sizeof(unsigned long long) + blobSize;
+	    unsigned len = sizeof(unsigned long long) + blobSize;
 	    pos += len;
 	    pBuf += len;		
 
@@ -1923,7 +1923,7 @@ void CegoQueryHelper::decodeUpdRec(Chain& tableAlias,
 	    
 	    exprList.Insert(pExpr);
 	    
-	    int len = sizeof(unsigned long long) + clobSize;
+	    unsigned len = sizeof(unsigned long long) + clobSize;
 	    pos += len;
 	    pBuf += len;
 	}
@@ -1931,7 +1931,7 @@ void CegoQueryHelper::decodeUpdRec(Chain& tableAlias,
 	{
 	    CegoExpr *pExpr = new CegoExpr(pBuf, pGTM, 0, tabSetId);
 	    
-	    int len = pExpr->getEncodingLength(0);
+	    unsigned len = pExpr->getEncodingLength(0);
 	    pos += len;
 	    pBuf += len;
 	    
@@ -1945,11 +1945,11 @@ void CegoQueryHelper::decodeUpdRec(Chain& tableAlias,
 void CegoQueryHelper::encodeDelRec(const Chain& tableAlias,
 				   CegoPredicate* pPred,
 				   CegoProcBlock* pBlock,
-				   char* &pBuf, int &buflen)
+				   char* &pBuf, unsigned &buflen)
 
 {
     char* predBuf;
-    int predBufLen = 0;
+    unsigned predBufLen = 0;
 
     if ( pPred )
     {
@@ -1970,17 +1970,17 @@ void CegoQueryHelper::encodeDelRec(const Chain& tableAlias,
 	memcpy(predBuf, &c, sizeof(char));
     }
 
-    int aliasLen = tableAlias.length();
+    unsigned aliasLen = (unsigned)tableAlias.length();
 
     buflen = predBufLen
-	+ sizeof(int) + aliasLen;
+	+ sizeof(unsigned) + aliasLen;
     
     pBuf = (char*)malloc(buflen);
 
     char* pBP = pBuf;
 
-    memcpy(pBP, &aliasLen, sizeof(int));
-    pBP = pBP + sizeof(int);
+    memcpy(pBP, &aliasLen, sizeof(unsigned));
+    pBP = pBP + sizeof(unsigned);
 
     memcpy( pBP, (char*)tableAlias, aliasLen);
     pBP = pBP + aliasLen;
@@ -1993,12 +1993,12 @@ void CegoQueryHelper::encodeDelRec(const Chain& tableAlias,
 
 void CegoQueryHelper::decodeDelRec(Chain& tableAlias,
 				   CegoPredicate* &pPred,
-				   char* pBuf, int buflen,
-				   CegoDistManager *pGTM, int tabSetId)
+				   char* pBuf, unsigned buflen,
+				   CegoDistManager *pGTM, unsigned tabSetId)
 {        
-    int aliasLen;
-    memcpy(&aliasLen, pBuf, sizeof(int));
-    pBuf += sizeof(int);
+    unsigned aliasLen;
+    memcpy(&aliasLen, pBuf, sizeof(unsigned));
+    pBuf += sizeof(unsigned);
     
     tableAlias = Chain(pBuf, aliasLen-1);
     pBuf += aliasLen;
@@ -2042,7 +2042,7 @@ void CegoQueryHelper::createConjunctionList(CegoPredicate* pPred, ListT<CegoPred
     }
 }
 
-bool CegoQueryHelper::string2Clob(CegoFieldValue& fv, CegoTableManager* pTM, int tabSetId)
+bool CegoQueryHelper::string2Clob(CegoFieldValue& fv, CegoTableManager* pTM, unsigned tabSetId)
 {
     if ( fv.getType() == VARCHAR_TYPE && pTM )
     {
@@ -2062,11 +2062,11 @@ bool CegoQueryHelper::string2Clob(CegoFieldValue& fv, CegoTableManager* pTM, int
 Chain CegoQueryHelper::skipComment(Chain& line)
 {
     Chain result;    
-    int pos=0;
+    unsigned pos=0;
     bool stringMode=false;
     bool commentFound=false;
     
-    while ( pos < (int)line.length() && commentFound == false)
+    while ( pos < (unsigned)line.length() && commentFound == false)
     {
 	if ( line[pos] == '\''  )
 	{
@@ -2109,7 +2109,7 @@ Chain CegoQueryHelper::skipComment(Chain& line)
 
 bool CegoQueryHelper::hasOpenString(Chain& line)
 {
-    int pos=0;
+    unsigned pos=0;
     bool stringMode=false;
     while ( pos < (int)line.length())
     {
@@ -2233,7 +2233,8 @@ CegoAttrCond CegoQueryHelper::mapAttrCond(const CegoAttrCond& attrCond, CegoAlia
     return mapCond;
 }
 
-void CegoQueryHelper::mapFLA(ListT<CegoField>* pFLAmap, ListT<CegoField>** pFLA, int offset, int size, CegoAliasObject* pAO)
+void CegoQueryHelper::mapFLA(ListT<CegoField>* pFLAmap, ListT<CegoField>** pFLA,
+			     unsigned offset, unsigned size, CegoAliasObject* pAO)
 {
     pFLAmap->Empty();
 	
@@ -2258,7 +2259,7 @@ void CegoQueryHelper::mapFLA(ListT<CegoField>* pFLAmap, ListT<CegoField>** pFLA,
     }
 }
 
-void CegoQueryHelper::propFLA(ListT<CegoField>* pFLAmap, ListT<CegoField>** pFLA, int offset, int size, CegoAliasObject* pAO)
+void CegoQueryHelper::propFLA(ListT<CegoField>* pFLAmap, ListT<CegoField>** pFLA, unsigned offset, unsigned size, CegoAliasObject* pAO)
 {
     pFLA[offset]->Empty();
     
@@ -2278,9 +2279,9 @@ void CegoQueryHelper::propFLA(ListT<CegoField>* pFLAmap, ListT<CegoField>** pFLA
     }
 }
 
-int CegoQueryHelper::maxFieldSize(CegoField *pF)
+unsigned CegoQueryHelper::maxFieldSize(CegoField *pF)
 {
-    int maxLen = 0;
+    unsigned maxLen = 0;
     
     switch ( pF->getType() )
     {
@@ -2402,9 +2403,9 @@ int CegoQueryHelper::maxFieldSize(CegoField *pF)
     return maxLen;    
 }
 
-int CegoQueryHelper::max(int i1, int i2, int i3, int i4)
+unsigned CegoQueryHelper::max(unsigned i1, unsigned i2, unsigned i3, unsigned i4)
 {
-    int c1 =  i1 < i2 ? i2 : i1 ;
-    int c2 =  i3 < i4 ? i4 : i3 ;
+    unsigned c1 =  i1 < i2 ? i2 : i1 ;
+    unsigned c2 =  i3 < i4 ? i4 : i3 ;
     return c1 < c2 ? c2 : c1 ;
 }
