@@ -637,7 +637,7 @@ CegoRecoveryManager::RecoveryState CegoRecoveryManager::recoverCurrentTransactio
 			CegoViewObject vo;
 			vo.decode(logRec.getData());
 			_pGTM->createViewObject(vo);
-			_pDBMng->addObject(tabSetId, logRec.getObjName(), CegoObject::VIEW);
+			_pDBMng->addObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;		    
 		    }
 		    case CegoObject::PROCEDURE:
@@ -645,7 +645,7 @@ CegoRecoveryManager::RecoveryState CegoRecoveryManager::recoverCurrentTransactio
 			CegoProcObject po;
 			po.decode(logRec.getData());
 			_pGTM->createProcObject(po);
-			_pDBMng->addObject(tabSetId, logRec.getObjName(), CegoObject::PROCEDURE);
+			_pDBMng->addObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;		    
 		    }
 		    case CegoObject::FKEY:
@@ -653,7 +653,7 @@ CegoRecoveryManager::RecoveryState CegoRecoveryManager::recoverCurrentTransactio
 			CegoKeyObject ko;
 			ko.decode(logRec.getData());
 			_pGTM->createKeyObject(ko);
-			_pDBMng->addObject(tabSetId, logRec.getObjName(), CegoObject::FKEY);
+			_pDBMng->addObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    }
 		    case CegoObject::CHECK:
@@ -661,17 +661,23 @@ CegoRecoveryManager::RecoveryState CegoRecoveryManager::recoverCurrentTransactio
 			CegoCheckObject co;
 			co.decode(logRec.getData());
 			_pGTM->createCheckObject(co);
-			_pDBMng->addObject(tabSetId, logRec.getObjName(), CegoObject::CHECK);
+			_pDBMng->addObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    }
 		    case CegoObject::TRIGGER:
 		    {
-			// TODO
+			CegoTriggerObject to;
+			to.decode(logRec.getData());
+			_pGTM->createTriggerObject(to);
+			_pDBMng->addObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    }
 		    case CegoObject::ALIAS:
 		    {
-			// TODO
+			CegoAliasObject ao;
+			ao.decode(logRec.getData());
+			_pGTM->createAliasObject(ao);
+			_pDBMng->addObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    }
 		    case CegoObject::RBSEG:
@@ -688,34 +694,43 @@ CegoRecoveryManager::RecoveryState CegoRecoveryManager::recoverCurrentTransactio
 		    {
 		    case CegoObject::TABLE:
 			_pGTM->dropTable(tabSetId, logRec.getObjName());
+			_pDBMng->removeObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    case CegoObject::AVLTREE:
 		    case CegoObject::UAVLTREE:
 		    case CegoObject::PAVLTREE:
 			_pGTM->dropIndex(tabSetId, logRec.getObjName());
+			_pDBMng->removeObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    case CegoObject::BTREE:
 		    case CegoObject::UBTREE:
 		    case CegoObject::PBTREE:
 			_pGTM->dropBTree(tabSetId, logRec.getObjName());
+			_pDBMng->removeObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    case CegoObject::VIEW:
 			_pGTM->dropView(tabSetId, logRec.getObjName());
+			_pDBMng->removeObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    case CegoObject::PROCEDURE:
 			_pGTM->dropProcedure(tabSetId, logRec.getObjName());
+			_pDBMng->removeObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    case CegoObject::FKEY:
 			_pGTM->dropFKey(tabSetId, logRec.getObjName());
+			_pDBMng->removeObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    case CegoObject::CHECK:
 			_pGTM->dropCheck(tabSetId, logRec.getObjName());
+			_pDBMng->removeObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    case CegoObject::TRIGGER:
 			_pGTM->dropTrigger(tabSetId, logRec.getObjName());
+			_pDBMng->removeObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    case CegoObject::ALIAS:
 			_pGTM->dropAlias(tabSetId, logRec.getObjName());
+			_pDBMng->removeObject(tabSetId, logRec.getObjName(), logRec.getObjType());
 			break;
 		    case CegoObject::SYSTEM:
 		    case CegoObject::RBSEG:
