@@ -36,7 +36,7 @@
 #include <string.h>
 #include <stdlib.h>
 
-CegoSelect::CegoSelect(char* buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, int tabSetId)
+CegoSelect::CegoSelect(char* buf, CegoDistManager* pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _pPred = 0;
     _pNativeOrderList = 0;
@@ -53,7 +53,7 @@ CegoSelect::CegoSelect(char* buf, CegoDistManager* pGTM, CegoProcBlock *pBlock,
 
     _modId = 0;
 
-    int i=0;
+    unsigned i=0;
     while ( i < TABMNG_MAXJOINLEVEL )
     {
 	_joinBuf[i] = 0;
@@ -102,7 +102,7 @@ CegoSelect::CegoSelect(ListT<CegoContentObject*>& coList,
 		       ListT<CegoExpr*> *pOrderList,
 		       ListT<CegoOrderNode::Ordering>* pOrderOptList,
 		       bool isDistinct,
-		       int rowLimit,
+		       unsigned rowLimit,
 		       CegoDistManager* pGTM)
 {
     _coList = coList;
@@ -129,7 +129,7 @@ CegoSelect::CegoSelect(ListT<CegoContentObject*>& coList,
 	_modId = _pGTM->getDBMng()->getModId("CegoSelect");
     }
     
-    int i=0;
+    unsigned i=0;
     while ( i < TABMNG_MAXJOINLEVEL )
     {
 	_joinBuf[i] = 0;
@@ -186,7 +186,7 @@ CegoSelect::~CegoSelect()
 	pP = _viewConjunctionList.Next();
     }
     
-    int i=0;
+    unsigned i=0;
     while ( i < TABMNG_MAXJOINLEVEL )
     {
 	if ( _pTC[i] )
@@ -298,7 +298,7 @@ void CegoSelect::setTableManager(CegoDistManager* pGTM)
     }
 }
 
-void CegoSelect::setTabSetId(int tabSetId)
+void CegoSelect::setTabSetId(unsigned tabSetId)
 {
     _tabSetId = tabSetId;
 
@@ -378,7 +378,7 @@ void CegoSelect::cleanUp()
         pExpr = _exprList.Next();
     }
     
-    int i = 0;
+    unsigned i = 0;
     while ( i < TABMNG_MAXJOINLEVEL )
     {
 	if ( _pTC[i] )	
@@ -535,7 +535,7 @@ void CegoSelect::reset()
 	    _pGroupSpace->resetGroupSpace();
     }
 	
-    int i=0;
+    unsigned i=0;
 
     while ( i <= _joinLevel )
     {
@@ -912,7 +912,7 @@ bool CegoSelect::nextTuple(ListT<CegoField>& jfl)
 	{	    
 	    jfl = _cacheSchema;
 	    CegoField *pF = jfl.First();
-	    int pos=0;
+	    unsigned pos=0;
 	    while ( pF )
 	    {
 		pF->setValue(*pCacheRow[pos]);
@@ -945,7 +945,7 @@ bool CegoSelect::nextTuple(ListT<CegoField>& jfl)
 			pF = jfl.Next();
 		    }
 
-		    if ( _pCache->getMaxSize() > (int)_cacheEntrySize )
+		    if ( _pCache->getMaxSize() > (unsigned)_cacheEntrySize )
 		    {
 			_pCacheList->Insert(staticFieldList);
 		    }
@@ -983,7 +983,7 @@ bool CegoSelect::nextTuple(ListT<CegoField>& jfl)
 			pF = jfl.Next();
 		    }
 
-		    if ( _pCache->getMaxSize() > (int)_cacheEntrySize )
+		    if ( _pCache->getMaxSize() > (unsigned)_cacheEntrySize )
 		    {
 			_pCacheList->Insert(staticFieldList);
 		    }
@@ -1073,7 +1073,7 @@ void CegoSelect::finishCaching()
     
     _execTime.stop();
     // get queryTime in msec 
-    int queryTime = (int) ( _execTime.getSum()  / 1000000 );
+    unsigned queryTime = (unsigned) ( _execTime.getSum()  / 1000000 );
     
     if ( hasForeign == false && queryId != Chain(MOD_QUERY_ID) && _pCache->getThreshold() <= queryTime )
     {
@@ -1096,7 +1096,7 @@ Chain CegoSelect::getQueryId() const
 	
 	if ( _pParentJoinBuf && _extRefCount > 0 )
 	{
-	    int i=0;
+	    unsigned i=0;
 	    while ( _pParentJoinBuf[i] )
 	    {
 		CegoField *pF = _pParentJoinBuf[i]->First();
@@ -1373,7 +1373,7 @@ bool CegoSelect::nextOrderedTuple(ListT<CegoField>& jfl)
 		{
 		    CegoField* pF1=_dfl.First();
 		    CegoField* pF2=jfl.First();
-		    int i=0;
+		    unsigned i=0;
 		    while ( pF1 && pF2 && i < _dcount )
 		    {
 			if ( pF1->getValue() != pF2->getValue() )
@@ -1889,7 +1889,7 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 		}
 		else
 		{
-		    int i=0;
+		    unsigned i=0;
 		    while ( i < TABMNG_MAXJOINLEVEL )
 		    {			
 			if ( _pTC[i] )
@@ -1954,7 +1954,7 @@ bool CegoSelect::nextJoinTuple(ListT<CegoField>& jfl, ListT<CegoField>& ofl)
 		    
 		    while ( pAttrRef )
 		    {
-			int i=0;
+			unsigned i=0;
 			bool notFound=true;
 			while ( i< _joinSize + _joinList[_joinLevel]->getSubCOList().Size()
 				&& notFound )
@@ -2089,7 +2089,7 @@ void CegoSelect::evalSchema(bool graceful)
     }
 
     CegoField *pF = _evalSchema.First();
-    int id=1;
+    unsigned id=1;
     while ( pF )
     {
         pF->setId(id);
@@ -2280,8 +2280,8 @@ void CegoSelect::consolidateConjunctionList()
 	}
     }
  
-    int growSize = 1;
-    int numAdded = 0;
+    unsigned growSize = 1;
+    unsigned numAdded = 0;
     while ( numAdded < _conjunctionList.Size() )
     {
 	pPred = _conjunctionList.First();
@@ -2320,7 +2320,7 @@ void CegoSelect::buildJoinTables()
 
     // growStep is the number of tables to join with the next join step
     // we start with growStep 1 
-    int growStep=1;
+    unsigned growStep=1;
     
     while ( _joinList.Size() != _coList.Size() && growStep <= _coList.Size() )
     {	
@@ -2459,7 +2459,7 @@ void CegoSelect::buildJoinConditions()
 	pP = _conjunctionList.Next();
     }
 
-    int i = 0;
+    unsigned i = 0;
     while ( i < TABMNG_MAXJOINLEVEL )
     {
 	_attrCondFlag[i]=false;
@@ -2471,7 +2471,7 @@ void CegoSelect::buildJoinConditions()
     
     if ( _pParentJoinBuf )
     {
-	int i=0;
+	unsigned i=0;
 	while ( _pParentJoinBuf[i] )
 	{
 	    availJoinFields += *_pParentJoinBuf[i];
@@ -2582,7 +2582,7 @@ void CegoSelect::buildJoinRefs()
 {
     // provide all selected fields in _joinFields
 
-    int i=0;
+    unsigned i=0;
     CegoContentObject** pCO = _joinList.First();
     
     while ( pCO )
@@ -2627,7 +2627,7 @@ void CegoSelect::buildJoinRefs()
 		_joinBuf[i] = new ListT<CegoField>;
 	    
 	    CegoField *pF = outSchema.First();
-	    int maxId=0;
+	    unsigned maxId=0;
 	    while ( pF )
 	    {
 		if ( pF->getId() > maxId )
@@ -2635,7 +2635,7 @@ void CegoSelect::buildJoinRefs()
 		pF = outSchema.Next();
 	    }
 
-	    for ( int id=0; id<=maxId; id++ )
+	    for ( unsigned id=0; id<=maxId; id++ )
 	    {
 		CegoField *pF = outSchema.First();
 		while ( pF )
@@ -2695,7 +2695,7 @@ void CegoSelect::filterRefs(const ListT<CegoField>& inSchema, ListT<CegoField>&
     
     ListT<CegoField> tmpSchema[TABMNG_MAXTMPSCHEMA];
 
-    int tmpidx=0;
+    unsigned tmpidx=0;
 
     if (_pPred)
     {
@@ -2749,7 +2749,7 @@ void CegoSelect::filterRefs(const ListT<CegoField>& inSchema, ListT<CegoField>&
 
     // merge tmpSchemas to outSchema
 
-    for ( int i=0; i < tmpidx; i++)
+    for ( unsigned i=0; i < tmpidx; i++)
     {
 	CegoField *pF = tmpSchema[i].First();
 	while( pF )
@@ -3087,9 +3087,9 @@ void CegoSelect::getCondObjectList(CegoCondition* pC, ListT<CegoContentObject*>&
 // table information for later processing. In these terms, the defined selection list
 // but also all refrences in the condition clause are resolved.
 
-int CegoSelect::evalExtTableReferences(CegoContentObject* pCO, const ListT<CegoField>& fl)
+unsigned CegoSelect::evalExtTableReferences(CegoContentObject* pCO, const ListT<CegoField>& fl)
 {
-    int refCount = evalTableReferences(pCO, fl);
+    unsigned refCount = evalTableReferences(pCO, fl);
     if ( refCount > 0 )
     {
 	// we do not disable cache anymore, rather in case of external references, we add external fields to query id
@@ -3101,9 +3101,9 @@ int CegoSelect::evalExtTableReferences(CegoContentObject* pCO, const ListT<CegoF
     return refCount;
 }
 
-int CegoSelect::evalTableReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
+unsigned CegoSelect::evalTableReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
 {
-    int refCount = 0;
+    unsigned refCount = 0;
 
     CegoExpr** pExpr = _exprList.First();
     while (pExpr)
@@ -3235,7 +3235,7 @@ void CegoSelect::evalSelection(ListT<CegoExpr*>& exprList, ListT<CegoField>** pJ
 {    
     if ( exprList.isEmpty() )
     {
-	int i=0;
+	unsigned i=0;
 	while ( pJoinBuf[i] )
 	{
 	    CegoField* pF = pJoinBuf[i]->First();
@@ -3271,7 +3271,7 @@ void CegoSelect::evalSelection(ListT<CegoExpr*>& exprList, ListT<CegoField>** pJ
 	    {
 		if ( pAttrDesc->getAttrName() == Chain(SELECTION_WILDCARD) )
 		{	    
-		    int i=0;
+		    unsigned i=0;
 		    while ( pJoinBuf[i] )
 		    {
 			CegoField *pF = pJoinBuf[i]->First();
@@ -3297,7 +3297,7 @@ void CegoSelect::evalSelection(ListT<CegoExpr*>& exprList, ListT<CegoField>** pJ
 		    
 		    ListT<CegoField>* fl[TABMNG_MAXJOINLEVEL];
 
-		    int i=0;
+		    unsigned i=0;
 		    while ( pJoinBuf[i] )
 		    {
 			fl[i] = pJoinBuf[i];
@@ -3305,7 +3305,7 @@ void CegoSelect::evalSelection(ListT<CegoExpr*>& exprList, ListT<CegoField>** pJ
 		    }
 		    if ( _pParentJoinBuf )
 		    {
-			int j=0;
+			unsigned j=0;
 			while ( _pParentJoinBuf[j] )
 			{
 			    fl[i] = _pParentJoinBuf[j];
@@ -3328,7 +3328,7 @@ void CegoSelect::evalSelection(ListT<CegoExpr*>& exprList, ListT<CegoField>** pJ
 		
 		ListT<CegoField>* fl[TABMNG_MAXJOINLEVEL];
 		
-		int i=0;
+		unsigned i=0;
 		while ( pJoinBuf[i] )
 		{
 		    fl[i] = pJoinBuf[i];
@@ -3336,7 +3336,7 @@ void CegoSelect::evalSelection(ListT<CegoExpr*>& exprList, ListT<CegoField>** pJ
 		}
 		if ( _pParentJoinBuf )
 		{
-		    int j=0;
+		    unsigned j=0;
 		    while ( _pParentJoinBuf[j] )
 		    {
 			fl[i] = _pParentJoinBuf[j];
@@ -3360,7 +3360,7 @@ void CegoSelect::encode(char *buf, CegoProcBlock *pBlock)
 {
     char* pBuf = (char*)buf;
 
-    int size = 0;
+    unsigned size = 0;
     CegoExpr** pExpr = _exprList.First();
     while (pExpr)
     {
@@ -3368,8 +3368,8 @@ void CegoSelect::encode(char *buf, CegoProcBlock *pBlock)
 	pExpr = _exprList.Next();
     }
     
-    memcpy( pBuf, &size, sizeof(int));
-    pBuf = pBuf + sizeof(int);
+    memcpy( pBuf, &size, sizeof(unsigned));
+    pBuf = pBuf + sizeof(unsigned);
 
     pExpr = _exprList.First();
     while (pExpr)
@@ -3387,8 +3387,8 @@ void CegoSelect::encode(char *buf, CegoProcBlock *pBlock)
 	pCO = _coList.Next();
     }
 
-    memcpy( pBuf, &size, sizeof(int));
-    pBuf = pBuf + sizeof(int);
+    memcpy( pBuf, &size, sizeof(unsigned));
+    pBuf = pBuf + sizeof(unsigned);
 
     pCO = _coList.First();
     while (pCO)
@@ -3402,15 +3402,15 @@ void CegoSelect::encode(char *buf, CegoProcBlock *pBlock)
     if (_pPred)
     {
 	size = _pPred->getEncodingLength(pBlock);
-	memcpy( pBuf, &size, sizeof(int));
-	pBuf = pBuf + sizeof(int);
+	memcpy( pBuf, &size, sizeof(unsigned));
+	pBuf = pBuf + sizeof(unsigned);
 	_pPred->encode(pBuf, pBlock);
 	pBuf = pBuf + size;
     }
     else
     {
-	memcpy( pBuf, &size, sizeof(int));
-	pBuf = pBuf + sizeof(int);
+	memcpy( pBuf, &size, sizeof(unsigned));
+	pBuf = pBuf + sizeof(unsigned);
     }
     
     size = 0;
@@ -3423,8 +3423,8 @@ void CegoSelect::encode(char *buf, CegoProcBlock *pBlock)
 	    pAttrDesc = _pGroupList->Next();
 	}
        
-	memcpy( pBuf, &size, sizeof(int));
-	pBuf = pBuf + sizeof(int);
+	memcpy( pBuf, &size, sizeof(unsigned));
+	pBuf = pBuf + sizeof(unsigned);
 
 	pAttrDesc = _pGroupList->First();
 	while ( pAttrDesc )
@@ -3438,21 +3438,21 @@ void CegoSelect::encode(char *buf, CegoProcBlock *pBlock)
 	if ( _pHavingPred )
 	{
 	    size = _pHavingPred->getEncodingLength(pBlock);
-	    memcpy( pBuf, &size, sizeof(int));
-	    pBuf = pBuf + sizeof(int);
+	    memcpy( pBuf, &size, sizeof(unsigned));
+	    pBuf = pBuf + sizeof(unsigned);
 	    _pHavingPred->encode(pBuf, pBlock);
 	    pBuf = pBuf + size;
 	}
 	else
 	{
-	    memcpy( pBuf, &size, sizeof(int));
-	    pBuf = pBuf + sizeof(int);
+	    memcpy( pBuf, &size, sizeof(unsigned));
+	    pBuf = pBuf + sizeof(unsigned);
 	}
     }
     else
     {
-	memcpy( pBuf, &size, sizeof(int));
-	pBuf = pBuf + sizeof(int);	
+	memcpy( pBuf, &size, sizeof(unsigned));
+	pBuf = pBuf + sizeof(unsigned);	
     }
     size = 0;
     if ( _pOrderList )
@@ -3464,8 +3464,8 @@ void CegoSelect::encode(char *buf, CegoProcBlock *pBlock)
 	    pExpr = _pOrderList->Next();
 	}
        
-	memcpy( pBuf, &size, sizeof(int));
-	pBuf = pBuf + sizeof(int);
+	memcpy( pBuf, &size, sizeof(unsigned));
+	pBuf = pBuf + sizeof(unsigned);
 	
 	pExpr = _pOrderList->First();
 	while (pExpr)
@@ -3477,40 +3477,40 @@ void CegoSelect::encode(char *buf, CegoProcBlock *pBlock)
     }
     else
     {
-	memcpy( pBuf, &size, sizeof(int));
-	pBuf = pBuf + sizeof(int);	
+	memcpy( pBuf, &size, sizeof(unsigned));
+	pBuf = pBuf + sizeof(unsigned);	
     }
 
     size = 0;
     if ( _pUnionSelect )
     {
 	size = _pUnionSelect->getEncodingLength(pBlock);
-	memcpy( pBuf, &size, sizeof(int));
-	pBuf = pBuf + sizeof(int);
+	memcpy( pBuf, &size, sizeof(unsigned));
+	pBuf = pBuf + sizeof(unsigned);
 
 	_pUnionSelect->encode(pBuf, pBlock);
 	pBuf = pBuf + _pUnionSelect->getEncodingLength(pBlock);
     }
     else
     {
-	memcpy( pBuf, &size, sizeof(int));
-	pBuf = pBuf + sizeof(int);
+	memcpy( pBuf, &size, sizeof(unsigned));
+	pBuf = pBuf + sizeof(unsigned);
     }
 }
 
-void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId)
+void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     char* pBuf = (char*)buf;
     
-    int size;
-    memcpy( &size, pBuf, sizeof(int));
-    pBuf += sizeof(int);
+    unsigned size;
+    memcpy( &size, pBuf, sizeof(unsigned));
+    pBuf += sizeof(unsigned);
     
-    int i = 0;
+    unsigned i = 0;
     while ( i < size )
     {
 	CegoExpr *pExpr = new CegoExpr(pBuf, pGTM, pBlock, tabSetId);
-	int len = pExpr->getEncodingLength(pBlock);
+	unsigned len = pExpr->getEncodingLength(pBlock);
 	
 	pBuf += len;
 	i += len;
@@ -3518,8 +3518,8 @@ void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock,
 	_exprList.Insert( pExpr );	
     }
 
-    memcpy( &size, pBuf, sizeof(int));
-    pBuf += sizeof(int);
+    memcpy( &size, pBuf, sizeof(unsigned));
+    pBuf += sizeof(unsigned);
     
     i = 0;
     while ( i < size )
@@ -3527,7 +3527,7 @@ void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock,
 	CegoContentObject *pCO;
 
 	CegoObject obj;
-	int size;
+	unsigned size;
 	obj.decodeBase(pBuf, size);   
 		
 	if ( obj.getType() == CegoObject::TABLE )
@@ -3549,7 +3549,7 @@ void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock,
 	}
 	pCO->decode(pBuf);	    
 
-	int len = pCO->getEntrySize();
+	unsigned len = pCO->getEntrySize();
 	
 	pBuf += len;
 	i += len;
@@ -3557,8 +3557,8 @@ void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock,
 	_coList.Insert( pCO );	
     }
 
-    memcpy( &size, pBuf, sizeof(int));
-    pBuf += sizeof(int);
+    memcpy( &size, pBuf, sizeof(unsigned));
+    pBuf += sizeof(unsigned);
     
     if ( size > 0 )
     {
@@ -3570,8 +3570,8 @@ void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock,
 	_pPred = 0;
     }
 
-    memcpy( &size, pBuf, sizeof(int));
-    pBuf += sizeof(int);
+    memcpy( &size, pBuf, sizeof(unsigned));
+    pBuf += sizeof(unsigned);
 
     if ( size > 0 )
     {
@@ -3581,7 +3581,7 @@ void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock,
 	while ( i < size )
 	{
 	    CegoAttrDesc* pAD = new CegoAttrDesc(pBuf);
-	    int len = pAD->getEncodingLength();
+	    unsigned len = pAD->getEncodingLength();
 	    
 	    pBuf += len;
 	    i += len;
@@ -3589,8 +3589,8 @@ void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock,
 	    _pGroupList->Insert( pAD );	    
 	}
 		
-	memcpy( &size, pBuf, sizeof(int));
-	pBuf += sizeof(int);
+	memcpy( &size, pBuf, sizeof(unsigned));
+	pBuf += sizeof(unsigned);
 
 	if ( size > 0 )
 	{
@@ -3608,18 +3608,18 @@ void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock,
 	_pHavingPred = 0;
     }
 
-    memcpy( &size, pBuf, sizeof(int));
-    pBuf += sizeof(int);
+    memcpy( &size, pBuf, sizeof(unsigned));
+    pBuf += sizeof(unsigned);
     
     if ( size > 0 )
     {
 	_pOrderList = new ListT<CegoExpr*>;
 
-	int i = 0;
+	unsigned i = 0;
 	while ( i < size )
 	{
 	    CegoExpr *pExpr = new CegoExpr(pBuf, pGTM, pBlock, tabSetId);
-	    int len = pExpr->getEncodingLength(pBlock);
+	    unsigned len = pExpr->getEncodingLength(pBlock);
 	    
 	    pBuf += len;
 	    i += len;
@@ -3632,8 +3632,8 @@ void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock,
 	_pOrderList = 0;
     }
 
-    memcpy( &size, pBuf, sizeof(int));
-    pBuf += sizeof(int);
+    memcpy( &size, pBuf, sizeof(unsigned));
+    pBuf += sizeof(unsigned);
     
     if ( size > 0 )
     {
@@ -3645,11 +3645,11 @@ void CegoSelect::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock,
     }
 }
 
-int CegoSelect::getEncodingLength(CegoProcBlock *pBlock) const
+unsigned CegoSelect::getEncodingLength(CegoProcBlock *pBlock) const
 {    
-    int len=0;
+    unsigned len=0;
 
-    len += sizeof(int);
+    len += sizeof(unsigned);
     CegoExpr** pExpr = _exprList.First();
     while (pExpr)
     {
@@ -3657,7 +3657,7 @@ int CegoSelect::getEncodingLength(CegoProcBlock *pBlock) const
 	pExpr = _exprList.Next();
     }
     
-    len += sizeof(int);
+    len += sizeof(unsigned);
     CegoContentObject** pCO = _coList.First();
     while (pCO)
     {
@@ -3665,14 +3665,14 @@ int CegoSelect::getEncodingLength(CegoProcBlock *pBlock) const
 	pCO = _coList.Next();
     }
 
-    len += sizeof(int);
+    len += sizeof(unsigned);
 
     if (_pPred)
     {
 	len += _pPred->getEncodingLength(pBlock);
     }
 
-    len += sizeof(int);
+    len += sizeof(unsigned);
 
     if (_pGroupList)
     {
@@ -3683,7 +3683,7 @@ int CegoSelect::getEncodingLength(CegoProcBlock *pBlock) const
 	    pAttrDesc = _pGroupList->Next();
 	}
 
-	len += sizeof(int);
+	len += sizeof(unsigned);
 
 	if ( _pHavingPred )
 	{
@@ -3691,7 +3691,7 @@ int CegoSelect::getEncodingLength(CegoProcBlock *pBlock) const
 	}
     }
 
-    len += sizeof(int);
+    len += sizeof(unsigned);
 
     if ( _pOrderList )
     {	
@@ -3703,7 +3703,7 @@ int CegoSelect::getEncodingLength(CegoProcBlock *pBlock) const
 	}
     }
 
-    len += sizeof(int);
+    len += sizeof(unsigned);
 
     if (_pUnionSelect)
     {
@@ -3782,7 +3782,7 @@ bool CegoSelect::setViewCond(const Chain& viewAlias,  CegoAttrCond& attrCond, Ce
     return isComplete;
 }
 
-Chain CegoSelect::toChain(int defTabSetId, const Chain& indent) const
+Chain CegoSelect::toChain(unsigned defTabSetId, const Chain& indent) const
 {
     Chain s;
 
@@ -3969,7 +3969,7 @@ void CegoSelect::getFieldList(ListT<CegoField>& fl, ListT<CegoField>** pFLA) con
 
 void CegoSelect::initAggregation()
 {
-    int nextAid=0;
+    unsigned nextAid=0;
     
     CegoExpr** pExpr = _exprList.First();
     while ( pExpr )
@@ -4221,12 +4221,12 @@ void CegoSelect::prepareOrder()
     return;
 }
  
-void CegoSelect::setExtRefCount(int refCount)
+void CegoSelect::setExtRefCount(unsigned refCount)
 {
     _extRefCount = refCount;
 }
 
-int CegoSelect::getExtRefCount() const
+unsigned CegoSelect::getExtRefCount() const
 {
     return _extRefCount;
 }
@@ -4346,7 +4346,7 @@ void CegoSelect::mergeBuffer()
 
     if ( _pParentJoinBuf )
     {		
-	int i=0;
+	unsigned i=0;
 	while ( _joinBuf[i] )
 	{	    
 	    _mergeBuf[i] = _joinBuf[i];
@@ -4355,7 +4355,7 @@ void CegoSelect::mergeBuffer()
 	
 	// now we take parent join buf we a lower priority
 	
-	int j=0;
+	unsigned j=0;
 	while ( _pParentJoinBuf[j] )
 	{	    
 	    _mergeBuf[i] = _pParentJoinBuf[j];	    
