@@ -31,7 +31,7 @@ CegoTerm::CegoTerm()
     _pFactor=0;
 }
 
-CegoTerm::CegoTerm(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId)
+CegoTerm::CegoTerm(char* buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     _pTerm = 0;
     _pFactor = 0;
@@ -69,7 +69,7 @@ void CegoTerm::cleanUp()
 	_pFactor->cleanUp();
 }
 
-void CegoTerm::setTabSetId(int tabSetId)
+void CegoTerm::setTabSetId(unsigned tabSetId)
 {
     if ( _pTerm )
 	_pTerm->setTabSetId(tabSetId);
@@ -205,9 +205,9 @@ ListT<CegoAttrDesc*> CegoTerm::getAttrRefList() const
     return attrList;
 }
 
-int CegoTerm::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
+unsigned CegoTerm::evalReferences(CegoContentObject *pCO, const ListT<CegoField>& fl)
 {
-    int refCount = 0;
+    unsigned refCount = 0;
 
     switch ( _termType )
     {
@@ -240,8 +240,8 @@ CegoField CegoTerm::evalField(const ListT<CegoField>& fl, bool graceful) const
 
 	// the type conversion refers to method : CegoFieldValue operator * ( const CegoFieldValue& fv1, const CegoFieldValue& fv2 )
 	CegoDataType dt;
-	int len;
-	int dim;
+	unsigned len;
+	unsigned dim;
 	
 	if ( f1.getType() == DECIMAL_TYPE )
 	{
@@ -276,8 +276,8 @@ CegoField CegoTerm::evalField(const ListT<CegoField>& fl, bool graceful) const
 
 	// the type conversion refers to method : CegoFieldValue operator / ( const CegoFieldValue& fv1, const CegoFieldValue& fv2 )
 	CegoDataType dt;
-	int len;
-	int dim;
+	unsigned len;
+	unsigned dim;
 	
 	if ( f1.getType() == DECIMAL_TYPE )
 	{
@@ -391,7 +391,7 @@ void CegoTerm::encode(char *buf, CegoProcBlock *pBlock)
     }
 }
 
-void CegoTerm::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, int tabSetId)
+void CegoTerm::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, unsigned tabSetId)
 {
     char* pE = (char*)buf;
 
@@ -419,9 +419,9 @@ void CegoTerm::decode(char *buf, CegoDistManager *pGTM, CegoProcBlock *pBlock, i
     }
 }
 
-int CegoTerm::getEncodingLength(CegoProcBlock *pBlock) const
+unsigned CegoTerm::getEncodingLength(CegoProcBlock *pBlock) const
 {
-    int len = 0;
+    unsigned len = 0;
 
     len += sizeof(CegoTerm::TermType);
 
@@ -462,7 +462,7 @@ Chain CegoTerm::getId(CegoProcBlock *pBlock) const
     return s;    
 }
 
-Chain CegoTerm::toChain(int defTabSetId, const Chain& indent) const
+Chain CegoTerm::toChain(unsigned defTabSetId, const Chain& indent) const
 {
     Chain s;
     switch ( _termType )
