@@ -47,7 +47,7 @@ static SetT<Chain> modLogSet;
 
 extern "C" {
 
-    void cego_modlog(char* module, int level)
+    void cego_modlog(char* module, unsigned level)
     {
 	Chain modEntry = *module;
 
@@ -62,7 +62,7 @@ extern "C" {
     }
 
     CGDB* cego_connect(char *servername, 
-		       int portno,
+		       unsigned portno,
 		       char *prot,
 		       char *tsname, 
 		       char *user, 
@@ -234,7 +234,7 @@ extern "C" {
 	return -1;
     }
 
-    CGVal* cego_allocate_value(int type, int len, void *val)      
+    CGVal* cego_allocate_value(unsigned type, unsigned len, void *val)      
     {	
 	CGVal *pVal = (CGVal*)malloc(sizeof(CGVal));
 	pVal->type = type;
@@ -346,7 +346,7 @@ extern "C" {
     {
 	if ( cgfetch )
 	{
-	    int pos = 0;
+	    unsigned pos = 0;
 	    CegoField *pF = cgfetch->pSchema->First();
 	    while ( pF )
 	    {
@@ -360,7 +360,7 @@ extern "C" {
 	return -1;
     }
 
-    char* cego_getcolname(CGFetch* cgfetch, int pos)
+    char* cego_getcolname(CGFetch* cgfetch, unsigned pos)
     {
 	if ( cgfetch )
 	{
@@ -373,7 +373,7 @@ extern "C" {
 	return NULL;
     }
 
-    int cego_getcollen(CGFetch* cgfetch, int pos)
+    int cego_getcollen(CGFetch* cgfetch, unsigned pos)
     {
 	if ( cgfetch )
 	{
@@ -386,7 +386,7 @@ extern "C" {
 	return -1;
     }
 
-    int cego_getcoltype(CGFetch* cgfetch, int pos)
+    int cego_getcoltype(CGFetch* cgfetch, unsigned pos)
     {
 	if ( cgfetch )
 	{
@@ -470,7 +470,7 @@ extern "C" {
 	return NULL;
     }
 	
-    int cego_bind_in (CGStmt * cgstmt, CGVal* cgval, int pos)
+    int cego_bind_in (CGStmt * cgstmt, CGVal* cgval, unsigned pos)
     {
 	if ( cgstmt && cgval )
 	{
@@ -493,7 +493,7 @@ extern "C" {
 	return -1;
     }
     
-    int cego_bind_out (CGStmt * cgstmt, CGVal* cgval, int pos)
+    int cego_bind_out (CGStmt * cgstmt, CGVal* cgval, unsigned pos)
     {
 	if ( cgstmt && cgval )
 	{
@@ -509,7 +509,7 @@ extern "C" {
 	return -1;
     }
 	
-    int cego_bind_inout (CGStmt * cgstmt, CGVal* cgval, int pos)
+    int cego_bind_inout (CGStmt * cgstmt, CGVal* cgval, unsigned pos)
     {
 	if ( cgstmt && cgval )
 	{
@@ -539,7 +539,7 @@ extern "C" {
 	    }
 	    else
 	    {	
-		int pos=1;
+		unsigned pos=1;
 		
 		Chain* pChunk = cgstmt->pStmtChunks->First();
 		
@@ -822,7 +822,7 @@ extern "C" {
 	return -1;	
     }
     
-    int cego_fetch (CGFetch *cgfetch, CGVal cgval[], int numCol)
+    int cego_fetch (CGFetch *cgfetch, CGVal cgval[], unsigned numCol)
     {
 	if ( cgfetch )
 	{
@@ -834,7 +834,7 @@ extern "C" {
 	    ListT<CegoFieldValue> fvl;
 	    if ( ( res = cgfetch->cgdb->pDB->receiveTableData(*(cgfetch->pSchema), fvl) ) == CegoDbHandler::DB_DATA )
 	    {
-		int pos=0;
+		unsigned pos=0;
 		CegoFieldValue *pFV = fvl.First();
 		while ( pFV )
 		{
@@ -927,7 +927,7 @@ extern "C" {
 		return -1;
 	    }
 	    
-	    if ( cgblob->len < (int)blob.getSize() )
+	    if ( cgblob->len < (unsigned)blob.getSize() )
 	    {
 		cgblob->buf = (unsigned char*)realloc( cgblob->buf, blob.getSize());
 		cgblob->len = blob.getSize();
@@ -991,7 +991,7 @@ extern "C" {
 		strcpy(cgerrmsg, (char*)msg);		
 		return -1;
 	    }
-	    if ( cgclob->len < (int)clob.getSize() )
+	    if ( cgclob->len < (unsigned)clob.getSize() )
 	    {
 		cgclob->buf = (char*)realloc( cgclob->buf, clob.getSize());
 		cgclob->len = clob.getSize();
